Class: Google::Apis::ConnectorsV1::AuthorizationCodeLink

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

This configuration captures the details required to render an authorization link for the OAuth Authorization Code Flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthorizationCodeLink

Returns a new instance of AuthorizationCodeLink.



467
468
469
# File 'lib/google/apis/connectors_v1/classes.rb', line 467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

Optional. The client ID assigned to the Google Cloud Connectors OAuth app for the connector data source. Corresponds to the JSON property clientId

Returns:

  • (String)


436
437
438
# File 'lib/google/apis/connectors_v1/classes.rb', line 436

def client_id
  @client_id
end

#client_secretGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientSecret



441
442
443
# File 'lib/google/apis/connectors_v1/classes.rb', line 441

def client_secret
  @client_secret
end

#enable_pkceBoolean Also known as: enable_pkce?

Optional. Whether to enable PKCE for the auth code flow. Corresponds to the JSON property enablePkce

Returns:

  • (Boolean)


446
447
448
# File 'lib/google/apis/connectors_v1/classes.rb', line 446

def enable_pkce
  @enable_pkce
end

#omit_query_paramsBoolean Also known as: omit_query_params?

Optional. Omit query params from the redirect URI. Corresponds to the JSON property omitQueryParams

Returns:

  • (Boolean)


452
453
454
# File 'lib/google/apis/connectors_v1/classes.rb', line 452

def omit_query_params
  @omit_query_params
end

#scopesArray<String>

Optional. The scopes for which the user will authorize Google Cloud Connectors on the connector data source. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


459
460
461
# File 'lib/google/apis/connectors_v1/classes.rb', line 459

def scopes
  @scopes
end

#uriString

Optional. The base URI the user must click to trigger the authorization code login flow. Corresponds to the JSON property uri

Returns:

  • (String)


465
466
467
# File 'lib/google/apis/connectors_v1/classes.rb', line 465

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



472
473
474
475
476
477
478
479
# File 'lib/google/apis/connectors_v1/classes.rb', line 472

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @enable_pkce = args[:enable_pkce] if args.key?(:enable_pkce)
  @omit_query_params = args[:omit_query_params] if args.key?(:omit_query_params)
  @scopes = args[:scopes] if args.key?(:scopes)
  @uri = args[:uri] if args.key?(:uri)
end