Class: Google::Apis::ConnectorsV1::Connection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Connection represents an instance of connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Connection

Returns a new instance of Connection.



996
997
998
# File 'lib/google/apis/connectors_v1/classes.rb', line 996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_filtersArray<Google::Apis::ConnectorsV1::AdminFilters>

Optional. Admin filters for the connection. These are used by Gemini Enterprise. Corresponds to the JSON property adminFilters



789
790
791
# File 'lib/google/apis/connectors_v1/classes.rb', line 789

def admin_filters
  @admin_filters
end

#async_operations_enabledBoolean Also known as: async_operations_enabled?

Optional. Async operations enabled for the connection. If Async Operations is enabled, Connection allows the customers to initiate async long running operations using the actions API. Corresponds to the JSON property asyncOperationsEnabled

Returns:

  • (Boolean)


796
797
798
# File 'lib/google/apis/connectors_v1/classes.rb', line 796

def async_operations_enabled
  @async_operations_enabled
end

#auth_configGoogle::Apis::ConnectorsV1::AuthConfig

AuthConfig defines details of a authentication type. Corresponds to the JSON property authConfig



802
803
804
# File 'lib/google/apis/connectors_v1/classes.rb', line 802

def auth_config
  @auth_config
end

#auth_override_enabledBoolean Also known as: auth_override_enabled?

Optional. Auth override enabled for the connection. If Auth Override is enabled, Connection allows the backend service auth to be overridden in the entities/actions API. Corresponds to the JSON property authOverrideEnabled

Returns:

  • (Boolean)


809
810
811
# File 'lib/google/apis/connectors_v1/classes.rb', line 809

def auth_override_enabled
  @auth_override_enabled
end

#billing_configGoogle::Apis::ConnectorsV1::BillingConfig

Billing config for the connection. Corresponds to the JSON property billingConfig



815
816
817
# File 'lib/google/apis/connectors_v1/classes.rb', line 815

def billing_config
  @billing_config
end

#config_variablesArray<Google::Apis::ConnectorsV1::ConfigVariable>

Optional. Configuration for configuring the connection with an external system. Corresponds to the JSON property configVariables



820
821
822
# File 'lib/google/apis/connectors_v1/classes.rb', line 820

def config_variables
  @config_variables
end

#connection_revisionFixnum

Output only. Connection revision. This field is only updated when the connection is created or updated by User. Corresponds to the JSON property connectionRevision

Returns:

  • (Fixnum)


826
827
828
# File 'lib/google/apis/connectors_v1/classes.rb', line 826

def connection_revision
  @connection_revision
end

#connector_versionString

Required. Connector version on which the connection is created. The format is: projects//locations//providers//connectors//versions/* Only global location is supported for ConnectorVersion resource. Corresponds to the JSON property connectorVersion

Returns:

  • (String)


833
834
835
# File 'lib/google/apis/connectors_v1/classes.rb', line 833

def connector_version
  @connector_version
end

#connector_version_infra_configGoogle::Apis::ConnectorsV1::ConnectorVersionInfraConfig

This configuration provides infra configs like rate limit threshold which need to be configurable for every connector version Corresponds to the JSON property connectorVersionInfraConfig



839
840
841
# File 'lib/google/apis/connectors_v1/classes.rb', line 839

def connector_version_infra_config
  @connector_version_infra_config
end

#connector_version_launch_stageString

Output only. Flag to mark the version indicating the launch stage. Corresponds to the JSON property connectorVersionLaunchStage

Returns:

  • (String)


844
845
846
# File 'lib/google/apis/connectors_v1/classes.rb', line 844

def connector_version_launch_stage
  @connector_version_launch_stage
end

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


849
850
851
# File 'lib/google/apis/connectors_v1/classes.rb', line 849

def create_time
  @create_time
end

#descriptionString

Optional. Description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


854
855
856
# File 'lib/google/apis/connectors_v1/classes.rb', line 854

def description
  @description
end

#destination_configsArray<Google::Apis::ConnectorsV1::DestinationConfig>

Optional. Configuration of the Connector's destination. Only accepted for Connectors that accepts user defined destination(s). Corresponds to the JSON property destinationConfigs



860
861
862
# File 'lib/google/apis/connectors_v1/classes.rb', line 860

def destination_configs
  @destination_configs
end

#envoy_image_locationString

Output only. GCR location where the envoy image is stored. formatted like: gcr. io/bucketName/imageName Corresponds to the JSON property envoyImageLocation

Returns:

  • (String)


866
867
868
# File 'lib/google/apis/connectors_v1/classes.rb', line 866

def envoy_image_location
  @envoy_image_location
end

#eua_oauth_auth_configGoogle::Apis::ConnectorsV1::AuthConfig

AuthConfig defines details of a authentication type. Corresponds to the JSON property euaOauthAuthConfig



871
872
873
# File 'lib/google/apis/connectors_v1/classes.rb', line 871

def eua_oauth_auth_config
  @eua_oauth_auth_config
end

#eventing_configGoogle::Apis::ConnectorsV1::EventingConfig

Eventing Configuration of a connection next: 21 Corresponds to the JSON property eventingConfig



876
877
878
# File 'lib/google/apis/connectors_v1/classes.rb', line 876

def eventing_config
  @eventing_config
end

#eventing_enablement_typeString

Optional. Eventing enablement type. Will be nil if eventing is not enabled. Corresponds to the JSON property eventingEnablementType

Returns:

  • (String)


881
882
883
# File 'lib/google/apis/connectors_v1/classes.rb', line 881

def eventing_enablement_type
  @eventing_enablement_type
end

#eventing_runtime_dataGoogle::Apis::ConnectorsV1::EventingRuntimeData

Eventing runtime data has the details related to eventing managed by the system. Corresponds to the JSON property eventingRuntimeData



887
888
889
# File 'lib/google/apis/connectors_v1/classes.rb', line 887

def eventing_runtime_data
  @eventing_runtime_data
end

#fallback_on_admin_credentialsBoolean Also known as: fallback_on_admin_credentials?

Optional. Fallback on admin credentials for the connection. If this both auth_override_enabled and fallback_on_admin_credentials are set to true, the connection will use the admin credentials if the dynamic auth header is not present during auth override. Corresponds to the JSON property fallbackOnAdminCredentials

Returns:

  • (Boolean)


895
896
897
# File 'lib/google/apis/connectors_v1/classes.rb', line 895

def fallback_on_admin_credentials
  @fallback_on_admin_credentials
end

#hostString

Output only. The name of the Hostname of the Service Directory service with TLS. Corresponds to the JSON property host

Returns:

  • (String)


902
903
904
# File 'lib/google/apis/connectors_v1/classes.rb', line 902

def host
  @host
end

#image_locationString

Output only. GCR location where the runtime image is stored. formatted like: gcr.io/bucketName/imageName Corresponds to the JSON property imageLocation

Returns:

  • (String)


908
909
910
# File 'lib/google/apis/connectors_v1/classes.rb', line 908

def image_location
  @image_location
end

#is_trusted_testerBoolean Also known as: is_trusted_tester?

Output only. Is trusted tester program enabled for the project. Corresponds to the JSON property isTrustedTester

Returns:

  • (Boolean)


913
914
915
# File 'lib/google/apis/connectors_v1/classes.rb', line 913

def is_trusted_tester
  @is_trusted_tester
end

#labelsHash<String,String>

Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/ docs/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


921
922
923
# File 'lib/google/apis/connectors_v1/classes.rb', line 921

def labels
  @labels
end

#lock_configGoogle::Apis::ConnectorsV1::LockConfig

Determines whether or no a connection is locked. If locked, a reason must be specified. Corresponds to the JSON property lockConfig



927
928
929
# File 'lib/google/apis/connectors_v1/classes.rb', line 927

def lock_config
  @lock_config
end

#log_configGoogle::Apis::ConnectorsV1::ConnectorsLogConfig

Log configuration for the connection. Corresponds to the JSON property logConfig



932
933
934
# File 'lib/google/apis/connectors_v1/classes.rb', line 932

def log_config
  @log_config
end

#nameString

Output only. Resource name of the Connection. Format: projects/project/ locations/location/connections/connection Corresponds to the JSON property name

Returns:

  • (String)


938
939
940
# File 'lib/google/apis/connectors_v1/classes.rb', line 938

def name
  @name
end

#node_configGoogle::Apis::ConnectorsV1::NodeConfig

Node configuration for the connection. Corresponds to the JSON property nodeConfig



943
944
945
# File 'lib/google/apis/connectors_v1/classes.rb', line 943

def node_config
  @node_config
end

#service_accountString

Optional. Service account needed for runtime plane to access Google Cloud resources. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


949
950
951
# File 'lib/google/apis/connectors_v1/classes.rb', line 949

def 
  @service_account
end

#service_directoryString

Output only. The name of the Service Directory service name. Used for Private Harpoon to resolve the ILB address. e.g. "projects/cloud-connectors-e2e- testing/locations/us-central1/namespaces/istio-system/services/istio- ingressgateway-connectors" Corresponds to the JSON property serviceDirectory

Returns:

  • (String)


957
958
959
# File 'lib/google/apis/connectors_v1/classes.rb', line 957

def service_directory
  @service_directory
end

#ssl_configGoogle::Apis::ConnectorsV1::SslConfig

SSL Configuration of a connection Corresponds to the JSON property sslConfig



962
963
964
# File 'lib/google/apis/connectors_v1/classes.rb', line 962

def ssl_config
  @ssl_config
end

#statusGoogle::Apis::ConnectorsV1::ConnectionStatus

ConnectionStatus indicates the state of the connection. Corresponds to the JSON property status



967
968
969
# File 'lib/google/apis/connectors_v1/classes.rb', line 967

def status
  @status
end

#subscription_typeString

Output only. This subscription type enum states the subscription type of the project. Corresponds to the JSON property subscriptionType

Returns:

  • (String)


973
974
975
# File 'lib/google/apis/connectors_v1/classes.rb', line 973

def subscription_type
  @subscription_type
end

#suspendedBoolean Also known as: suspended?

Optional. Suspended indicates if a user has suspended a connection or not. Corresponds to the JSON property suspended

Returns:

  • (Boolean)


978
979
980
# File 'lib/google/apis/connectors_v1/classes.rb', line 978

def suspended
  @suspended
end

#tls_service_directoryString

Output only. The name of the Service Directory service with TLS. Corresponds to the JSON property tlsServiceDirectory

Returns:

  • (String)


984
985
986
# File 'lib/google/apis/connectors_v1/classes.rb', line 984

def tls_service_directory
  @tls_service_directory
end

#traffic_shaping_configsArray<Google::Apis::ConnectorsV1::TrafficShapingConfig>

Optional. Traffic shaping configuration for the connection. Corresponds to the JSON property trafficShapingConfigs



989
990
991
# File 'lib/google/apis/connectors_v1/classes.rb', line 989

def traffic_shaping_configs
  @traffic_shaping_configs
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


994
995
996
# File 'lib/google/apis/connectors_v1/classes.rb', line 994

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
# File 'lib/google/apis/connectors_v1/classes.rb', line 1001

def update!(**args)
  @admin_filters = args[:admin_filters] if args.key?(:admin_filters)
  @async_operations_enabled = args[:async_operations_enabled] if args.key?(:async_operations_enabled)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @auth_override_enabled = args[:auth_override_enabled] if args.key?(:auth_override_enabled)
  @billing_config = args[:billing_config] if args.key?(:billing_config)
  @config_variables = args[:config_variables] if args.key?(:config_variables)
  @connection_revision = args[:connection_revision] if args.key?(:connection_revision)
  @connector_version = args[:connector_version] if args.key?(:connector_version)
  @connector_version_infra_config = args[:connector_version_infra_config] if args.key?(:connector_version_infra_config)
  @connector_version_launch_stage = args[:connector_version_launch_stage] if args.key?(:connector_version_launch_stage)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination_configs = args[:destination_configs] if args.key?(:destination_configs)
  @envoy_image_location = args[:envoy_image_location] if args.key?(:envoy_image_location)
  @eua_oauth_auth_config = args[:eua_oauth_auth_config] if args.key?(:eua_oauth_auth_config)
  @eventing_config = args[:eventing_config] if args.key?(:eventing_config)
  @eventing_enablement_type = args[:eventing_enablement_type] if args.key?(:eventing_enablement_type)
  @eventing_runtime_data = args[:eventing_runtime_data] if args.key?(:eventing_runtime_data)
  @fallback_on_admin_credentials = args[:fallback_on_admin_credentials] if args.key?(:fallback_on_admin_credentials)
  @host = args[:host] if args.key?(:host)
  @image_location = args[:image_location] if args.key?(:image_location)
  @is_trusted_tester = args[:is_trusted_tester] if args.key?(:is_trusted_tester)
  @labels = args[:labels] if args.key?(:labels)
  @lock_config = args[:lock_config] if args.key?(:lock_config)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @node_config = args[:node_config] if args.key?(:node_config)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_directory = args[:service_directory] if args.key?(:service_directory)
  @ssl_config = args[:ssl_config] if args.key?(:ssl_config)
  @status = args[:status] if args.key?(:status)
  @subscription_type = args[:subscription_type] if args.key?(:subscription_type)
  @suspended = args[:suspended] if args.key?(:suspended)
  @tls_service_directory = args[:tls_service_directory] if args.key?(:tls_service_directory)
  @traffic_shaping_configs = args[:traffic_shaping_configs] if args.key?(:traffic_shaping_configs)
  @update_time = args[:update_time] if args.key?(:update_time)
end