Class: Google::Apis::ConnectorsV1::ConnectionSchemaMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

ConnectionSchemaMetadata is the singleton resource of each connection. It includes the entity and action names of runtime resources exposed by a connection backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionSchemaMetadata

Returns a new instance of ConnectionSchemaMetadata.



1084
1085
1086
# File 'lib/google/apis/connectors_v1/classes.rb', line 1084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<String>

Output only. List of actions. Corresponds to the JSON property actions

Returns:

  • (Array<String>)


1050
1051
1052
# File 'lib/google/apis/connectors_v1/classes.rb', line 1050

def actions
  @actions
end

#entitiesArray<String>

Output only. List of entity names. Corresponds to the JSON property entities

Returns:

  • (Array<String>)


1055
1056
1057
# File 'lib/google/apis/connectors_v1/classes.rb', line 1055

def entities
  @entities
end

#error_messageString

Error message for users. Corresponds to the JSON property errorMessage

Returns:

  • (String)


1060
1061
1062
# File 'lib/google/apis/connectors_v1/classes.rb', line 1060

def error_message
  @error_message
end

#nameString

Output only. Resource name. Format: projects/project/locations/location/ connections/connection/connectionSchemaMetadata Corresponds to the JSON property name

Returns:

  • (String)


1066
1067
1068
# File 'lib/google/apis/connectors_v1/classes.rb', line 1066

def name
  @name
end

#refresh_timeString

Output only. Timestamp when the connection runtime schema refresh was triggered. Corresponds to the JSON property refreshTime

Returns:

  • (String)


1072
1073
1074
# File 'lib/google/apis/connectors_v1/classes.rb', line 1072

def refresh_time
  @refresh_time
end

#stateString

Output only. The current state of runtime schema. Corresponds to the JSON property state

Returns:

  • (String)


1077
1078
1079
# File 'lib/google/apis/connectors_v1/classes.rb', line 1077

def state
  @state
end

#update_timeString

Output only. Timestamp when the connection runtime schema was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1082
1083
1084
# File 'lib/google/apis/connectors_v1/classes.rb', line 1082

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1089
1090
1091
1092
1093
1094
1095
1096
1097
# File 'lib/google/apis/connectors_v1/classes.rb', line 1089

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @entities = args[:entities] if args.key?(:entities)
  @error_message = args[:error_message] if args.key?(:error_message)
  @name = args[:name] if args.key?(:name)
  @refresh_time = args[:refresh_time] if args.key?(:refresh_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end