Class: Google::Apis::ConnectorsV1::ConnectorInfraConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

This cofiguration provides infra configs like rate limit threshold which need to be configurable for every connector version

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectorInfraConfig

Returns a new instance of ConnectorInfraConfig.



1343
1344
1345
# File 'lib/google/apis/connectors_v1/classes.rb', line 1343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#always_allocate_cpuBoolean Also known as: always_allocate_cpu?

Indicates that the Cloud Run CPU should always be allocated. Corresponds to the JSON property alwaysAllocateCpu

Returns:

  • (Boolean)


1246
1247
1248
# File 'lib/google/apis/connectors_v1/classes.rb', line 1246

def always_allocate_cpu
  @always_allocate_cpu
end

#connection_ratelimit_window_secondsFixnum

The window used for ratelimiting runtime requests to connections. Corresponds to the JSON property connectionRatelimitWindowSeconds

Returns:

  • (Fixnum)


1252
1253
1254
# File 'lib/google/apis/connectors_v1/classes.rb', line 1252

def connection_ratelimit_window_seconds
  @connection_ratelimit_window_seconds
end

#connection_service_account_enabledBoolean Also known as: connection_service_account_enabled?

Indicate whether connection service account is enabled. If false, the common runtime service agent is used. Corresponds to the JSON property connectionServiceAccountEnabled

Returns:

  • (Boolean)


1258
1259
1260
# File 'lib/google/apis/connectors_v1/classes.rb', line 1258

def 
  @connection_service_account_enabled
end

#connector_versioning_enabledBoolean Also known as: connector_versioning_enabled?

Indicate whether connector versioning is enabled. Corresponds to the JSON property connectorVersioningEnabled

Returns:

  • (Boolean)


1264
1265
1266
# File 'lib/google/apis/connectors_v1/classes.rb', line 1264

def connector_versioning_enabled
  @connector_versioning_enabled
end

#deployment_modelString

Indicate whether connector is deployed on GKE/CloudRun Corresponds to the JSON property deploymentModel

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/connectors_v1/classes.rb', line 1270

def deployment_model
  @deployment_model
end

#hpa_configGoogle::Apis::ConnectorsV1::HpaConfig

Autoscaling config for connector deployment system metrics. Corresponds to the JSON property hpaConfig



1275
1276
1277
# File 'lib/google/apis/connectors_v1/classes.rb', line 1275

def hpa_config
  @hpa_config
end

#internalclient_ratelimit_thresholdFixnum

Max QPS supported for internal requests originating from Connd. Corresponds to the JSON property internalclientRatelimitThreshold

Returns:

  • (Fixnum)


1280
1281
1282
# File 'lib/google/apis/connectors_v1/classes.rb', line 1280

def internalclient_ratelimit_threshold
  @internalclient_ratelimit_threshold
end

#max_instance_request_concurrencyFixnum

Max Instance Request Conncurrency for Cloud Run service. Corresponds to the JSON property maxInstanceRequestConcurrency

Returns:

  • (Fixnum)


1285
1286
1287
# File 'lib/google/apis/connectors_v1/classes.rb', line 1285

def max_instance_request_concurrency
  @max_instance_request_concurrency
end

#migrate_deployment_modelBoolean Also known as: migrate_deployment_model?

Indicate whether connector is being migrated to cloud run deployment model. Corresponds to the JSON property migrateDeploymentModel

Returns:

  • (Boolean)


1290
1291
1292
# File 'lib/google/apis/connectors_v1/classes.rb', line 1290

def migrate_deployment_model
  @migrate_deployment_model
end

#migrate_tlsBoolean Also known as: migrate_tls?

Indicate whether connector is being migrated to TLS. Corresponds to the JSON property migrateTls

Returns:

  • (Boolean)


1296
1297
1298
# File 'lib/google/apis/connectors_v1/classes.rb', line 1296

def migrate_tls
  @migrate_tls
end

#network_egress_mode_overrideGoogle::Apis::ConnectorsV1::NetworkEgressModeOverride

NetworkEgressModeOverride provides the network egress mode override for a connector. Corresponds to the JSON property networkEgressModeOverride



1303
1304
1305
# File 'lib/google/apis/connectors_v1/classes.rb', line 1303

def network_egress_mode_override
  @network_egress_mode_override
end

#provision_cloud_spannerBoolean Also known as: provision_cloud_spanner?

Indicate whether cloud spanner is required for connector job. Corresponds to the JSON property provisionCloudSpanner

Returns:

  • (Boolean)


1308
1309
1310
# File 'lib/google/apis/connectors_v1/classes.rb', line 1308

def provision_cloud_spanner
  @provision_cloud_spanner
end

#provision_memstoreBoolean Also known as: provision_memstore?

Indicate whether memstore is required for connector job. Corresponds to the JSON property provisionMemstore

Returns:

  • (Boolean)


1314
1315
1316
# File 'lib/google/apis/connectors_v1/classes.rb', line 1314

def provision_memstore
  @provision_memstore
end

#public_network_ingress_enabledBoolean Also known as: public_network_ingress_enabled?

Indicate whether public network ingress should be enabled. Corresponds to the JSON property publicNetworkIngressEnabled

Returns:

  • (Boolean)


1320
1321
1322
# File 'lib/google/apis/connectors_v1/classes.rb', line 1320

def public_network_ingress_enabled
  @public_network_ingress_enabled
end

#ratelimit_thresholdFixnum

Max QPS supported by the connector version before throttling of requests. Corresponds to the JSON property ratelimitThreshold

Returns:

  • (Fixnum)


1326
1327
1328
# File 'lib/google/apis/connectors_v1/classes.rb', line 1326

def ratelimit_threshold
  @ratelimit_threshold
end

#resource_limitsGoogle::Apis::ConnectorsV1::ResourceLimits

Resource limits defined for connection pods of a given connector type. Corresponds to the JSON property resourceLimits



1331
1332
1333
# File 'lib/google/apis/connectors_v1/classes.rb', line 1331

def resource_limits
  @resource_limits
end

#resource_requestsGoogle::Apis::ConnectorsV1::ResourceRequests

Resource requests defined for connection pods of a given connector type. Corresponds to the JSON property resourceRequests



1336
1337
1338
# File 'lib/google/apis/connectors_v1/classes.rb', line 1336

def resource_requests
  @resource_requests
end

#shared_deploymentString

The name of shared connector deployment. Corresponds to the JSON property sharedDeployment

Returns:

  • (String)


1341
1342
1343
# File 'lib/google/apis/connectors_v1/classes.rb', line 1341

def shared_deployment
  @shared_deployment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
# File 'lib/google/apis/connectors_v1/classes.rb', line 1348

def update!(**args)
  @always_allocate_cpu = args[:always_allocate_cpu] if args.key?(:always_allocate_cpu)
  @connection_ratelimit_window_seconds = args[:connection_ratelimit_window_seconds] if args.key?(:connection_ratelimit_window_seconds)
  @connection_service_account_enabled = args[:connection_service_account_enabled] if args.key?(:connection_service_account_enabled)
  @connector_versioning_enabled = args[:connector_versioning_enabled] if args.key?(:connector_versioning_enabled)
  @deployment_model = args[:deployment_model] if args.key?(:deployment_model)
  @hpa_config = args[:hpa_config] if args.key?(:hpa_config)
  @internalclient_ratelimit_threshold = args[:internalclient_ratelimit_threshold] if args.key?(:internalclient_ratelimit_threshold)
  @max_instance_request_concurrency = args[:max_instance_request_concurrency] if args.key?(:max_instance_request_concurrency)
  @migrate_deployment_model = args[:migrate_deployment_model] if args.key?(:migrate_deployment_model)
  @migrate_tls = args[:migrate_tls] if args.key?(:migrate_tls)
  @network_egress_mode_override = args[:network_egress_mode_override] if args.key?(:network_egress_mode_override)
  @provision_cloud_spanner = args[:provision_cloud_spanner] if args.key?(:provision_cloud_spanner)
  @provision_memstore = args[:provision_memstore] if args.key?(:provision_memstore)
  @public_network_ingress_enabled = args[:public_network_ingress_enabled] if args.key?(:public_network_ingress_enabled)
  @ratelimit_threshold = args[:ratelimit_threshold] if args.key?(:ratelimit_threshold)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
  @resource_requests = args[:resource_requests] if args.key?(:resource_requests)
  @shared_deployment = args[:shared_deployment] if args.key?(:shared_deployment)
end