Class: Google::Apis::ConnectorsV1::ConnectorVersion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

ConnectorVersion indicates a specific version of a connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectorVersion

Returns a new instance of ConnectorVersion.



1514
1515
1516
# File 'lib/google/apis/connectors_v1/classes.rb', line 1514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_config_templatesArray<Google::Apis::ConnectorsV1::AuthConfigTemplate>

Output only. List of auth configs supported by the Connector Version. Corresponds to the JSON property authConfigTemplates



1377
1378
1379
# File 'lib/google/apis/connectors_v1/classes.rb', line 1377

def auth_config_templates
  @auth_config_templates
end

#auth_override_enabledBoolean Also known as: auth_override_enabled?

Output only. Flag to mark the dynamic auth override. Corresponds to the JSON property authOverrideEnabled

Returns:

  • (Boolean)


1382
1383
1384
# File 'lib/google/apis/connectors_v1/classes.rb', line 1382

def auth_override_enabled
  @auth_override_enabled
end

#config_variable_templatesArray<Google::Apis::ConnectorsV1::ConfigVariableTemplate>

Output only. List of config variables needed to create a connection. Corresponds to the JSON property configVariableTemplates



1388
1389
1390
# File 'lib/google/apis/connectors_v1/classes.rb', line 1388

def config_variable_templates
  @config_variable_templates
end

#connector_infra_configGoogle::Apis::ConnectorsV1::ConnectorInfraConfig

This cofiguration provides infra configs like rate limit threshold which need to be configurable for every connector version Corresponds to the JSON property connectorInfraConfig



1394
1395
1396
# File 'lib/google/apis/connectors_v1/classes.rb', line 1394

def connector_infra_config
  @connector_infra_config
end

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/connectors_v1/classes.rb', line 1399

def create_time
  @create_time
end

#destination_config_templatesArray<Google::Apis::ConnectorsV1::DestinationConfigTemplate>

Output only. List of destination configs needed to create a connection. Corresponds to the JSON property destinationConfigTemplates



1404
1405
1406
# File 'lib/google/apis/connectors_v1/classes.rb', line 1404

def destination_config_templates
  @destination_config_templates
end

#display_nameString

Output only. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1409
1410
1411
# File 'lib/google/apis/connectors_v1/classes.rb', line 1409

def display_name
  @display_name
end

#egress_control_configGoogle::Apis::ConnectorsV1::EgressControlConfig

Egress control config for connector runtime. These configurations define the rules to identify which outbound domains/hosts needs to be whitelisted. It may be a static information for a particular connector version or it is derived from the configurations provided by the customer in Connection resource. Corresponds to the JSON property egressControlConfig



1417
1418
1419
# File 'lib/google/apis/connectors_v1/classes.rb', line 1417

def egress_control_config
  @egress_control_config
end

#eventing_config_templateGoogle::Apis::ConnectorsV1::EventingConfigTemplate

Eventing Config details of a connector version. next: 14 Corresponds to the JSON property eventingConfigTemplate



1422
1423
1424
# File 'lib/google/apis/connectors_v1/classes.rb', line 1422

def eventing_config_template
  @eventing_config_template
end

#is_custom_actions_supportedBoolean Also known as: is_custom_actions_supported?

Output only. Is custom actions supported. Corresponds to the JSON property isCustomActionsSupported

Returns:

  • (Boolean)


1427
1428
1429
# File 'lib/google/apis/connectors_v1/classes.rb', line 1427

def is_custom_actions_supported
  @is_custom_actions_supported
end

#is_custom_entities_supportedBoolean Also known as: is_custom_entities_supported?

Output only. Is custom entities supported. Corresponds to the JSON property isCustomEntitiesSupported

Returns:

  • (Boolean)


1433
1434
1435
# File 'lib/google/apis/connectors_v1/classes.rb', line 1433

def is_custom_entities_supported
  @is_custom_entities_supported
end

#labelsHash<String,String>

Output only. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/ compute/docs/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1441
1442
1443
# File 'lib/google/apis/connectors_v1/classes.rb', line 1441

def labels
  @labels
end

#launch_stageString

Output only. Flag to mark the version indicating the launch stage. Corresponds to the JSON property launchStage

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/connectors_v1/classes.rb', line 1446

def launch_stage
  @launch_stage
end

#nameString

Output only. Resource name of the Version. Format: projects/project/ locations/location/providers/provider/connectors/connector/versions/ version Only global location is supported for Connector resource. Corresponds to the JSON property name

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/connectors_v1/classes.rb', line 1453

def name
  @name
end

#release_versionString

Output only. ReleaseVersion of the connector, for example: "1.0.1-alpha". Corresponds to the JSON property releaseVersion

Returns:

  • (String)


1458
1459
1460
# File 'lib/google/apis/connectors_v1/classes.rb', line 1458

def release_version
  @release_version
end

#role_grantGoogle::Apis::ConnectorsV1::RoleGrant

This configuration defines all the Cloud IAM roles that needs to be granted to a particular Google Cloud resource for the selected principal like service account. These configurations will let UI display to customers what IAM roles need to be granted by them. Or these configurations can be used by the UI to render a 'grant' button to do the same on behalf of the user. Corresponds to the JSON property roleGrant



1467
1468
1469
# File 'lib/google/apis/connectors_v1/classes.rb', line 1467

def role_grant
  @role_grant
end

#role_grantsArray<Google::Apis::ConnectorsV1::RoleGrant>

Output only. Role grant configurations for this connector version. Corresponds to the JSON property roleGrants



1472
1473
1474
# File 'lib/google/apis/connectors_v1/classes.rb', line 1472

def role_grants
  @role_grants
end

#schema_refresh_configGoogle::Apis::ConnectorsV1::SchemaRefreshConfig

Config for connection schema refresh Corresponds to the JSON property schemaRefreshConfig



1477
1478
1479
# File 'lib/google/apis/connectors_v1/classes.rb', line 1477

def schema_refresh_config
  @schema_refresh_config
end

#ssl_config_templateGoogle::Apis::ConnectorsV1::SslConfigTemplate

Ssl config details of a connector version Corresponds to the JSON property sslConfigTemplate



1482
1483
1484
# File 'lib/google/apis/connectors_v1/classes.rb', line 1482

def ssl_config_template
  @ssl_config_template
end

#supported_runtime_featuresGoogle::Apis::ConnectorsV1::SupportedRuntimeFeatures

Supported runtime features of a connector version. Corresponds to the JSON property supportedRuntimeFeatures



1487
1488
1489
# File 'lib/google/apis/connectors_v1/classes.rb', line 1487

def supported_runtime_features
  @supported_runtime_features
end

#supported_standard_actionsArray<Google::Apis::ConnectorsV1::StandardAction>

Output only. Supported standard actions. Corresponds to the JSON property supportedStandardActions



1492
1493
1494
# File 'lib/google/apis/connectors_v1/classes.rb', line 1492

def supported_standard_actions
  @supported_standard_actions
end

#supported_standard_entitiesArray<Google::Apis::ConnectorsV1::StandardEntity>

Output only. Supported standard entities. Corresponds to the JSON property supportedStandardEntities



1497
1498
1499
# File 'lib/google/apis/connectors_v1/classes.rb', line 1497

def supported_standard_entities
  @supported_standard_entities
end

#unsupported_connection_typesArray<String>

Output only. Unsupported connection types. Corresponds to the JSON property unsupportedConnectionTypes

Returns:

  • (Array<String>)


1502
1503
1504
# File 'lib/google/apis/connectors_v1/classes.rb', line 1502

def unsupported_connection_types
  @unsupported_connection_types
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1507
1508
1509
# File 'lib/google/apis/connectors_v1/classes.rb', line 1507

def update_time
  @update_time
end

#vpcsc_configGoogle::Apis::ConnectorsV1::VpcscConfig

This configuration provides VPCSC config for a connector. Corresponds to the JSON property vpcscConfig



1512
1513
1514
# File 'lib/google/apis/connectors_v1/classes.rb', line 1512

def vpcsc_config
  @vpcsc_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
# File 'lib/google/apis/connectors_v1/classes.rb', line 1519

def update!(**args)
  @auth_config_templates = args[:auth_config_templates] if args.key?(:auth_config_templates)
  @auth_override_enabled = args[:auth_override_enabled] if args.key?(:auth_override_enabled)
  @config_variable_templates = args[:config_variable_templates] if args.key?(:config_variable_templates)
  @connector_infra_config = args[:connector_infra_config] if args.key?(:connector_infra_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination_config_templates = args[:destination_config_templates] if args.key?(:destination_config_templates)
  @display_name = args[:display_name] if args.key?(:display_name)
  @egress_control_config = args[:egress_control_config] if args.key?(:egress_control_config)
  @eventing_config_template = args[:eventing_config_template] if args.key?(:eventing_config_template)
  @is_custom_actions_supported = args[:is_custom_actions_supported] if args.key?(:is_custom_actions_supported)
  @is_custom_entities_supported = args[:is_custom_entities_supported] if args.key?(:is_custom_entities_supported)
  @labels = args[:labels] if args.key?(:labels)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @release_version = args[:release_version] if args.key?(:release_version)
  @role_grant = args[:role_grant] if args.key?(:role_grant)
  @role_grants = args[:role_grants] if args.key?(:role_grants)
  @schema_refresh_config = args[:schema_refresh_config] if args.key?(:schema_refresh_config)
  @ssl_config_template = args[:ssl_config_template] if args.key?(:ssl_config_template)
  @supported_runtime_features = args[:supported_runtime_features] if args.key?(:supported_runtime_features)
  @supported_standard_actions = args[:supported_standard_actions] if args.key?(:supported_standard_actions)
  @supported_standard_entities = args[:supported_standard_entities] if args.key?(:supported_standard_entities)
  @unsupported_connection_types = args[:unsupported_connection_types] if args.key?(:unsupported_connection_types)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vpcsc_config = args[:vpcsc_config] if args.key?(:vpcsc_config)
end