Class: Google::Apis::ConnectorsV1::ConnectorVersionInfraConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

This configuration provides infra configs like rate limit threshold which need to be configurable for every connector version

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectorVersionInfraConfig

Returns a new instance of ConnectorVersionInfraConfig.



1609
1610
1611
# File 'lib/google/apis/connectors_v1/classes.rb', line 1609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_ratelimit_window_secondsFixnum

Output only. The window used for ratelimiting runtime requests to connections. Corresponds to the JSON property connectionRatelimitWindowSeconds

Returns:

  • (Fixnum)


1556
1557
1558
# File 'lib/google/apis/connectors_v1/classes.rb', line 1556

def connection_ratelimit_window_seconds
  @connection_ratelimit_window_seconds
end

#deployment_modelString

Output only. Indicates whether connector is deployed on GKE/CloudRun Corresponds to the JSON property deploymentModel

Returns:

  • (String)


1561
1562
1563
# File 'lib/google/apis/connectors_v1/classes.rb', line 1561

def deployment_model
  @deployment_model
end

#deployment_model_migration_stateString

Output only. Status of the deployment model migration. Corresponds to the JSON property deploymentModelMigrationState

Returns:

  • (String)


1566
1567
1568
# File 'lib/google/apis/connectors_v1/classes.rb', line 1566

def deployment_model_migration_state
  @deployment_model_migration_state
end

#hpa_configGoogle::Apis::ConnectorsV1::HpaConfig

Autoscaling config for connector deployment system metrics. Corresponds to the JSON property hpaConfig



1571
1572
1573
# File 'lib/google/apis/connectors_v1/classes.rb', line 1571

def hpa_config
  @hpa_config
end

#internalclient_ratelimit_thresholdFixnum

Output only. Max QPS supported for internal requests originating from Connd. Corresponds to the JSON property internalclientRatelimitThreshold

Returns:

  • (Fixnum)


1576
1577
1578
# File 'lib/google/apis/connectors_v1/classes.rb', line 1576

def internalclient_ratelimit_threshold
  @internalclient_ratelimit_threshold
end

#max_instance_request_concurrencyFixnum

Output only. Max instance request concurrency. Corresponds to the JSON property maxInstanceRequestConcurrency

Returns:

  • (Fixnum)


1581
1582
1583
# File 'lib/google/apis/connectors_v1/classes.rb', line 1581

def max_instance_request_concurrency
  @max_instance_request_concurrency
end

#ratelimit_thresholdFixnum

Output only. Max QPS supported by the connector version before throttling of requests. Corresponds to the JSON property ratelimitThreshold

Returns:

  • (Fixnum)


1587
1588
1589
# File 'lib/google/apis/connectors_v1/classes.rb', line 1587

def ratelimit_threshold
  @ratelimit_threshold
end

#resource_limitsGoogle::Apis::ConnectorsV1::ResourceLimits

Resource limits defined for connection pods of a given connector type. Corresponds to the JSON property resourceLimits



1592
1593
1594
# File 'lib/google/apis/connectors_v1/classes.rb', line 1592

def resource_limits
  @resource_limits
end

#resource_requestsGoogle::Apis::ConnectorsV1::ResourceRequests

Resource requests defined for connection pods of a given connector type. Corresponds to the JSON property resourceRequests



1597
1598
1599
# File 'lib/google/apis/connectors_v1/classes.rb', line 1597

def resource_requests
  @resource_requests
end

#shared_deploymentString

Output only. The name of shared connector deployment. Corresponds to the JSON property sharedDeployment

Returns:

  • (String)


1602
1603
1604
# File 'lib/google/apis/connectors_v1/classes.rb', line 1602

def shared_deployment
  @shared_deployment
end

#tls_migration_stateString

Output only. Status of the TLS migration. Corresponds to the JSON property tlsMigrationState

Returns:

  • (String)


1607
1608
1609
# File 'lib/google/apis/connectors_v1/classes.rb', line 1607

def tls_migration_state
  @tls_migration_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/google/apis/connectors_v1/classes.rb', line 1614

def update!(**args)
  @connection_ratelimit_window_seconds = args[:connection_ratelimit_window_seconds] if args.key?(:connection_ratelimit_window_seconds)
  @deployment_model = args[:deployment_model] if args.key?(:deployment_model)
  @deployment_model_migration_state = args[:deployment_model_migration_state] if args.key?(:deployment_model_migration_state)
  @hpa_config = args[:hpa_config] if args.key?(:hpa_config)
  @internalclient_ratelimit_threshold = args[:internalclient_ratelimit_threshold] if args.key?(:internalclient_ratelimit_threshold)
  @max_instance_request_concurrency = args[:max_instance_request_concurrency] if args.key?(:max_instance_request_concurrency)
  @ratelimit_threshold = args[:ratelimit_threshold] if args.key?(:ratelimit_threshold)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
  @resource_requests = args[:resource_requests] if args.key?(:resource_requests)
  @shared_deployment = args[:shared_deployment] if args.key?(:shared_deployment)
  @tls_migration_state = args[:tls_migration_state] if args.key?(:tls_migration_state)
end