Class: Google::Apis::ConnectorsV1::CustomConnector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

CustomConnector represents the custom connector defined by the customer as part of byoc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomConnector

Returns a new instance of CustomConnector.



1724
1725
1726
# File 'lib/google/apis/connectors_v1/classes.rb', line 1724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_connector_versionsArray<String>

Output only. Active connector versions. Corresponds to the JSON property activeConnectorVersions

Returns:

  • (Array<String>)


1664
1665
1666
# File 'lib/google/apis/connectors_v1/classes.rb', line 1664

def active_connector_versions
  @active_connector_versions
end

#all_connector_versionsArray<String>

Output only. All connector versions. Corresponds to the JSON property allConnectorVersions

Returns:

  • (Array<String>)


1669
1670
1671
# File 'lib/google/apis/connectors_v1/classes.rb', line 1669

def all_connector_versions
  @all_connector_versions
end

#all_marketplace_versionsArray<String>

Output only. All marketplace versions. Corresponds to the JSON property allMarketplaceVersions

Returns:

  • (Array<String>)


1674
1675
1676
# File 'lib/google/apis/connectors_v1/classes.rb', line 1674

def all_marketplace_versions
  @all_marketplace_versions
end

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


1679
1680
1681
# File 'lib/google/apis/connectors_v1/classes.rb', line 1679

def create_time
  @create_time
end

#custom_connector_typeString

Required. Type of the custom connector. Corresponds to the JSON property customConnectorType

Returns:

  • (String)


1684
1685
1686
# File 'lib/google/apis/connectors_v1/classes.rb', line 1684

def custom_connector_type
  @custom_connector_type
end

#descriptionString

Optional. Description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


1689
1690
1691
# File 'lib/google/apis/connectors_v1/classes.rb', line 1689

def description
  @description
end

#display_nameString

Optional. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1694
1695
1696
# File 'lib/google/apis/connectors_v1/classes.rb', line 1694

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/ docs/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1701
1702
1703
# File 'lib/google/apis/connectors_v1/classes.rb', line 1701

def labels
  @labels
end

#logoString

Optional. Logo of the resource. Corresponds to the JSON property logo

Returns:

  • (String)


1706
1707
1708
# File 'lib/google/apis/connectors_v1/classes.rb', line 1706

def 
  @logo
end

#nameString

Identifier. Resource name of the CustomConnector. Format: projects/project/ locations/location/customConnectors/connector Corresponds to the JSON property name

Returns:

  • (String)


1712
1713
1714
# File 'lib/google/apis/connectors_v1/classes.rb', line 1712

def name
  @name
end

#published_marketplace_versionsArray<String>

Output only. Published marketplace versions. Corresponds to the JSON property publishedMarketplaceVersions

Returns:

  • (Array<String>)


1717
1718
1719
# File 'lib/google/apis/connectors_v1/classes.rb', line 1717

def published_marketplace_versions
  @published_marketplace_versions
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1722
1723
1724
# File 'lib/google/apis/connectors_v1/classes.rb', line 1722

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
# File 'lib/google/apis/connectors_v1/classes.rb', line 1729

def update!(**args)
  @active_connector_versions = args[:active_connector_versions] if args.key?(:active_connector_versions)
  @all_connector_versions = args[:all_connector_versions] if args.key?(:all_connector_versions)
  @all_marketplace_versions = args[:all_marketplace_versions] if args.key?(:all_marketplace_versions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_connector_type = args[:custom_connector_type] if args.key?(:custom_connector_type)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @logo = args[:logo] if args.key?(:logo)
  @name = args[:name] if args.key?(:name)
  @published_marketplace_versions = args[:published_marketplace_versions] if args.key?(:published_marketplace_versions)
  @update_time = args[:update_time] if args.key?(:update_time)
end