Class: Google::Apis::ConnectorsV1::DailyCycle

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Time window specified for daily operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyCycle

Returns a new instance of DailyCycle.



1897
1898
1899
# File 'lib/google/apis/connectors_v1/classes.rb', line 1897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. Duration of the time window, set by service producer. Corresponds to the JSON property duration

Returns:

  • (String)


1888
1889
1890
# File 'lib/google/apis/connectors_v1/classes.rb', line 1888

def duration
  @duration
end

#start_timeGoogle::Apis::ConnectorsV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



1895
1896
1897
# File 'lib/google/apis/connectors_v1/classes.rb', line 1895

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1902
1903
1904
1905
# File 'lib/google/apis/connectors_v1/classes.rb', line 1902

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end