Class: Google::Apis::ConnectorsV1::DestinationConfigTemplate
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::DestinationConfigTemplate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
DestinationConfigTemplate defines required destinations supported by the Connector.
Instance Attribute Summary collapse
-
#autocomplete_suggestions ⇒ Array<String>
Autocomplete suggestions for destination URL field.
-
#default_port ⇒ Fixnum
The default port.
-
#description ⇒ String
Description.
-
#display_name ⇒ String
Display name of the parameter.
-
#is_advanced ⇒ Boolean
(also: #is_advanced?)
Whether the current destination tempalate is part of Advanced settings Corresponds to the JSON property
isAdvanced. -
#key ⇒ String
Key of the destination.
-
#max ⇒ Fixnum
The maximum number of destinations supported for this key.
-
#min ⇒ Fixnum
The minimum number of destinations supported for this key.
-
#port_field_type ⇒ String
Whether port number should be provided by customers.
-
#regex_pattern ⇒ String
Regex pattern for host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DestinationConfigTemplate
constructor
A new instance of DestinationConfigTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DestinationConfigTemplate
Returns a new instance of DestinationConfigTemplate.
2095 2096 2097 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2095 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autocomplete_suggestions ⇒ Array<String>
Autocomplete suggestions for destination URL field.
Corresponds to the JSON property autocompleteSuggestions
2047 2048 2049 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2047 def autocomplete_suggestions @autocomplete_suggestions end |
#default_port ⇒ Fixnum
The default port.
Corresponds to the JSON property defaultPort
2052 2053 2054 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2052 def default_port @default_port end |
#description ⇒ String
Description.
Corresponds to the JSON property description
2057 2058 2059 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2057 def description @description end |
#display_name ⇒ String
Display name of the parameter.
Corresponds to the JSON property displayName
2062 2063 2064 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2062 def display_name @display_name end |
#is_advanced ⇒ Boolean Also known as: is_advanced?
Whether the current destination tempalate is part of Advanced settings
Corresponds to the JSON property isAdvanced
2067 2068 2069 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2067 def is_advanced @is_advanced end |
#key ⇒ String
Key of the destination.
Corresponds to the JSON property key
2073 2074 2075 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2073 def key @key end |
#max ⇒ Fixnum
The maximum number of destinations supported for this key.
Corresponds to the JSON property max
2078 2079 2080 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2078 def max @max end |
#min ⇒ Fixnum
The minimum number of destinations supported for this key.
Corresponds to the JSON property min
2083 2084 2085 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2083 def min @min end |
#port_field_type ⇒ String
Whether port number should be provided by customers.
Corresponds to the JSON property portFieldType
2088 2089 2090 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2088 def port_field_type @port_field_type end |
#regex_pattern ⇒ String
Regex pattern for host.
Corresponds to the JSON property regexPattern
2093 2094 2095 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2093 def regex_pattern @regex_pattern end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2100 def update!(**args) @autocomplete_suggestions = args[:autocomplete_suggestions] if args.key?(:autocomplete_suggestions) @default_port = args[:default_port] if args.key?(:default_port) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @is_advanced = args[:is_advanced] if args.key?(:is_advanced) @key = args[:key] if args.key?(:key) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @port_field_type = args[:port_field_type] if args.key?(:port_field_type) @regex_pattern = args[:regex_pattern] if args.key?(:regex_pattern) end |