Class: Google::Apis::ConnectorsV1::EndUserAuthentication

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

AuthConfig defines details of a authentication type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthentication

Returns a new instance of EndUserAuthentication.



2408
2409
2410
# File 'lib/google/apis/connectors_v1/classes.rb', line 2408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_variablesArray<Google::Apis::ConnectorsV1::EndUserAuthenticationConfigVariable>

Optional. Config variables for the EndUserAuthentication. Corresponds to the JSON property configVariables



2351
2352
2353
# File 'lib/google/apis/connectors_v1/classes.rb', line 2351

def config_variables
  @config_variables
end

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


2356
2357
2358
# File 'lib/google/apis/connectors_v1/classes.rb', line 2356

def create_time
  @create_time
end

#destination_configsArray<Google::Apis::ConnectorsV1::DestinationConfig>

Optional. Destination configs for the EndUserAuthentication. Corresponds to the JSON property destinationConfigs



2361
2362
2363
# File 'lib/google/apis/connectors_v1/classes.rb', line 2361

def destination_configs
  @destination_configs
end

#end_user_authentication_configGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfig

EndUserAuthenticationConfig defines details of a authentication configuration for EUC Corresponds to the JSON property endUserAuthenticationConfig



2367
2368
2369
# File 'lib/google/apis/connectors_v1/classes.rb', line 2367

def end_user_authentication_config
  @end_user_authentication_config
end

#labelsArray<String>

Optional. Labels for the EndUserAuthentication. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


2372
2373
2374
# File 'lib/google/apis/connectors_v1/classes.rb', line 2372

def labels
  @labels
end

#nameString

Required. Identifier. Resource name of the EndUserAuthentication. Format: projects/project/locations/location/connections/connection/ endUserAuthentications/end_user_authentication Corresponds to the JSON property name

Returns:

  • (String)


2379
2380
2381
# File 'lib/google/apis/connectors_v1/classes.rb', line 2379

def name
  @name
end

#notify_endpoint_destinationGoogle::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination

Message for NotifyEndpointDestination Destination to hit when the refresh token is expired. Corresponds to the JSON property notifyEndpointDestination



2385
2386
2387
# File 'lib/google/apis/connectors_v1/classes.rb', line 2385

def notify_endpoint_destination
  @notify_endpoint_destination
end

#rolesArray<String>

Optional. Roles for the EndUserAuthentication. Corresponds to the JSON property roles

Returns:

  • (Array<String>)


2390
2391
2392
# File 'lib/google/apis/connectors_v1/classes.rb', line 2390

def roles
  @roles
end

#statusGoogle::Apis::ConnectorsV1::EndUserAuthenticationEndUserAuthenticationStatus

EndUserAuthentication Status denotes the status of the EndUserAuthentication resource. Corresponds to the JSON property status



2396
2397
2398
# File 'lib/google/apis/connectors_v1/classes.rb', line 2396

def status
  @status
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2401
2402
2403
# File 'lib/google/apis/connectors_v1/classes.rb', line 2401

def update_time
  @update_time
end

#user_idString

Optional. The user id of the user. Corresponds to the JSON property userId

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/connectors_v1/classes.rb', line 2406

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
# File 'lib/google/apis/connectors_v1/classes.rb', line 2413

def update!(**args)
  @config_variables = args[:config_variables] if args.key?(:config_variables)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination_configs = args[:destination_configs] if args.key?(:destination_configs)
  @end_user_authentication_config = args[:end_user_authentication_config] if args.key?(:end_user_authentication_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notify_endpoint_destination = args[:notify_endpoint_destination] if args.key?(:notify_endpoint_destination)
  @roles = args[:roles] if args.key?(:roles)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end