Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

EndUserAuthenticationConfig defines details of a authentication configuration for EUC

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthenticationConfig

Returns a new instance of EndUserAuthenticationConfig.



2484
2485
2486
# File 'lib/google/apis/connectors_v1/classes.rb', line 2484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_variablesArray<Google::Apis::ConnectorsV1::EndUserAuthenticationConfigVariable>

Optional. List containing additional auth configs. Corresponds to the JSON property additionalVariables



2436
2437
2438
# File 'lib/google/apis/connectors_v1/classes.rb', line 2436

def additional_variables
  @additional_variables
end

#auth_keyString

Identifier key for auth config Corresponds to the JSON property authKey

Returns:

  • (String)


2441
2442
2443
# File 'lib/google/apis/connectors_v1/classes.rb', line 2441

def auth_key
  @auth_key
end

#auth_typeString

The type of authentication configured. Corresponds to the JSON property authType

Returns:

  • (String)


2446
2447
2448
# File 'lib/google/apis/connectors_v1/classes.rb', line 2446

def auth_type
  @auth_type
end

#oauth2_auth_code_flowGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlow

Parameters to support Oauth 2.0 Auth Code Grant Authentication. See https:// www.rfc-editor.org/rfc/rfc6749#section-1.3.1 for more details. Corresponds to the JSON property oauth2AuthCodeFlow



2452
2453
2454
# File 'lib/google/apis/connectors_v1/classes.rb', line 2452

def oauth2_auth_code_flow
  @oauth2_auth_code_flow
end

#oauth2_auth_code_flow_google_managedGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged

Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client. See https://tools.ietf.org/html/rfc6749#section-1.3.1 for more details. Corresponds to the JSON property oauth2AuthCodeFlowGoogleManaged



2459
2460
2461
# File 'lib/google/apis/connectors_v1/classes.rb', line 2459

def oauth2_auth_code_flow_google_managed
  @oauth2_auth_code_flow_google_managed
end

#oauth2_client_credentialsGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2ClientCredentials

Parameters to support Oauth 2.0 Client Credentials Grant Authentication. See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details. Corresponds to the JSON property oauth2ClientCredentials



2465
2466
2467
# File 'lib/google/apis/connectors_v1/classes.rb', line 2465

def oauth2_client_credentials
  @oauth2_client_credentials
end

#oauth2_jwt_bearerGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2JwtBearer

Parameters to support JSON Web Token (JWT) Profile for Oauth 2.0 Authorization Grant based authentication. See https://tools.ietf.org/html/rfc7523 for more details. Corresponds to the JSON property oauth2JwtBearer



2472
2473
2474
# File 'lib/google/apis/connectors_v1/classes.rb', line 2472

def oauth2_jwt_bearer
  @oauth2_jwt_bearer
end

#ssh_public_keyGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfigSshPublicKey

Parameters to support Ssh public key Authentication. Corresponds to the JSON property sshPublicKey



2477
2478
2479
# File 'lib/google/apis/connectors_v1/classes.rb', line 2477

def ssh_public_key
  @ssh_public_key
end

#user_passwordGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfigUserPassword

Parameters to support Username and Password Authentication. Corresponds to the JSON property userPassword



2482
2483
2484
# File 'lib/google/apis/connectors_v1/classes.rb', line 2482

def user_password
  @user_password
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
# File 'lib/google/apis/connectors_v1/classes.rb', line 2489

def update!(**args)
  @additional_variables = args[:additional_variables] if args.key?(:additional_variables)
  @auth_key = args[:auth_key] if args.key?(:auth_key)
  @auth_type = args[:auth_type] if args.key?(:auth_type)
  @oauth2_auth_code_flow = args[:oauth2_auth_code_flow] if args.key?(:oauth2_auth_code_flow)
  @oauth2_auth_code_flow_google_managed = args[:oauth2_auth_code_flow_google_managed] if args.key?(:oauth2_auth_code_flow_google_managed)
  @oauth2_client_credentials = args[:oauth2_client_credentials] if args.key?(:oauth2_client_credentials)
  @oauth2_jwt_bearer = args[:oauth2_jwt_bearer] if args.key?(:oauth2_jwt_bearer)
  @ssh_public_key = args[:ssh_public_key] if args.key?(:ssh_public_key)
  @user_password = args[:user_password] if args.key?(:user_password)
end