Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Parameters to support Oauth 2.0 Auth Code Grant Authentication. See https:// www.rfc-editor.org/rfc/rfc6749#section-1.3.1 for more details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthenticationConfigOauth2AuthCodeFlow

Returns a new instance of EndUserAuthenticationConfigOauth2AuthCodeFlow.



2500
2501
2502
# File 'lib/google/apis/connectors_v1/classes.rb', line 2500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_codeString

Optional. Authorization code to be exchanged for access and refresh tokens. Corresponds to the JSON property authCode

Returns:

  • (String)


2456
2457
2458
# File 'lib/google/apis/connectors_v1/classes.rb', line 2456

def auth_code
  @auth_code
end

#auth_uriString

Optional. Auth URL for Authorization Code Flow Corresponds to the JSON property authUri

Returns:

  • (String)


2461
2462
2463
# File 'lib/google/apis/connectors_v1/classes.rb', line 2461

def auth_uri
  @auth_uri
end

#client_idString

Optional. Client ID for user-provided OAuth app. Corresponds to the JSON property clientId

Returns:

  • (String)


2466
2467
2468
# File 'lib/google/apis/connectors_v1/classes.rb', line 2466

def client_id
  @client_id
end

#client_secretGoogle::Apis::ConnectorsV1::EuaSecret

EUASecret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientSecret



2471
2472
2473
# File 'lib/google/apis/connectors_v1/classes.rb', line 2471

def client_secret
  @client_secret
end

#enable_pkceBoolean Also known as: enable_pkce?

Optional. Whether to enable PKCE when the user performs the auth code flow. Corresponds to the JSON property enablePkce

Returns:

  • (Boolean)


2476
2477
2478
# File 'lib/google/apis/connectors_v1/classes.rb', line 2476

def enable_pkce
  @enable_pkce
end

#oauth_token_dataGoogle::Apis::ConnectorsV1::OAuthTokenData

pass only at create and not update using updateMask Auth Code Data Corresponds to the JSON property oauthTokenData



2482
2483
2484
# File 'lib/google/apis/connectors_v1/classes.rb', line 2482

def oauth_token_data
  @oauth_token_data
end

#pkce_verifierString

Optional. PKCE verifier to be used during the auth code exchange. Corresponds to the JSON property pkceVerifier

Returns:

  • (String)


2487
2488
2489
# File 'lib/google/apis/connectors_v1/classes.rb', line 2487

def pkce_verifier
  @pkce_verifier
end

#redirect_uriString

Optional. Redirect URI to be provided during the auth code exchange. Corresponds to the JSON property redirectUri

Returns:

  • (String)


2492
2493
2494
# File 'lib/google/apis/connectors_v1/classes.rb', line 2492

def redirect_uri
  @redirect_uri
end

#scopesArray<String>

Optional. Scopes the connection will request when the user performs the auth code flow. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


2498
2499
2500
# File 'lib/google/apis/connectors_v1/classes.rb', line 2498

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2505
2506
2507
2508
2509
2510
2511
2512
2513
2514
2515
# File 'lib/google/apis/connectors_v1/classes.rb', line 2505

def update!(**args)
  @auth_code = args[:auth_code] if args.key?(:auth_code)
  @auth_uri = args[:auth_uri] if args.key?(:auth_uri)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @enable_pkce = args[:enable_pkce] if args.key?(:enable_pkce)
  @oauth_token_data = args[:oauth_token_data] if args.key?(:oauth_token_data)
  @pkce_verifier = args[:pkce_verifier] if args.key?(:pkce_verifier)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @scopes = args[:scopes] if args.key?(:scopes)
end