Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client. See https://tools.ietf.org/html/rfc6749#section-1.3.1 for more details.
Instance Attribute Summary collapse
-
#auth_code ⇒ String
Optional.
-
#oauth_token_data ⇒ Google::Apis::ConnectorsV1::OAuthTokenData
pass only at create and not update using updateMask Auth Code Data Corresponds to the JSON property
oauthTokenData. -
#redirect_uri ⇒ String
Optional.
-
#scopes ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged
constructor
A new instance of EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged
Returns a new instance of EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged.
2599 2600 2601 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_code ⇒ String
Optional. Authorization code to be exchanged for access and refresh tokens.
Corresponds to the JSON property authCode
2581 2582 2583 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2581 def auth_code @auth_code end |
#oauth_token_data ⇒ Google::Apis::ConnectorsV1::OAuthTokenData
pass only at create and not update using updateMask Auth Code Data
Corresponds to the JSON property oauthTokenData
2586 2587 2588 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2586 def oauth_token_data @oauth_token_data end |
#redirect_uri ⇒ String
Optional. Redirect URI to be provided during the auth code exchange.
Corresponds to the JSON property redirectUri
2591 2592 2593 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2591 def redirect_uri @redirect_uri end |
#scopes ⇒ Array<String>
Required. Scopes the connection will request when the user performs the auth
code flow.
Corresponds to the JSON property scopes
2597 2598 2599 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2597 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2604 2605 2606 2607 2608 2609 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2604 def update!(**args) @auth_code = args[:auth_code] if args.key?(:auth_code) @oauth_token_data = args[:oauth_token_data] if args.key?(:oauth_token_data) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @scopes = args[:scopes] if args.key?(:scopes) end |