Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfigSshPublicKey
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EndUserAuthenticationConfigSshPublicKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Parameters to support Ssh public key Authentication.
Instance Attribute Summary collapse
-
#cert_type ⇒ String
Format of SSH Client cert.
-
#ssh_client_cert ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
-
#ssh_client_cert_pass ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
-
#username ⇒ String
The user account used to authenticate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndUserAuthenticationConfigSshPublicKey
constructor
A new instance of EndUserAuthenticationConfigSshPublicKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndUserAuthenticationConfigSshPublicKey
Returns a new instance of EndUserAuthenticationConfigSshPublicKey.
2666 2667 2668 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert_type ⇒ String
Format of SSH Client cert.
Corresponds to the JSON property certType
2649 2650 2651 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2649 def cert_type @cert_type end |
#ssh_client_cert ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
Corresponds to the JSON property sshClientCert
2654 2655 2656 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2654 def ssh_client_cert @ssh_client_cert end |
#ssh_client_cert_pass ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
Corresponds to the JSON property sshClientCertPass
2659 2660 2661 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2659 def ssh_client_cert_pass @ssh_client_cert_pass end |
#username ⇒ String
The user account used to authenticate.
Corresponds to the JSON property username
2664 2665 2666 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2664 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2671 2672 2673 2674 2675 2676 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2671 def update!(**args) @cert_type = args[:cert_type] if args.key?(:cert_type) @ssh_client_cert = args[:ssh_client_cert] if args.key?(:ssh_client_cert) @ssh_client_cert_pass = args[:ssh_client_cert_pass] if args.key?(:ssh_client_cert_pass) @username = args[:username] if args.key?(:username) end |