Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfigUserPassword
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EndUserAuthenticationConfigUserPassword
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Parameters to support Username and Password Authentication.
Instance Attribute Summary collapse
-
#password ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
-
#username ⇒ String
Username.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndUserAuthenticationConfigUserPassword
constructor
A new instance of EndUserAuthenticationConfigUserPassword.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndUserAuthenticationConfigUserPassword
Returns a new instance of EndUserAuthenticationConfigUserPassword.
2693 2694 2695 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
Corresponds to the JSON property password
2686 2687 2688 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2686 def password @password end |
#username ⇒ String
Username.
Corresponds to the JSON property username
2691 2692 2693 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2691 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2698 2699 2700 2701 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2698 def update!(**args) @password = args[:password] if args.key?(:password) @username = args[:username] if args.key?(:username) end |