Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfigVariable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

EndUserAuthenticationConfigVariable represents a configuration variable present in a EndUserAuthentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthenticationConfigVariable

Returns a new instance of EndUserAuthenticationConfigVariable.



2789
2790
2791
# File 'lib/google/apis/connectors_v1/classes.rb', line 2789

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Value is a bool. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


2766
2767
2768
# File 'lib/google/apis/connectors_v1/classes.rb', line 2766

def bool_value
  @bool_value
end

#int_valueFixnum

Value is an integer Corresponds to the JSON property intValue

Returns:

  • (Fixnum)


2772
2773
2774
# File 'lib/google/apis/connectors_v1/classes.rb', line 2772

def int_value
  @int_value
end

#keyString

Required. Key of the config variable. Corresponds to the JSON property key

Returns:

  • (String)


2777
2778
2779
# File 'lib/google/apis/connectors_v1/classes.rb', line 2777

def key
  @key
end

#secret_valueGoogle::Apis::ConnectorsV1::EuaSecret

EUASecret provides a reference to entries in Secret Manager. Corresponds to the JSON property secretValue



2782
2783
2784
# File 'lib/google/apis/connectors_v1/classes.rb', line 2782

def secret_value
  @secret_value
end

#string_valueString

Value is a string. Corresponds to the JSON property stringValue

Returns:

  • (String)


2787
2788
2789
# File 'lib/google/apis/connectors_v1/classes.rb', line 2787

def string_value
  @string_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2794
2795
2796
2797
2798
2799
2800
# File 'lib/google/apis/connectors_v1/classes.rb', line 2794

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @int_value = args[:int_value] if args.key?(:int_value)
  @key = args[:key] if args.key?(:key)
  @secret_value = args[:secret_value] if args.key?(:secret_value)
  @string_value = args[:string_value] if args.key?(:string_value)
end