Class: Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Message for NotifyEndpointDestination Destination to hit when the refresh token is expired.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthenticationNotifyEndpointDestination

Returns a new instance of EndUserAuthenticationNotifyEndpointDestination.



2849
2850
2851
# File 'lib/google/apis/connectors_v1/classes.rb', line 2849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointGoogle::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestinationEndPoint

Endpoint message includes details of the Destination endpoint. Corresponds to the JSON property endpoint



2837
2838
2839
# File 'lib/google/apis/connectors_v1/classes.rb', line 2837

def endpoint
  @endpoint
end

#service_accountString

Required. Service account needed for runtime plane to notify the backend. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2842
2843
2844
# File 'lib/google/apis/connectors_v1/classes.rb', line 2842

def 
  @service_account
end

#typeString

Required. type of the destination Corresponds to the JSON property type

Returns:

  • (String)


2847
2848
2849
# File 'lib/google/apis/connectors_v1/classes.rb', line 2847

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2854
2855
2856
2857
2858
# File 'lib/google/apis/connectors_v1/classes.rb', line 2854

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @service_account = args[:service_account] if args.key?(:service_account)
  @type = args[:type] if args.key?(:type)
end