Class: Google::Apis::ConnectorsV1::EuaSecret

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

EUASecret provides a reference to entries in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EuaSecret

Returns a new instance of EuaSecret.



2129
2130
2131
# File 'lib/google/apis/connectors_v1/classes.rb', line 2129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secret_valueString

Optional. The plain string value of the secret. Corresponds to the JSON property secretValue

Returns:

  • (String)


2121
2122
2123
# File 'lib/google/apis/connectors_v1/classes.rb', line 2121

def secret_value
  @secret_value
end

#secret_versionString

Optional. The resource name of the secret version in the format, format as: projects/*/secrets/*/versions/*. Corresponds to the JSON property secretVersion

Returns:

  • (String)


2127
2128
2129
# File 'lib/google/apis/connectors_v1/classes.rb', line 2127

def secret_version
  @secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2134
2135
2136
2137
# File 'lib/google/apis/connectors_v1/classes.rb', line 2134

def update!(**args)
  @secret_value = args[:secret_value] if args.key?(:secret_value)
  @secret_version = args[:secret_version] if args.key?(:secret_version)
end