Class: Google::Apis::ConnectorsV1::EventSubscription

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

represents the Connector's EventSubscription resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventSubscription

Returns a new instance of EventSubscription.



3092
3093
3094
# File 'lib/google/apis/connectors_v1/classes.rb', line 3092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


3037
3038
3039
# File 'lib/google/apis/connectors_v1/classes.rb', line 3037

def create_time
  @create_time
end

#destinationsGoogle::Apis::ConnectorsV1::EventSubscriptionDestination

Message for EventSubscription Destination to act on receiving an event Corresponds to the JSON property destinations



3042
3043
3044
# File 'lib/google/apis/connectors_v1/classes.rb', line 3042

def destinations
  @destinations
end

#event_type_idString

Optional. Event type id of the event of current EventSubscription. Corresponds to the JSON property eventTypeId

Returns:

  • (String)


3047
3048
3049
# File 'lib/google/apis/connectors_v1/classes.rb', line 3047

def event_type_id
  @event_type_id
end

#filterString

Optional. Filter for the event subscription. Incoming events are filtered based on the filter expression. Corresponds to the JSON property filter

Returns:

  • (String)


3053
3054
3055
# File 'lib/google/apis/connectors_v1/classes.rb', line 3053

def filter
  @filter
end

#jmsGoogle::Apis::ConnectorsV1::Jms

JMS message denotes the source of the event Corresponds to the JSON property jms



3058
3059
3060
# File 'lib/google/apis/connectors_v1/classes.rb', line 3058

def jms
  @jms
end

#nameString

Required. Identifier. Resource name of the EventSubscription. Format: projects/ project/locations/location/connections/connection/eventSubscriptions/ event_subscription Corresponds to the JSON property name

Returns:

  • (String)


3065
3066
3067
# File 'lib/google/apis/connectors_v1/classes.rb', line 3065

def name
  @name
end

#statusGoogle::Apis::ConnectorsV1::EventSubscriptionStatus

EventSubscription Status denotes the status of the EventSubscription resource. Corresponds to the JSON property status



3070
3071
3072
# File 'lib/google/apis/connectors_v1/classes.rb', line 3070

def status
  @status
end

#subscriberString

Optional. name of the Subscriber for the current EventSubscription. Corresponds to the JSON property subscriber

Returns:

  • (String)


3075
3076
3077
# File 'lib/google/apis/connectors_v1/classes.rb', line 3075

def subscriber
  @subscriber
end

Optional. Link for Subscriber of the current EventSubscription. Corresponds to the JSON property subscriberLink

Returns:

  • (String)


3080
3081
3082
# File 'lib/google/apis/connectors_v1/classes.rb', line 3080

def subscriber_link
  @subscriber_link
end

#trigger_config_variablesArray<Google::Apis::ConnectorsV1::ConfigVariable>

Optional. Configuration for configuring the trigger Corresponds to the JSON property triggerConfigVariables



3085
3086
3087
# File 'lib/google/apis/connectors_v1/classes.rb', line 3085

def trigger_config_variables
  @trigger_config_variables
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


3090
3091
3092
# File 'lib/google/apis/connectors_v1/classes.rb', line 3090

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
# File 'lib/google/apis/connectors_v1/classes.rb', line 3097

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destinations = args[:destinations] if args.key?(:destinations)
  @event_type_id = args[:event_type_id] if args.key?(:event_type_id)
  @filter = args[:filter] if args.key?(:filter)
  @jms = args[:jms] if args.key?(:jms)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @subscriber = args[:subscriber] if args.key?(:subscriber)
  @subscriber_link = args[:subscriber_link] if args.key?(:subscriber_link)
  @trigger_config_variables = args[:trigger_config_variables] if args.key?(:trigger_config_variables)
  @update_time = args[:update_time] if args.key?(:update_time)
end