Class: Google::Apis::ConnectorsV1::EventingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EventingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Eventing Configuration of a connection next: 21
Instance Attribute Summary collapse
-
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional.
-
#allowed_event_types ⇒ Array<String>
Optional.
-
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
-
#dead_letter_config ⇒ Google::Apis::ConnectorsV1::DeadLetterConfig
Dead Letter configuration details provided by the user.
-
#enrichment_config ⇒ Google::Apis::ConnectorsV1::EnrichmentConfig
Data enrichment configuration.
-
#enrichment_enabled ⇒ Boolean
(also: #enrichment_enabled?)
Optional.
-
#events_listener_ingress_endpoint ⇒ String
Output only.
-
#global_event_filter ⇒ String
Optional.
-
#listener_auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
-
#private_connectivity_allowlisted_projects ⇒ Array<String>
Optional.
-
#private_connectivity_enabled ⇒ Boolean
(also: #private_connectivity_enabled?)
Optional.
-
#proxy_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
-
#registration_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
-
#ssl_config ⇒ Google::Apis::ConnectorsV1::SslConfig
SSL Configuration of a connection Corresponds to the JSON property
sslConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventingConfig
constructor
A new instance of EventingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventingConfig
Returns a new instance of EventingConfig.
3318 3319 3320 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional. Additional eventing related field values
Corresponds to the JSON property additionalVariables
3247 3248 3249 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3247 def additional_variables @additional_variables end |
#allowed_event_types ⇒ Array<String>
Optional. List of allowed event types for the connection.
Corresponds to the JSON property allowedEventTypes
3252 3253 3254 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3252 def allowed_event_types @allowed_event_types end |
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
Corresponds to the JSON property authConfig
3257 3258 3259 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3257 def auth_config @auth_config end |
#dead_letter_config ⇒ Google::Apis::ConnectorsV1::DeadLetterConfig
Dead Letter configuration details provided by the user.
Corresponds to the JSON property deadLetterConfig
3262 3263 3264 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3262 def dead_letter_config @dead_letter_config end |
#enrichment_config ⇒ Google::Apis::ConnectorsV1::EnrichmentConfig
Data enrichment configuration.
Corresponds to the JSON property enrichmentConfig
3267 3268 3269 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3267 def enrichment_config @enrichment_config end |
#enrichment_enabled ⇒ Boolean Also known as: enrichment_enabled?
Optional. Enrichment Enabled.
Corresponds to the JSON property enrichmentEnabled
3272 3273 3274 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3272 def enrichment_enabled @enrichment_enabled end |
#events_listener_ingress_endpoint ⇒ String
Output only. Ingress endpoint of the event listener. This is used only when
private connectivity is enabled.
Corresponds to the JSON property eventsListenerIngressEndpoint
3279 3280 3281 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3279 def events_listener_ingress_endpoint @events_listener_ingress_endpoint end |
#global_event_filter ⇒ String
Optional. Filter to be applied on the events to be received by the connection.
Corresponds to the JSON property globalEventFilter
3284 3285 3286 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3284 def global_event_filter @global_event_filter end |
#listener_auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
Corresponds to the JSON property listenerAuthConfig
3289 3290 3291 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3289 def listener_auth_config @listener_auth_config end |
#private_connectivity_allowlisted_projects ⇒ Array<String>
Optional. List of projects to be allowlisted for the service attachment
created in the tenant project for eventing ingress.
Corresponds to the JSON property privateConnectivityAllowlistedProjects
3295 3296 3297 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3295 def private_connectivity_allowlisted_projects @private_connectivity_allowlisted_projects end |
#private_connectivity_enabled ⇒ Boolean Also known as: private_connectivity_enabled?
Optional. Private Connectivity Enabled.
Corresponds to the JSON property privateConnectivityEnabled
3300 3301 3302 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3300 def private_connectivity_enabled @private_connectivity_enabled end |
#proxy_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
Corresponds to the JSON property proxyDestinationConfig
3306 3307 3308 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3306 def proxy_destination_config @proxy_destination_config end |
#registration_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
Corresponds to the JSON property registrationDestinationConfig
3311 3312 3313 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3311 def registration_destination_config @registration_destination_config end |
#ssl_config ⇒ Google::Apis::ConnectorsV1::SslConfig
SSL Configuration of a connection
Corresponds to the JSON property sslConfig
3316 3317 3318 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3316 def ssl_config @ssl_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3323 3324 3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3323 def update!(**args) @additional_variables = args[:additional_variables] if args.key?(:additional_variables) @allowed_event_types = args[:allowed_event_types] if args.key?(:allowed_event_types) @auth_config = args[:auth_config] if args.key?(:auth_config) @dead_letter_config = args[:dead_letter_config] if args.key?(:dead_letter_config) @enrichment_config = args[:enrichment_config] if args.key?(:enrichment_config) @enrichment_enabled = args[:enrichment_enabled] if args.key?(:enrichment_enabled) @events_listener_ingress_endpoint = args[:events_listener_ingress_endpoint] if args.key?(:events_listener_ingress_endpoint) @global_event_filter = args[:global_event_filter] if args.key?(:global_event_filter) @listener_auth_config = args[:listener_auth_config] if args.key?(:listener_auth_config) @private_connectivity_allowlisted_projects = args[:private_connectivity_allowlisted_projects] if args.key?(:private_connectivity_allowlisted_projects) @private_connectivity_enabled = args[:private_connectivity_enabled] if args.key?(:private_connectivity_enabled) @proxy_destination_config = args[:proxy_destination_config] if args.key?(:proxy_destination_config) @registration_destination_config = args[:registration_destination_config] if args.key?(:registration_destination_config) @ssl_config = args[:ssl_config] if args.key?(:ssl_config) end |