Class: Google::Apis::ConnectorsV1::ExtractionRule
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::ExtractionRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Extraction Rule.
Instance Attribute Summary collapse
-
#extraction_regex ⇒ String
Regex used to extract backend details from source.
-
#format_string ⇒ String
Format string used to format the extracted backend details.
-
#source ⇒ Google::Apis::ConnectorsV1::Source
Source to extract the backend from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtractionRule
constructor
A new instance of ExtractionRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtractionRule
Returns a new instance of ExtractionRule.
3654 3655 3656 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extraction_regex ⇒ String
Regex used to extract backend details from source. If empty, whole source
value will be used.
Corresponds to the JSON property extractionRegex
3641 3642 3643 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3641 def extraction_regex @extraction_regex end |
#format_string ⇒ String
Format string used to format the extracted backend details. If empty,
extracted backend details will be returned as it is.
Corresponds to the JSON property formatString
3647 3648 3649 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3647 def format_string @format_string end |
#source ⇒ Google::Apis::ConnectorsV1::Source
Source to extract the backend from.
Corresponds to the JSON property source
3652 3653 3654 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3652 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3659 3660 3661 3662 3663 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3659 def update!(**args) @extraction_regex = args[:extraction_regex] if args.key?(:extraction_regex) @format_string = args[:format_string] if args.key?(:format_string) @source = args[:source] if args.key?(:source) end |