Class: Google::Apis::ConnectorsV1::FetchConnectionToolspecOverrideResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Response message for FetchConnectionToolspecOverride API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FetchConnectionToolspecOverrideResponse

Returns a new instance of FetchConnectionToolspecOverrideResponse.



3740
3741
3742
# File 'lib/google/apis/connectors_v1/classes.rb', line 3740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#toolspec_overrideGoogle::Apis::ConnectorsV1::ToolspecOverride

Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins. Corresponds to the JSON property toolspecOverride



3738
3739
3740
# File 'lib/google/apis/connectors_v1/classes.rb', line 3738

def toolspec_override
  @toolspec_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3745
3746
3747
# File 'lib/google/apis/connectors_v1/classes.rb', line 3745

def update!(**args)
  @toolspec_override = args[:toolspec_override] if args.key?(:toolspec_override)
end