Class: Google::Apis::ConnectorsV1::Field

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Metadata of an entity field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



3805
3806
3807
# File 'lib/google/apis/connectors_v1/classes.rb', line 3805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_detailsHash<String,Object>

The following map contains fields that are not explicitly mentioned above,this give connectors the flexibility to add new metadata fields. Corresponds to the JSON property additionalDetails

Returns:

  • (Hash<String,Object>)


3758
3759
3760
# File 'lib/google/apis/connectors_v1/classes.rb', line 3758

def additional_details
  @additional_details
end

#data_typeString

The data type of the Field. Corresponds to the JSON property dataType

Returns:

  • (String)


3763
3764
3765
# File 'lib/google/apis/connectors_v1/classes.rb', line 3763

def data_type
  @data_type
end

#default_valueObject

The following field specifies the default value of the Field provided by the external system if a value is not provided. Corresponds to the JSON property defaultValue

Returns:

  • (Object)


3769
3770
3771
# File 'lib/google/apis/connectors_v1/classes.rb', line 3769

def default_value
  @default_value
end

#descriptionString

A brief description of the Field. Corresponds to the JSON property description

Returns:

  • (String)


3774
3775
3776
# File 'lib/google/apis/connectors_v1/classes.rb', line 3774

def description
  @description
end

#fieldString

Name of the Field. Corresponds to the JSON property field

Returns:

  • (String)


3779
3780
3781
# File 'lib/google/apis/connectors_v1/classes.rb', line 3779

def field
  @field
end

#json_schemaGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property jsonSchema



3784
3785
3786
# File 'lib/google/apis/connectors_v1/classes.rb', line 3784

def json_schema
  @json_schema
end

#keyBoolean Also known as: key?

The following boolean field specifies if the current Field acts as a primary key or id if the parent is of type entity. Corresponds to the JSON property key

Returns:

  • (Boolean)


3790
3791
3792
# File 'lib/google/apis/connectors_v1/classes.rb', line 3790

def key
  @key
end

#nullableBoolean Also known as: nullable?

Specifies whether a null value is allowed. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


3796
3797
3798
# File 'lib/google/apis/connectors_v1/classes.rb', line 3796

def nullable
  @nullable
end

#readonlyBoolean Also known as: readonly?

Specifies if the Field is readonly. Corresponds to the JSON property readonly

Returns:

  • (Boolean)


3802
3803
3804
# File 'lib/google/apis/connectors_v1/classes.rb', line 3802

def readonly
  @readonly
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/google/apis/connectors_v1/classes.rb', line 3810

def update!(**args)
  @additional_details = args[:additional_details] if args.key?(:additional_details)
  @data_type = args[:data_type] if args.key?(:data_type)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
  @field = args[:field] if args.key?(:field)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @key = args[:key] if args.key?(:key)
  @nullable = args[:nullable] if args.key?(:nullable)
  @readonly = args[:readonly] if args.key?(:readonly)
end