Class: Google::Apis::ConnectorsV1::GenerateConnectionToolspecOverrideResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Response message for GenerateConnectionToolspecOverride API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateConnectionToolspecOverrideResponse

Returns a new instance of GenerateConnectionToolspecOverrideResponse.



3896
3897
3898
# File 'lib/google/apis/connectors_v1/classes.rb', line 3896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#toolspec_overrideGoogle::Apis::ConnectorsV1::ToolspecOverride

Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins. Corresponds to the JSON property toolspecOverride



3894
3895
3896
# File 'lib/google/apis/connectors_v1/classes.rb', line 3894

def toolspec_override
  @toolspec_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3901
3902
3903
# File 'lib/google/apis/connectors_v1/classes.rb', line 3901

def update!(**args)
  @toolspec_override = args[:toolspec_override] if args.key?(:toolspec_override)
end