Class: Google::Apis::ConnectorsV1::InputParameter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Metadata of an input parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InputParameter

Returns a new instance of InputParameter.



3874
3875
3876
# File 'lib/google/apis/connectors_v1/classes.rb', line 3874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

The data type of the Parameter. Corresponds to the JSON property dataType

Returns:

  • (String)


3845
3846
3847
# File 'lib/google/apis/connectors_v1/classes.rb', line 3845

def data_type
  @data_type
end

#default_valueObject

The following field specifies the default value of the Parameter provided by the external system if a value is not provided. Corresponds to the JSON property defaultValue

Returns:

  • (Object)


3851
3852
3853
# File 'lib/google/apis/connectors_v1/classes.rb', line 3851

def default_value
  @default_value
end

#descriptionString

A brief description of the Parameter. Corresponds to the JSON property description

Returns:

  • (String)


3856
3857
3858
# File 'lib/google/apis/connectors_v1/classes.rb', line 3856

def description
  @description
end

#json_schemaGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property jsonSchema



3861
3862
3863
# File 'lib/google/apis/connectors_v1/classes.rb', line 3861

def json_schema
  @json_schema
end

#nullableBoolean Also known as: nullable?

Specifies whether a null value is allowed. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


3866
3867
3868
# File 'lib/google/apis/connectors_v1/classes.rb', line 3866

def nullable
  @nullable
end

#parameterString

Name of the Parameter. Corresponds to the JSON property parameter

Returns:

  • (String)


3872
3873
3874
# File 'lib/google/apis/connectors_v1/classes.rb', line 3872

def parameter
  @parameter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3879
3880
3881
3882
3883
3884
3885
3886
# File 'lib/google/apis/connectors_v1/classes.rb', line 3879

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @nullable = args[:nullable] if args.key?(:nullable)
  @parameter = args[:parameter] if args.key?(:parameter)
end