Class: Google::Apis::ConnectorsV1::JsonSchema

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

JsonSchema representation of schema metadata

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JsonSchema

Returns a new instance of JsonSchema.



4490
4491
4492
# File 'lib/google/apis/connectors_v1/classes.rb', line 4490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#_commentString

A comment on the schema. Corresponds to the JSON property $comment

Returns:

  • (String)


4239
4240
4241
# File 'lib/google/apis/connectors_v1/classes.rb', line 4239

def _comment
  @_comment
end

#_defsHash<String,Google::Apis::ConnectorsV1::JsonSchema>

Definitions for the schema. Corresponds to the JSON property $defs

Returns:



4244
4245
4246
# File 'lib/google/apis/connectors_v1/classes.rb', line 4244

def _defs
  @_defs
end

#_idString

The URI defining the core schema meta-schema. Corresponds to the JSON property $id

Returns:

  • (String)


4249
4250
4251
# File 'lib/google/apis/connectors_v1/classes.rb', line 4249

def _id
  @_id
end

#_refString

A reference to another schema. Corresponds to the JSON property $ref

Returns:

  • (String)


4254
4255
4256
# File 'lib/google/apis/connectors_v1/classes.rb', line 4254

def _ref
  @_ref
end

#_schemaString

The URI defining the schema. Corresponds to the JSON property $schema

Returns:

  • (String)


4259
4260
4261
# File 'lib/google/apis/connectors_v1/classes.rb', line 4259

def _schema
  @_schema
end

#additional_detailsHash<String,Object>

Additional details apart from standard json schema fields, this gives flexibility to store metadata about the schema Corresponds to the JSON property additionalDetails

Returns:

  • (Hash<String,Object>)


4265
4266
4267
# File 'lib/google/apis/connectors_v1/classes.rb', line 4265

def additional_details
  @additional_details
end

#additional_itemsGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property additionalItems



4270
4271
4272
# File 'lib/google/apis/connectors_v1/classes.rb', line 4270

def additional_items
  @additional_items
end

#additional_propertiesGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property additionalProperties



4275
4276
4277
# File 'lib/google/apis/connectors_v1/classes.rb', line 4275

def additional_properties
  @additional_properties
end

#all_ofArray<Google::Apis::ConnectorsV1::JsonSchema>

Schema that must be valid against all of the sub-schemas. Corresponds to the JSON property allOf



4280
4281
4282
# File 'lib/google/apis/connectors_v1/classes.rb', line 4280

def all_of
  @all_of
end

#any_ofArray<Google::Apis::ConnectorsV1::JsonSchema>

Schema that must be valid against at least one of the sub-schemas. Corresponds to the JSON property anyOf



4285
4286
4287
# File 'lib/google/apis/connectors_v1/classes.rb', line 4285

def any_of
  @any_of
end

#constObject

Const value that the data must match. Corresponds to the JSON property const

Returns:

  • (Object)


4290
4291
4292
# File 'lib/google/apis/connectors_v1/classes.rb', line 4290

def const
  @const
end

#containsGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property contains



4295
4296
4297
# File 'lib/google/apis/connectors_v1/classes.rb', line 4295

def contains
  @contains
end

#content_encodingString

Encoding of the content. Corresponds to the JSON property contentEncoding

Returns:

  • (String)


4300
4301
4302
# File 'lib/google/apis/connectors_v1/classes.rb', line 4300

def content_encoding
  @content_encoding
end

#content_media_typeString

Media type of the content. Corresponds to the JSON property contentMediaType

Returns:

  • (String)


4305
4306
4307
# File 'lib/google/apis/connectors_v1/classes.rb', line 4305

def content_media_type
  @content_media_type
end

#defaultObject

The default value of the field or object described by this schema. Corresponds to the JSON property default

Returns:

  • (Object)


4310
4311
4312
# File 'lib/google/apis/connectors_v1/classes.rb', line 4310

def default
  @default
end

#definitionsHash<String,Google::Apis::ConnectorsV1::JsonSchema>

Definitions for the schema. Corresponds to the JSON property definitions

Returns:



4315
4316
4317
# File 'lib/google/apis/connectors_v1/classes.rb', line 4315

def definitions
  @definitions
end

#dependenciesHash<String,Object>

Dependencies for the schema. Corresponds to the JSON property dependencies

Returns:

  • (Hash<String,Object>)


4320
4321
4322
# File 'lib/google/apis/connectors_v1/classes.rb', line 4320

def dependencies
  @dependencies
end

#descriptionString

A description of this schema. Corresponds to the JSON property description

Returns:

  • (String)


4325
4326
4327
# File 'lib/google/apis/connectors_v1/classes.rb', line 4325

def description
  @description
end

#elseGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property else



4330
4331
4332
# File 'lib/google/apis/connectors_v1/classes.rb', line 4330

def else
  @else
end

#enumArray<Object>

Possible values for an enumeration. This works in conjunction with type to represent types with a fixed set of legal values Corresponds to the JSON property enum

Returns:

  • (Array<Object>)


4336
4337
4338
# File 'lib/google/apis/connectors_v1/classes.rb', line 4336

def enum
  @enum
end

#examplesArray<Object>

Examples of the value. Corresponds to the JSON property examples

Returns:

  • (Array<Object>)


4341
4342
4343
# File 'lib/google/apis/connectors_v1/classes.rb', line 4341

def examples
  @examples
end

#exclusive_maximumObject

Whether the maximum number value is exclusive. Corresponds to the JSON property exclusiveMaximum

Returns:

  • (Object)


4346
4347
4348
# File 'lib/google/apis/connectors_v1/classes.rb', line 4346

def exclusive_maximum
  @exclusive_maximum
end

#exclusive_minimumObject

Whether the minimum number value is exclusive. Corresponds to the JSON property exclusiveMinimum

Returns:

  • (Object)


4351
4352
4353
# File 'lib/google/apis/connectors_v1/classes.rb', line 4351

def exclusive_minimum
  @exclusive_minimum
end

#formatString

Format of the value as per https://json-schema.org/understanding-json-schema/ reference/string.html#format Corresponds to the JSON property format

Returns:

  • (String)


4357
4358
4359
# File 'lib/google/apis/connectors_v1/classes.rb', line 4357

def format
  @format
end

#ifGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property if



4362
4363
4364
# File 'lib/google/apis/connectors_v1/classes.rb', line 4362

def if
  @if
end

#itemsGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property items



4367
4368
4369
# File 'lib/google/apis/connectors_v1/classes.rb', line 4367

def items
  @items
end

#jdbc_typeString

JDBC datatype of the field. Corresponds to the JSON property jdbcType

Returns:

  • (String)


4372
4373
4374
# File 'lib/google/apis/connectors_v1/classes.rb', line 4372

def jdbc_type
  @jdbc_type
end

#max_itemsFixnum

Maximum number of items in the array field. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


4377
4378
4379
# File 'lib/google/apis/connectors_v1/classes.rb', line 4377

def max_items
  @max_items
end

#max_lengthFixnum

Maximum length of the string field. Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


4382
4383
4384
# File 'lib/google/apis/connectors_v1/classes.rb', line 4382

def max_length
  @max_length
end

#max_propertiesFixnum

Maximum number of properties. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


4387
4388
4389
# File 'lib/google/apis/connectors_v1/classes.rb', line 4387

def max_properties
  @max_properties
end

#maximumObject

Maximum value of the number field. Corresponds to the JSON property maximum

Returns:

  • (Object)


4392
4393
4394
# File 'lib/google/apis/connectors_v1/classes.rb', line 4392

def maximum
  @maximum
end

#min_itemsFixnum

Minimum number of items in the array field. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


4397
4398
4399
# File 'lib/google/apis/connectors_v1/classes.rb', line 4397

def min_items
  @min_items
end

#min_lengthFixnum

Minimum length of the string field. Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


4402
4403
4404
# File 'lib/google/apis/connectors_v1/classes.rb', line 4402

def min_length
  @min_length
end

#min_propertiesFixnum

Minimum number of properties. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


4407
4408
4409
# File 'lib/google/apis/connectors_v1/classes.rb', line 4407

def min_properties
  @min_properties
end

#minimumObject

Minimum value of the number field. Corresponds to the JSON property minimum

Returns:

  • (Object)


4412
4413
4414
# File 'lib/google/apis/connectors_v1/classes.rb', line 4412

def minimum
  @minimum
end

#multiple_ofFloat

Number must be a multiple of this value. Corresponds to the JSON property multipleOf

Returns:

  • (Float)


4417
4418
4419
# File 'lib/google/apis/connectors_v1/classes.rb', line 4417

def multiple_of
  @multiple_of
end

#notGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property not



4422
4423
4424
# File 'lib/google/apis/connectors_v1/classes.rb', line 4422

def not
  @not
end

#one_ofArray<Google::Apis::ConnectorsV1::JsonSchema>

Schema that must be valid against at least one of the sub-schemas. Corresponds to the JSON property oneOf



4427
4428
4429
# File 'lib/google/apis/connectors_v1/classes.rb', line 4427

def one_of
  @one_of
end

#patternString

Regex pattern of the string field. This is a string value that describes the regular expression that the string value should match. Corresponds to the JSON property pattern

Returns:

  • (String)


4433
4434
4435
# File 'lib/google/apis/connectors_v1/classes.rb', line 4433

def pattern
  @pattern
end

#pattern_propertiesHash<String,Google::Apis::ConnectorsV1::JsonSchema>

Pattern properties for the schema. Corresponds to the JSON property patternProperties

Returns:



4438
4439
4440
# File 'lib/google/apis/connectors_v1/classes.rb', line 4438

def pattern_properties
  @pattern_properties
end

#propertiesHash<String,Google::Apis::ConnectorsV1::JsonSchema>

The child schemas, applicable only if this is of type object. The key is the name of the property and the value is the json schema that describes that property Corresponds to the JSON property properties

Returns:



4445
4446
4447
# File 'lib/google/apis/connectors_v1/classes.rb', line 4445

def properties
  @properties
end

#property_namesGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property propertyNames



4450
4451
4452
# File 'lib/google/apis/connectors_v1/classes.rb', line 4450

def property_names
  @property_names
end

#read_onlyBoolean Also known as: read_only?

Whether the value is read-only. Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


4455
4456
4457
# File 'lib/google/apis/connectors_v1/classes.rb', line 4455

def read_only
  @read_only
end

#requiredArray<String>

Whether this property is required. Corresponds to the JSON property required

Returns:

  • (Array<String>)


4461
4462
4463
# File 'lib/google/apis/connectors_v1/classes.rb', line 4461

def required
  @required
end

#then_propGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property then



4466
4467
4468
# File 'lib/google/apis/connectors_v1/classes.rb', line 4466

def then_prop
  @then_prop
end

#titleString

A title of the schema. Corresponds to the JSON property title

Returns:

  • (String)


4471
4472
4473
# File 'lib/google/apis/connectors_v1/classes.rb', line 4471

def title
  @title
end

#typeArray<String>

JSON Schema Validation: A Vocabulary for Structural Validation of JSON Corresponds to the JSON property type

Returns:

  • (Array<String>)


4476
4477
4478
# File 'lib/google/apis/connectors_v1/classes.rb', line 4476

def type
  @type
end

#unique_itemsBoolean Also known as: unique_items?

Whether the items in the array field are unique. Corresponds to the JSON property uniqueItems

Returns:

  • (Boolean)


4481
4482
4483
# File 'lib/google/apis/connectors_v1/classes.rb', line 4481

def unique_items
  @unique_items
end

#write_onlyBoolean Also known as: write_only?

Whether the value is write-only. Corresponds to the JSON property writeOnly

Returns:

  • (Boolean)


4487
4488
4489
# File 'lib/google/apis/connectors_v1/classes.rb', line 4487

def write_only
  @write_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4495
4496
4497
4498
4499
4500
4501
4502
4503
4504
4505
4506
4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/google/apis/connectors_v1/classes.rb', line 4495

def update!(**args)
  @_comment = args[:_comment] if args.key?(:_comment)
  @_defs = args[:_defs] if args.key?(:_defs)
  @_id = args[:_id] if args.key?(:_id)
  @_ref = args[:_ref] if args.key?(:_ref)
  @_schema = args[:_schema] if args.key?(:_schema)
  @additional_details = args[:additional_details] if args.key?(:additional_details)
  @additional_items = args[:additional_items] if args.key?(:additional_items)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @all_of = args[:all_of] if args.key?(:all_of)
  @any_of = args[:any_of] if args.key?(:any_of)
  @const = args[:const] if args.key?(:const)
  @contains = args[:contains] if args.key?(:contains)
  @content_encoding = args[:content_encoding] if args.key?(:content_encoding)
  @content_media_type = args[:content_media_type] if args.key?(:content_media_type)
  @default = args[:default] if args.key?(:default)
  @definitions = args[:definitions] if args.key?(:definitions)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @description = args[:description] if args.key?(:description)
  @else = args[:else] if args.key?(:else)
  @enum = args[:enum] if args.key?(:enum)
  @examples = args[:examples] if args.key?(:examples)
  @exclusive_maximum = args[:exclusive_maximum] if args.key?(:exclusive_maximum)
  @exclusive_minimum = args[:exclusive_minimum] if args.key?(:exclusive_minimum)
  @format = args[:format] if args.key?(:format)
  @if = args[:if] if args.key?(:if)
  @items = args[:items] if args.key?(:items)
  @jdbc_type = args[:jdbc_type] if args.key?(:jdbc_type)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @multiple_of = args[:multiple_of] if args.key?(:multiple_of)
  @not = args[:not] if args.key?(:not)
  @one_of = args[:one_of] if args.key?(:one_of)
  @pattern = args[:pattern] if args.key?(:pattern)
  @pattern_properties = args[:pattern_properties] if args.key?(:pattern_properties)
  @properties = args[:properties] if args.key?(:properties)
  @property_names = args[:property_names] if args.key?(:property_names)
  @read_only = args[:read_only] if args.key?(:read_only)
  @required = args[:required] if args.key?(:required)
  @then_prop = args[:then_prop] if args.key?(:then_prop)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
  @unique_items = args[:unique_items] if args.key?(:unique_items)
  @write_only = args[:write_only] if args.key?(:write_only)
end