Class: Google::Apis::ConnectorsV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



4585
4586
4587
# File 'lib/google/apis/connectors_v1/classes.rb', line 4585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4570
4571
4572
# File 'lib/google/apis/connectors_v1/classes.rb', line 4570

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::ConnectorsV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



4575
4576
4577
# File 'lib/google/apis/connectors_v1/classes.rb', line 4575

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4583
4584
4585
# File 'lib/google/apis/connectors_v1/classes.rb', line 4583

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4590
4591
4592
4593
4594
# File 'lib/google/apis/connectors_v1/classes.rb', line 4590

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end