Class: Google::Apis::ConnectorsV1::MaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Maintenance schedule which is exposed to customer and potentially end user, indicating published upcoming future maintenance schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceSchedule

Returns a new instance of MaintenanceSchedule.



5310
5311
5312
# File 'lib/google/apis/connectors_v1/classes.rb', line 5310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_rescheduleBoolean Also known as: can_reschedule?

This field is deprecated, and will be always set to true since reschedule can happen multiple times now. This field should not be removed until all service producers remove this for their customers. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


5282
5283
5284
# File 'lib/google/apis/connectors_v1/classes.rb', line 5282

def can_reschedule
  @can_reschedule
end

#end_timeString

The scheduled end time for the maintenance. Corresponds to the JSON property endTime

Returns:

  • (String)


5288
5289
5290
# File 'lib/google/apis/connectors_v1/classes.rb', line 5288

def end_time
  @end_time
end

#rollout_management_policyString

The rollout management policy this maintenance schedule is associated with. When doing reschedule update request, the reschedule should be against this given policy. Corresponds to the JSON property rolloutManagementPolicy

Returns:

  • (String)


5295
5296
5297
# File 'lib/google/apis/connectors_v1/classes.rb', line 5295

def rollout_management_policy
  @rollout_management_policy
end

#schedule_deadline_timeString

schedule_deadline_time is the time deadline any schedule start time cannot go beyond, including reschedule. It's normally the initial schedule start time plus maintenance window length (1 day or 1 week). Maintenance cannot be scheduled to start beyond this deadline. Corresponds to the JSON property scheduleDeadlineTime

Returns:

  • (String)


5303
5304
5305
# File 'lib/google/apis/connectors_v1/classes.rb', line 5303

def schedule_deadline_time
  @schedule_deadline_time
end

#start_timeString

The scheduled start time for the maintenance. Corresponds to the JSON property startTime

Returns:

  • (String)


5308
5309
5310
# File 'lib/google/apis/connectors_v1/classes.rb', line 5308

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5315
5316
5317
5318
5319
5320
5321
# File 'lib/google/apis/connectors_v1/classes.rb', line 5315

def update!(**args)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @end_time = args[:end_time] if args.key?(:end_time)
  @rollout_management_policy = args[:rollout_management_policy] if args.key?(:rollout_management_policy)
  @schedule_deadline_time = args[:schedule_deadline_time] if args.key?(:schedule_deadline_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end