Class: Google::Apis::ConnectorsV1::OAuthTokenData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

pass only at create and not update using updateMask Auth Code Data

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OAuthTokenData

Returns a new instance of OAuthTokenData.



5765
5766
5767
# File 'lib/google/apis/connectors_v1/classes.rb', line 5765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_tokenGoogle::Apis::ConnectorsV1::EuaSecret

EUASecret provides a reference to entries in Secret Manager. Corresponds to the JSON property accessToken



5748
5749
5750
# File 'lib/google/apis/connectors_v1/classes.rb', line 5748

def access_token
  @access_token
end

#create_timeString

Optional. Timestamp when the access token was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5753
5754
5755
# File 'lib/google/apis/connectors_v1/classes.rb', line 5753

def create_time
  @create_time
end

#expiryString

Optional. Time in seconds when the access token expires. Corresponds to the JSON property expiry

Returns:

  • (String)


5758
5759
5760
# File 'lib/google/apis/connectors_v1/classes.rb', line 5758

def expiry
  @expiry
end

#refresh_tokenGoogle::Apis::ConnectorsV1::EuaSecret

EUASecret provides a reference to entries in Secret Manager. Corresponds to the JSON property refreshToken



5763
5764
5765
# File 'lib/google/apis/connectors_v1/classes.rb', line 5763

def refresh_token
  @refresh_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5770
5771
5772
5773
5774
5775
# File 'lib/google/apis/connectors_v1/classes.rb', line 5770

def update!(**args)
  @access_token = args[:access_token] if args.key?(:access_token)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expiry = args[:expiry] if args.key?(:expiry)
  @refresh_token = args[:refresh_token] if args.key?(:refresh_token)
end