Class: Google::Apis::ConnectorsV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



5678
5679
5680
# File 'lib/google/apis/connectors_v1/classes.rb', line 5678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


5642
5643
5644
# File 'lib/google/apis/connectors_v1/classes.rb', line 5642

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5647
5648
5649
# File 'lib/google/apis/connectors_v1/classes.rb', line 5647

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/connectors_v1/classes.rb', line 5652

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


5660
5661
5662
# File 'lib/google/apis/connectors_v1/classes.rb', line 5660

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


5666
5667
5668
# File 'lib/google/apis/connectors_v1/classes.rb', line 5666

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


5671
5672
5673
# File 'lib/google/apis/connectors_v1/classes.rb', line 5671

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


5676
5677
5678
# File 'lib/google/apis/connectors_v1/classes.rb', line 5676

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5683
5684
5685
5686
5687
5688
5689
5690
5691
# File 'lib/google/apis/connectors_v1/classes.rb', line 5683

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end