Class: Google::Apis::ConnectorsV1::PartnerMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Partner metadata details. This will be populated when publishing the custom connector as a partner connector version. On publishing, parntner connector version will be created using the fields in PartnerMetadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartnerMetadata

Returns a new instance of PartnerMetadata.



6149
6150
6151
# File 'lib/google/apis/connectors_v1/classes.rb', line 6149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_gcp_tosBoolean Also known as: accept_gcp_tos?

Required. Whether the user has accepted the Google Cloud Platform Terms of Service (https://cloud.google.com/terms/) and the Google Cloud Marketplace Terms of Service (https://cloud.google.com/terms/marketplace/launcher?hl=en). Corresponds to the JSON property acceptGcpTos

Returns:

  • (Boolean)


6061
6062
6063
# File 'lib/google/apis/connectors_v1/classes.rb', line 6061

def accept_gcp_tos
  @accept_gcp_tos
end

#additional_commentsString

Optional. Additional comments for the submission. Corresponds to the JSON property additionalComments

Returns:

  • (String)


6067
6068
6069
# File 'lib/google/apis/connectors_v1/classes.rb', line 6067

def additional_comments
  @additional_comments
end

#confirm_partner_requirementsBoolean Also known as: confirm_partner_requirements?

Required. Confirmation that connector meets all applicable requirements mentioned in the Partner Connector Publishing requirements list and Partner onboardiong requirements list (https://cloud.google.com/marketplace/docs/ partners/get-started#requirements). Corresponds to the JSON property confirmPartnerRequirements

Returns:

  • (Boolean)


6075
6076
6077
# File 'lib/google/apis/connectors_v1/classes.rb', line 6075

def confirm_partner_requirements
  @confirm_partner_requirements
end

#demo_uriString

Required. Public URL for the demo video. Corresponds to the JSON property demoUri

Returns:

  • (String)


6081
6082
6083
# File 'lib/google/apis/connectors_v1/classes.rb', line 6081

def demo_uri
  @demo_uri
end

#has_dynamic_spec_uriBoolean Also known as: has_dynamic_spec_uri?

Output only. Has dynamic open api spec uri. Corresponds to the JSON property hasDynamicSpecUri

Returns:

  • (Boolean)


6086
6087
6088
# File 'lib/google/apis/connectors_v1/classes.rb', line 6086

def has_dynamic_spec_uri
  @has_dynamic_spec_uri
end

#integration_templatesString

Required. Integration example templates for the custom connector. Corresponds to the JSON property integrationTemplates

Returns:

  • (String)


6092
6093
6094
# File 'lib/google/apis/connectors_v1/classes.rb', line 6092

def integration_templates
  @integration_templates
end

#local_spec_pathString

Output only. Local spec path. Required if has_dynamic_spec_uri is true. Corresponds to the JSON property localSpecPath

Returns:

  • (String)


6097
6098
6099
# File 'lib/google/apis/connectors_v1/classes.rb', line 6097

def local_spec_path
  @local_spec_path
end

#marketplace_productString

Optional. Marketplace product name. Corresponds to the JSON property marketplaceProduct

Returns:

  • (String)


6102
6103
6104
# File 'lib/google/apis/connectors_v1/classes.rb', line 6102

def marketplace_product
  @marketplace_product
end

#marketplace_product_idString

Required. Marketplace product ID. Corresponds to the JSON property marketplaceProductId

Returns:

  • (String)


6107
6108
6109
# File 'lib/google/apis/connectors_v1/classes.rb', line 6107

def marketplace_product_id
  @marketplace_product_id
end

#marketplace_product_project_idString

Optional. Marketplace product project ID. Corresponds to the JSON property marketplaceProductProjectId

Returns:

  • (String)


6112
6113
6114
# File 'lib/google/apis/connectors_v1/classes.rb', line 6112

def marketplace_product_project_id
  @marketplace_product_project_id
end

#marketplace_product_uriString

Optional. Marketplace product URL. Corresponds to the JSON property marketplaceProductUri

Returns:

  • (String)


6117
6118
6119
# File 'lib/google/apis/connectors_v1/classes.rb', line 6117

def marketplace_product_uri
  @marketplace_product_uri
end

#partnerString

Required. Partner name. Corresponds to the JSON property partner

Returns:

  • (String)


6122
6123
6124
# File 'lib/google/apis/connectors_v1/classes.rb', line 6122

def partner
  @partner
end

#partner_connector_display_nameString

Required. Partner connector display name. Corresponds to the JSON property partnerConnectorDisplayName

Returns:

  • (String)


6127
6128
6129
# File 'lib/google/apis/connectors_v1/classes.rb', line 6127

def partner_connector_display_name
  @partner_connector_display_name
end

#publish_request_timeString

Output only. Publish request time. Corresponds to the JSON property publishRequestTime

Returns:

  • (String)


6132
6133
6134
# File 'lib/google/apis/connectors_v1/classes.rb', line 6132

def publish_request_time
  @publish_request_time
end

#target_applicationString

Required. Target application for which partner connector is built. Corresponds to the JSON property targetApplication

Returns:

  • (String)


6137
6138
6139
# File 'lib/google/apis/connectors_v1/classes.rb', line 6137

def target_application
  @target_application
end

#target_customer_segmentString

Required. Target customer segment for the partner connector. Corresponds to the JSON property targetCustomerSegment

Returns:

  • (String)


6142
6143
6144
# File 'lib/google/apis/connectors_v1/classes.rb', line 6142

def target_customer_segment
  @target_customer_segment
end

#use_casesString

Required. Details about partner connector use cases. Corresponds to the JSON property useCases

Returns:

  • (String)


6147
6148
6149
# File 'lib/google/apis/connectors_v1/classes.rb', line 6147

def use_cases
  @use_cases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6154
6155
6156
6157
6158
6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
# File 'lib/google/apis/connectors_v1/classes.rb', line 6154

def update!(**args)
  @accept_gcp_tos = args[:accept_gcp_tos] if args.key?(:accept_gcp_tos)
  @additional_comments = args[:additional_comments] if args.key?(:additional_comments)
  @confirm_partner_requirements = args[:confirm_partner_requirements] if args.key?(:confirm_partner_requirements)
  @demo_uri = args[:demo_uri] if args.key?(:demo_uri)
  @has_dynamic_spec_uri = args[:has_dynamic_spec_uri] if args.key?(:has_dynamic_spec_uri)
  @integration_templates = args[:integration_templates] if args.key?(:integration_templates)
  @local_spec_path = args[:local_spec_path] if args.key?(:local_spec_path)
  @marketplace_product = args[:marketplace_product] if args.key?(:marketplace_product)
  @marketplace_product_id = args[:marketplace_product_id] if args.key?(:marketplace_product_id)
  @marketplace_product_project_id = args[:marketplace_product_project_id] if args.key?(:marketplace_product_project_id)
  @marketplace_product_uri = args[:marketplace_product_uri] if args.key?(:marketplace_product_uri)
  @partner = args[:partner] if args.key?(:partner)
  @partner_connector_display_name = args[:partner_connector_display_name] if args.key?(:partner_connector_display_name)
  @publish_request_time = args[:publish_request_time] if args.key?(:publish_request_time)
  @target_application = args[:target_application] if args.key?(:target_application)
  @target_customer_segment = args[:target_customer_segment] if args.key?(:target_customer_segment)
  @use_cases = args[:use_cases] if args.key?(:use_cases)
end