Class: Google::Apis::ConnectorsV1::Provider

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Provider indicates the owner who provides the connectors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Provider

Returns a new instance of Provider.



6357
6358
6359
# File 'lib/google/apis/connectors_v1/classes.rb', line 6357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


6306
6307
6308
# File 'lib/google/apis/connectors_v1/classes.rb', line 6306

def create_time
  @create_time
end

#descriptionString

Output only. Description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


6311
6312
6313
# File 'lib/google/apis/connectors_v1/classes.rb', line 6311

def description
  @description
end

#display_nameString

Output only. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


6316
6317
6318
# File 'lib/google/apis/connectors_v1/classes.rb', line 6316

def display_name
  @display_name
end

#documentation_uriString

Output only. Link to documentation page. Corresponds to the JSON property documentationUri

Returns:

  • (String)


6321
6322
6323
# File 'lib/google/apis/connectors_v1/classes.rb', line 6321

def documentation_uri
  @documentation_uri
end

#external_uriString

Output only. Link to external page. Corresponds to the JSON property externalUri

Returns:

  • (String)


6326
6327
6328
# File 'lib/google/apis/connectors_v1/classes.rb', line 6326

def external_uri
  @external_uri
end

#labelsHash<String,String>

Output only. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/ compute/docs/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6333
6334
6335
# File 'lib/google/apis/connectors_v1/classes.rb', line 6333

def labels
  @labels
end

#launch_stageString

Output only. Flag to mark the version indicating the launch stage. Corresponds to the JSON property launchStage

Returns:

  • (String)


6338
6339
6340
# File 'lib/google/apis/connectors_v1/classes.rb', line 6338

def launch_stage
  @launch_stage
end

#nameString

Output only. Resource name of the Provider. Format: projects/project/ locations/location/providers/provider Only global location is supported for Provider resource. Corresponds to the JSON property name

Returns:

  • (String)


6345
6346
6347
# File 'lib/google/apis/connectors_v1/classes.rb', line 6345

def name
  @name
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


6350
6351
6352
# File 'lib/google/apis/connectors_v1/classes.rb', line 6350

def update_time
  @update_time
end

#web_assets_locationString

Output only. Cloud storage location of icons etc consumed by UI. Corresponds to the JSON property webAssetsLocation

Returns:

  • (String)


6355
6356
6357
# File 'lib/google/apis/connectors_v1/classes.rb', line 6355

def web_assets_location
  @web_assets_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
# File 'lib/google/apis/connectors_v1/classes.rb', line 6362

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @labels = args[:labels] if args.key?(:labels)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @web_assets_location = args[:web_assets_location] if args.key?(:web_assets_location)
end