Class: Google::Apis::ConnectorsV1::PubSub

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Pub/Sub message includes details of the Destination Pub/Sub topic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PubSub

Returns a new instance of PubSub.



6430
6431
6432
# File 'lib/google/apis/connectors_v1/classes.rb', line 6430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,String>

Optional. Pub/Sub message attributes to be added to the Pub/Sub message. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,String>)


6413
6414
6415
# File 'lib/google/apis/connectors_v1/classes.rb', line 6413

def attributes
  @attributes
end

#config_variablesArray<Google::Apis::ConnectorsV1::ConfigVariable>

Optional. Configuration for configuring the trigger Corresponds to the JSON property configVariables



6418
6419
6420
# File 'lib/google/apis/connectors_v1/classes.rb', line 6418

def config_variables
  @config_variables
end

#project_idString

Required. The project id which has the Pub/Sub topic. Corresponds to the JSON property projectId

Returns:

  • (String)


6423
6424
6425
# File 'lib/google/apis/connectors_v1/classes.rb', line 6423

def project_id
  @project_id
end

#topic_idString

Required. The topic id of the Pub/Sub topic. Corresponds to the JSON property topicId

Returns:

  • (String)


6428
6429
6430
# File 'lib/google/apis/connectors_v1/classes.rb', line 6428

def topic_id
  @topic_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6435
6436
6437
6438
6439
6440
# File 'lib/google/apis/connectors_v1/classes.rb', line 6435

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @config_variables = args[:config_variables] if args.key?(:config_variables)
  @project_id = args[:project_id] if args.key?(:project_id)
  @topic_id = args[:topic_id] if args.key?(:topic_id)
end