Class: Google::Apis::ConnectorsV1::Resource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Resource definition

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Resource

Returns a new instance of Resource.



6149
6150
6151
# File 'lib/google/apis/connectors_v1/classes.rb', line 6149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#path_templateString

Optional. Template to uniquely represent a Google Cloud resource in a format IAM expects This is a template that can have references to other values provided in the config variable template. Corresponds to the JSON property pathTemplate

Returns:

  • (String)


6142
6143
6144
# File 'lib/google/apis/connectors_v1/classes.rb', line 6142

def path_template
  @path_template
end

#typeString

Optional. Different types of resource supported. Corresponds to the JSON property type

Returns:

  • (String)


6147
6148
6149
# File 'lib/google/apis/connectors_v1/classes.rb', line 6147

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6154
6155
6156
6157
# File 'lib/google/apis/connectors_v1/classes.rb', line 6154

def update!(**args)
  @path_template = args[:path_template] if args.key?(:path_template)
  @type = args[:type] if args.key?(:type)
end