Class: Google::Apis::ConnectorsV1::ResultMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Metadata of result field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResultMetadata

Returns a new instance of ResultMetadata.



6700
6701
6702
# File 'lib/google/apis/connectors_v1/classes.rb', line 6700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

The data type of the field. Corresponds to the JSON property dataType

Returns:

  • (String)


6671
6672
6673
# File 'lib/google/apis/connectors_v1/classes.rb', line 6671

def data_type
  @data_type
end

#default_valueObject

The following field specifies the default value of the Parameter provided by the external system if a value is not provided. Corresponds to the JSON property defaultValue

Returns:

  • (Object)


6677
6678
6679
# File 'lib/google/apis/connectors_v1/classes.rb', line 6677

def default_value
  @default_value
end

#descriptionString

A brief description of the field. Corresponds to the JSON property description

Returns:

  • (String)


6682
6683
6684
# File 'lib/google/apis/connectors_v1/classes.rb', line 6682

def description
  @description
end

#fieldString

Name of the result field. Corresponds to the JSON property field

Returns:

  • (String)


6687
6688
6689
# File 'lib/google/apis/connectors_v1/classes.rb', line 6687

def field
  @field
end

#json_schemaGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property jsonSchema



6692
6693
6694
# File 'lib/google/apis/connectors_v1/classes.rb', line 6692

def json_schema
  @json_schema
end

#nullableBoolean Also known as: nullable?

Specifies whether a null value is allowed. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


6697
6698
6699
# File 'lib/google/apis/connectors_v1/classes.rb', line 6697

def nullable
  @nullable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6705
6706
6707
6708
6709
6710
6711
6712
# File 'lib/google/apis/connectors_v1/classes.rb', line 6705

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
  @field = args[:field] if args.key?(:field)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @nullable = args[:nullable] if args.key?(:nullable)
end