Class: Google::Apis::ConnectorsV1::RuntimeActionSchema
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::RuntimeActionSchema
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Schema of a runtime action.
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#input_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata Corresponds to the JSON property
inputJsonSchema. -
#input_parameters ⇒ Array<Google::Apis::ConnectorsV1::InputParameter>
Output only.
-
#input_schema_as_string ⇒ String
Output only.
-
#result_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata Corresponds to the JSON property
resultJsonSchema. -
#result_metadata ⇒ Array<Google::Apis::ConnectorsV1::ResultMetadata>
Output only.
-
#result_schema_as_string ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeActionSchema
constructor
A new instance of RuntimeActionSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeActionSchema
Returns a new instance of RuntimeActionSchema.
6818 6819 6820 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6818 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Name of the action.
Corresponds to the JSON property action
6776 6777 6778 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6776 def action @action end |
#description ⇒ String
Output only. Brief Description of action
Corresponds to the JSON property description
6781 6782 6783 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6781 def description @description end |
#display_name ⇒ String
Output only. Display Name of action to be shown on client side
Corresponds to the JSON property displayName
6786 6787 6788 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6786 def display_name @display_name end |
#input_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata
Corresponds to the JSON property inputJsonSchema
6791 6792 6793 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6791 def input_json_schema @input_json_schema end |
#input_parameters ⇒ Array<Google::Apis::ConnectorsV1::InputParameter>
Output only. List of input parameter metadata for the action.
Corresponds to the JSON property inputParameters
6796 6797 6798 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6796 def input_parameters @input_parameters end |
#input_schema_as_string ⇒ String
Output only. Input schema as string.
Corresponds to the JSON property inputSchemaAsString
6801 6802 6803 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6801 def input_schema_as_string @input_schema_as_string end |
#result_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata
Corresponds to the JSON property resultJsonSchema
6806 6807 6808 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6806 def result_json_schema @result_json_schema end |
#result_metadata ⇒ Array<Google::Apis::ConnectorsV1::ResultMetadata>
Output only. List of result field metadata.
Corresponds to the JSON property resultMetadata
6811 6812 6813 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6811 def @result_metadata end |
#result_schema_as_string ⇒ String
Output only. Result schema as string.
Corresponds to the JSON property resultSchemaAsString
6816 6817 6818 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6816 def result_schema_as_string @result_schema_as_string end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6823 def update!(**args) @action = args[:action] if args.key?(:action) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @input_json_schema = args[:input_json_schema] if args.key?(:input_json_schema) @input_parameters = args[:input_parameters] if args.key?(:input_parameters) @input_schema_as_string = args[:input_schema_as_string] if args.key?(:input_schema_as_string) @result_json_schema = args[:result_json_schema] if args.key?(:result_json_schema) @result_metadata = args[:result_metadata] if args.key?(:result_metadata) @result_schema_as_string = args[:result_schema_as_string] if args.key?(:result_schema_as_string) end |