Class: Google::Apis::ConnectorsV1::RuntimeConfig
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::RuntimeConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
RuntimeConfig is the singleton resource of each location. It includes generic resource configs consumed by control plane and runtime plane like: pub/sub topic/subscription resource name, Cloud Storage location storing schema etc.
Instance Attribute Summary collapse
-
#connd_subscription ⇒ String
Output only.
-
#connd_topic ⇒ String
Output only.
-
#control_plane_subscription ⇒ String
Output only.
-
#control_plane_topic ⇒ String
Output only.
-
#location_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#runtime_endpoint ⇒ String
Output only.
-
#schema_gcs_bucket ⇒ String
Output only.
-
#service_directory ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeConfig
constructor
A new instance of RuntimeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeConfig
Returns a new instance of RuntimeConfig.
6897 6898 6899 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connd_subscription ⇒ String
Output only. Pub/Sub subscription for connd to receive message. E.g. projects/
project-id/subscriptions/topic-id
Corresponds to the JSON property conndSubscription
6846 6847 6848 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6846 def connd_subscription @connd_subscription end |
#connd_topic ⇒ String
Output only. Pub/Sub topic for connd to send message. E.g. projects/project-
id/topics/topic-id
Corresponds to the JSON property conndTopic
6852 6853 6854 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6852 def connd_topic @connd_topic end |
#control_plane_subscription ⇒ String
Output only. Pub/Sub subscription for control plane to receive message. E.g.
projects/project-id/subscriptions/topic-id
Corresponds to the JSON property controlPlaneSubscription
6858 6859 6860 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6858 def control_plane_subscription @control_plane_subscription end |
#control_plane_topic ⇒ String
Output only. Pub/Sub topic for control plne to send message. communication. E.
g. projects/project-id/topics/topic-id
Corresponds to the JSON property controlPlaneTopic
6864 6865 6866 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6864 def control_plane_topic @control_plane_topic end |
#location_id ⇒ String
Output only. location_id of the runtime location. E.g. "us-west1".
Corresponds to the JSON property locationId
6869 6870 6871 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6869 def location_id @location_id end |
#name ⇒ String
Output only. Name of the runtimeConfig resource. Format: projects/project/
locations/location/runtimeConfig
Corresponds to the JSON property name
6875 6876 6877 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6875 def name @name end |
#runtime_endpoint ⇒ String
Output only. The endpoint of the connectors runtime ingress.
Corresponds to the JSON property runtimeEndpoint
6880 6881 6882 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6880 def runtime_endpoint @runtime_endpoint end |
#schema_gcs_bucket ⇒ String
Output only. The Cloud Storage bucket that stores connector's schema reports.
Corresponds to the JSON property schemaGcsBucket
6885 6886 6887 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6885 def schema_gcs_bucket @schema_gcs_bucket end |
#service_directory ⇒ String
Output only. The name of the Service Directory service name.
Corresponds to the JSON property serviceDirectory
6890 6891 6892 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6890 def service_directory @service_directory end |
#state ⇒ String
Output only. The state of the location.
Corresponds to the JSON property state
6895 6896 6897 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6895 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6902 def update!(**args) @connd_subscription = args[:connd_subscription] if args.key?(:connd_subscription) @connd_topic = args[:connd_topic] if args.key?(:connd_topic) @control_plane_subscription = args[:control_plane_subscription] if args.key?(:control_plane_subscription) @control_plane_topic = args[:control_plane_topic] if args.key?(:control_plane_topic) @location_id = args[:location_id] if args.key?(:location_id) @name = args[:name] if args.key?(:name) @runtime_endpoint = args[:runtime_endpoint] if args.key?(:runtime_endpoint) @schema_gcs_bucket = args[:schema_gcs_bucket] if args.key?(:schema_gcs_bucket) @service_directory = args[:service_directory] if args.key?(:service_directory) @state = args[:state] if args.key?(:state) end |