Class: Google::Apis::ConnectorsV1::RuntimeEntitySchema
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::RuntimeEntitySchema
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Schema of a runtime entity.
Instance Attribute Summary collapse
-
#entity ⇒ String
Output only.
-
#fields ⇒ Array<Google::Apis::ConnectorsV1::Field>
Output only.
-
#json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata Corresponds to the JSON property
jsonSchema. -
#operations ⇒ Array<String>
List of operations supported by this entity Corresponds to the JSON property
operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeEntitySchema
constructor
A new instance of RuntimeEntitySchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeEntitySchema
Returns a new instance of RuntimeEntitySchema.
6940 6941 6942 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6940 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity ⇒ String
Output only. Name of the entity.
Corresponds to the JSON property entity
6923 6924 6925 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6923 def entity @entity end |
#fields ⇒ Array<Google::Apis::ConnectorsV1::Field>
Output only. List of fields in the entity.
Corresponds to the JSON property fields
6928 6929 6930 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6928 def fields @fields end |
#json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata
Corresponds to the JSON property jsonSchema
6933 6934 6935 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6933 def json_schema @json_schema end |
#operations ⇒ Array<String>
List of operations supported by this entity
Corresponds to the JSON property operations
6938 6939 6940 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6938 def operations @operations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6945 6946 6947 6948 6949 6950 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6945 def update!(**args) @entity = args[:entity] if args.key?(:entity) @fields = args[:fields] if args.key?(:fields) @json_schema = args[:json_schema] if args.key?(:json_schema) @operations = args[:operations] if args.key?(:operations) end |