Class: Google::Apis::ConnectorsV1::Schedule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Configure the schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schedule

Returns a new instance of Schedule.



6974
6975
6976
# File 'lib/google/apis/connectors_v1/classes.rb', line 6974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Allows to define schedule that runs specified day of the week. Corresponds to the JSON property day

Returns:

  • (String)


6960
6961
6962
# File 'lib/google/apis/connectors_v1/classes.rb', line 6960

def day
  @day
end

#durationString

Output only. Duration of the time window, set by service producer. Corresponds to the JSON property duration

Returns:

  • (String)


6965
6966
6967
# File 'lib/google/apis/connectors_v1/classes.rb', line 6965

def duration
  @duration
end

#start_timeGoogle::Apis::ConnectorsV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



6972
6973
6974
# File 'lib/google/apis/connectors_v1/classes.rb', line 6972

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6979
6980
6981
6982
6983
# File 'lib/google/apis/connectors_v1/classes.rb', line 6979

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end