Class: Google::Apis::ConnectorsV1::Secret

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Secret provides a reference to entries in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Secret

Returns a new instance of Secret.



7086
7087
7088
# File 'lib/google/apis/connectors_v1/classes.rb', line 7086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secret_versionString

Optional. The resource name of the secret version in the format, format as: projects/*/secrets/*/versions/*. Corresponds to the JSON property secretVersion

Returns:

  • (String)


7084
7085
7086
# File 'lib/google/apis/connectors_v1/classes.rb', line 7084

def secret_version
  @secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7091
7092
7093
# File 'lib/google/apis/connectors_v1/classes.rb', line 7091

def update!(**args)
  @secret_version = args[:secret_version] if args.key?(:secret_version)
end