Class: Google::Apis::ConnectorsV1::SloMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

SloMetadata contains resources required for proper SLO classification of the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SloMetadata

Returns a new instance of SloMetadata.



6789
6790
6791
# File 'lib/google/apis/connectors_v1/classes.rb', line 6789

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nodesArray<Google::Apis::ConnectorsV1::NodeSloMetadata>

Optional. List of nodes. Some producers need to use per-node metadata to calculate SLO. This field allows such producers to publish per-node SLO meta data, which will be consumed by SSA Eligibility Exporter and published in the form of per node metric to Monarch. Corresponds to the JSON property nodes



6775
6776
6777
# File 'lib/google/apis/connectors_v1/classes.rb', line 6775

def nodes
  @nodes
end

#per_sli_eligibilityGoogle::Apis::ConnectorsV1::PerSliSloEligibility

PerSliSloEligibility is a mapping from an SLI name to eligibility. Corresponds to the JSON property perSliEligibility



6780
6781
6782
# File 'lib/google/apis/connectors_v1/classes.rb', line 6780

def per_sli_eligibility
  @per_sli_eligibility
end

#tierString

Name of the SLO tier the Instance belongs to. This name will be expected to match the tiers specified in the service SLO configuration. Field is mandatory and must not be empty. Corresponds to the JSON property tier

Returns:

  • (String)


6787
6788
6789
# File 'lib/google/apis/connectors_v1/classes.rb', line 6787

def tier
  @tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6794
6795
6796
6797
6798
# File 'lib/google/apis/connectors_v1/classes.rb', line 6794

def update!(**args)
  @nodes = args[:nodes] if args.key?(:nodes)
  @per_sli_eligibility = args[:per_sli_eligibility] if args.key?(:per_sli_eligibility)
  @tier = args[:tier] if args.key?(:tier)
end