Class: Google::Apis::ConnectorsV1::SshPublicKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Parameters to support Ssh public key Authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SshPublicKey

Returns a new instance of SshPublicKey.



7304
7305
7306
# File 'lib/google/apis/connectors_v1/classes.rb', line 7304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cert_typeString

Optional. Format of SSH Client cert. Corresponds to the JSON property certType

Returns:

  • (String)


7287
7288
7289
# File 'lib/google/apis/connectors_v1/classes.rb', line 7287

def cert_type
  @cert_type
end

#ssh_client_certGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property sshClientCert



7292
7293
7294
# File 'lib/google/apis/connectors_v1/classes.rb', line 7292

def ssh_client_cert
  @ssh_client_cert
end

#ssh_client_cert_passGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property sshClientCertPass



7297
7298
7299
# File 'lib/google/apis/connectors_v1/classes.rb', line 7297

def ssh_client_cert_pass
  @ssh_client_cert_pass
end

#usernameString

Optional. The user account used to authenticate. Corresponds to the JSON property username

Returns:

  • (String)


7302
7303
7304
# File 'lib/google/apis/connectors_v1/classes.rb', line 7302

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7309
7310
7311
7312
7313
7314
# File 'lib/google/apis/connectors_v1/classes.rb', line 7309

def update!(**args)
  @cert_type = args[:cert_type] if args.key?(:cert_type)
  @ssh_client_cert = args[:ssh_client_cert] if args.key?(:ssh_client_cert)
  @ssh_client_cert_pass = args[:ssh_client_cert_pass] if args.key?(:ssh_client_cert_pass)
  @username = args[:username] if args.key?(:username)
end