Class: Google::Apis::ConnectorsV1::SslConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

SSL Configuration of a connection

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslConfig

Returns a new instance of SslConfig.



7372
7373
7374
# File 'lib/google/apis/connectors_v1/classes.rb', line 7372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_variablesArray<Google::Apis::ConnectorsV1::ConfigVariable>

Optional. Additional SSL related field values Corresponds to the JSON property additionalVariables



7324
7325
7326
# File 'lib/google/apis/connectors_v1/classes.rb', line 7324

def additional_variables
  @additional_variables
end

#client_cert_typeString

Optional. Type of Client Cert (PEM/JKS/.. etc.) Corresponds to the JSON property clientCertType

Returns:

  • (String)


7329
7330
7331
# File 'lib/google/apis/connectors_v1/classes.rb', line 7329

def client_cert_type
  @client_cert_type
end

#client_certificateGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientCertificate



7334
7335
7336
# File 'lib/google/apis/connectors_v1/classes.rb', line 7334

def client_certificate
  @client_certificate
end

#client_private_keyGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientPrivateKey



7339
7340
7341
# File 'lib/google/apis/connectors_v1/classes.rb', line 7339

def client_private_key
  @client_private_key
end

#client_private_key_passGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientPrivateKeyPass



7344
7345
7346
# File 'lib/google/apis/connectors_v1/classes.rb', line 7344

def client_private_key_pass
  @client_private_key_pass
end

#private_server_certificateGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property privateServerCertificate



7349
7350
7351
# File 'lib/google/apis/connectors_v1/classes.rb', line 7349

def private_server_certificate
  @private_server_certificate
end

#server_cert_typeString

Optional. Type of Server Cert (PEM/JKS/.. etc.) Corresponds to the JSON property serverCertType

Returns:

  • (String)


7354
7355
7356
# File 'lib/google/apis/connectors_v1/classes.rb', line 7354

def server_cert_type
  @server_cert_type
end

#trust_modelString

Optional. Trust Model of the SSL connection Corresponds to the JSON property trustModel

Returns:

  • (String)


7359
7360
7361
# File 'lib/google/apis/connectors_v1/classes.rb', line 7359

def trust_model
  @trust_model
end

#typeString

Optional. Controls the ssl type for the given connector version. Corresponds to the JSON property type

Returns:

  • (String)


7364
7365
7366
# File 'lib/google/apis/connectors_v1/classes.rb', line 7364

def type
  @type
end

#use_sslBoolean Also known as: use_ssl?

Optional. Bool for enabling SSL Corresponds to the JSON property useSsl

Returns:

  • (Boolean)


7369
7370
7371
# File 'lib/google/apis/connectors_v1/classes.rb', line 7369

def use_ssl
  @use_ssl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
# File 'lib/google/apis/connectors_v1/classes.rb', line 7377

def update!(**args)
  @additional_variables = args[:additional_variables] if args.key?(:additional_variables)
  @client_cert_type = args[:client_cert_type] if args.key?(:client_cert_type)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_private_key = args[:client_private_key] if args.key?(:client_private_key)
  @client_private_key_pass = args[:client_private_key_pass] if args.key?(:client_private_key_pass)
  @private_server_certificate = args[:private_server_certificate] if args.key?(:private_server_certificate)
  @server_cert_type = args[:server_cert_type] if args.key?(:server_cert_type)
  @trust_model = args[:trust_model] if args.key?(:trust_model)
  @type = args[:type] if args.key?(:type)
  @use_ssl = args[:use_ssl] if args.key?(:use_ssl)
end