Class: Google::Apis::ConnectorsV1::SslConfigTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Ssl config details of a connector version

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslConfigTemplate

Returns a new instance of SslConfigTemplate.



7421
7422
7423
# File 'lib/google/apis/connectors_v1/classes.rb', line 7421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_variablesArray<Google::Apis::ConnectorsV1::ConfigVariableTemplate>

Any additional fields that need to be rendered Corresponds to the JSON property additionalVariables



7398
7399
7400
# File 'lib/google/apis/connectors_v1/classes.rb', line 7398

def additional_variables
  @additional_variables
end

#client_cert_typeArray<String>

List of supported Client Cert Types Corresponds to the JSON property clientCertType

Returns:

  • (Array<String>)


7403
7404
7405
# File 'lib/google/apis/connectors_v1/classes.rb', line 7403

def client_cert_type
  @client_cert_type
end

#is_tls_mandatoryBoolean Also known as: is_tls_mandatory?

Boolean for determining if the connector version mandates TLS. Corresponds to the JSON property isTlsMandatory

Returns:

  • (Boolean)


7408
7409
7410
# File 'lib/google/apis/connectors_v1/classes.rb', line 7408

def is_tls_mandatory
  @is_tls_mandatory
end

#server_cert_typeArray<String>

List of supported Server Cert Types Corresponds to the JSON property serverCertType

Returns:

  • (Array<String>)


7414
7415
7416
# File 'lib/google/apis/connectors_v1/classes.rb', line 7414

def server_cert_type
  @server_cert_type
end

#ssl_typeString

Controls the ssl type for the given connector version Corresponds to the JSON property sslType

Returns:

  • (String)


7419
7420
7421
# File 'lib/google/apis/connectors_v1/classes.rb', line 7419

def ssl_type
  @ssl_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7426
7427
7428
7429
7430
7431
7432
# File 'lib/google/apis/connectors_v1/classes.rb', line 7426

def update!(**args)
  @additional_variables = args[:additional_variables] if args.key?(:additional_variables)
  @client_cert_type = args[:client_cert_type] if args.key?(:client_cert_type)
  @is_tls_mandatory = args[:is_tls_mandatory] if args.key?(:is_tls_mandatory)
  @server_cert_type = args[:server_cert_type] if args.key?(:server_cert_type)
  @ssl_type = args[:ssl_type] if args.key?(:ssl_type)
end