Class: Google::Apis::ConnectorsV1::SupportedRuntimeFeatures
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::SupportedRuntimeFeatures
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Supported runtime features of a connector version.
Instance Attribute Summary collapse
-
#action_apis ⇒ Boolean
(also: #action_apis?)
Specifies if the connector supports action apis like 'executeAction'.
-
#async_operations ⇒ Boolean
(also: #async_operations?)
Specifies if the connector supports async long running operations.
-
#entity_apis ⇒ Boolean
(also: #entity_apis?)
Specifies if the connector supports entity apis like 'createEntity'.
-
#sql_query ⇒ Boolean
(also: #sql_query?)
Specifies if the connector supports 'ExecuteSqlQuery' operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupportedRuntimeFeatures
constructor
A new instance of SupportedRuntimeFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupportedRuntimeFeatures
Returns a new instance of SupportedRuntimeFeatures.
7178 7179 7180 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_apis ⇒ Boolean Also known as: action_apis?
Specifies if the connector supports action apis like 'executeAction'.
Corresponds to the JSON property actionApis
7157 7158 7159 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7157 def action_apis @action_apis end |
#async_operations ⇒ Boolean Also known as: async_operations?
Specifies if the connector supports async long running operations.
Corresponds to the JSON property asyncOperations
7163 7164 7165 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7163 def async_operations @async_operations end |
#entity_apis ⇒ Boolean Also known as: entity_apis?
Specifies if the connector supports entity apis like 'createEntity'.
Corresponds to the JSON property entityApis
7169 7170 7171 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7169 def entity_apis @entity_apis end |
#sql_query ⇒ Boolean Also known as: sql_query?
Specifies if the connector supports 'ExecuteSqlQuery' operation.
Corresponds to the JSON property sqlQuery
7175 7176 7177 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7175 def sql_query @sql_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7183 7184 7185 7186 7187 7188 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7183 def update!(**args) @action_apis = args[:action_apis] if args.key?(:action_apis) @async_operations = args[:async_operations] if args.key?(:async_operations) @entity_apis = args[:entity_apis] if args.key?(:entity_apis) @sql_query = args[:sql_query] if args.key?(:sql_query) end |