Class: Google::Apis::ConnectorsV1::ToolName

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Tool name for which the tool spec override is to be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolName

Returns a new instance of ToolName.



7676
7677
7678
# File 'lib/google/apis/connectors_v1/classes.rb', line 7676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_typeString

Optional. Entity type name for which the tool was generated. Corresponds to the JSON property entityType

Returns:

  • (String)


7664
7665
7666
# File 'lib/google/apis/connectors_v1/classes.rb', line 7664

def entity_type
  @entity_type
end

#nameString

Required. Tool name that was generated in the list tools call. Corresponds to the JSON property name

Returns:

  • (String)


7669
7670
7671
# File 'lib/google/apis/connectors_v1/classes.rb', line 7669

def name
  @name
end

#operationString

Optional. Operation for which the tool was generated. Corresponds to the JSON property operation

Returns:

  • (String)


7674
7675
7676
# File 'lib/google/apis/connectors_v1/classes.rb', line 7674

def operation
  @operation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7681
7682
7683
7684
7685
# File 'lib/google/apis/connectors_v1/classes.rb', line 7681

def update!(**args)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
end