Class: Google::Apis::ConnectorsV1::UserPassword
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::UserPassword
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Parameters to support Username and Password Authentication.
Instance Attribute Summary collapse
-
#password ⇒ Google::Apis::ConnectorsV1::Secret
Secret provides a reference to entries in Secret Manager.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserPassword
constructor
A new instance of UserPassword.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserPassword
Returns a new instance of UserPassword.
7431 7432 7433 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password ⇒ Google::Apis::ConnectorsV1::Secret
Secret provides a reference to entries in Secret Manager.
Corresponds to the JSON property password
7424 7425 7426 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7424 def password @password end |
#username ⇒ String
Optional. Username.
Corresponds to the JSON property username
7429 7430 7431 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7429 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7436 7437 7438 7439 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7436 def update!(**args) @password = args[:password] if args.key?(:password) @username = args[:username] if args.key?(:username) end |