Class: Google::Apis::ConnectorsV1::WebhookData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

WebhookData has details of webhook configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebhookData

Returns a new instance of WebhookData.



7954
7955
7956
# File 'lib/google/apis/connectors_v1/classes.rb', line 7954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_variablesArray<Google::Apis::ConnectorsV1::ConfigVariable>

Output only. Additional webhook related field values. Corresponds to the JSON property additionalVariables



7915
7916
7917
# File 'lib/google/apis/connectors_v1/classes.rb', line 7915

def additional_variables
  @additional_variables
end

#create_timeString

Output only. Timestamp when the webhook was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7920
7921
7922
# File 'lib/google/apis/connectors_v1/classes.rb', line 7920

def create_time
  @create_time
end

#event_subscriptionsArray<String>

Output only. List of event subscriptions which are using the webhook. Corresponds to the JSON property eventSubscriptions

Returns:

  • (Array<String>)


7925
7926
7927
# File 'lib/google/apis/connectors_v1/classes.rb', line 7925

def event_subscriptions
  @event_subscriptions
end

#event_typesArray<String>

Output only. List of event types for the webhook. This is the event types subscribed by the current webhook. Corresponds to the JSON property eventTypes

Returns:

  • (Array<String>)


7931
7932
7933
# File 'lib/google/apis/connectors_v1/classes.rb', line 7931

def event_types
  @event_types
end

#idString

Output only. ID to uniquely identify webhook. Corresponds to the JSON property id

Returns:

  • (String)


7936
7937
7938
# File 'lib/google/apis/connectors_v1/classes.rb', line 7936

def id
  @id
end

#nameString

Output only. Name of the Webhook Corresponds to the JSON property name

Returns:

  • (String)


7941
7942
7943
# File 'lib/google/apis/connectors_v1/classes.rb', line 7941

def name
  @name
end

#next_refresh_timeString

Output only. Next webhook refresh time. Will be null if refresh is not supported. Corresponds to the JSON property nextRefreshTime

Returns:

  • (String)


7947
7948
7949
# File 'lib/google/apis/connectors_v1/classes.rb', line 7947

def next_refresh_time
  @next_refresh_time
end

#update_timeString

Output only. Timestamp when the webhook was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7952
7953
7954
# File 'lib/google/apis/connectors_v1/classes.rb', line 7952

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7959
7960
7961
7962
7963
7964
7965
7966
7967
7968
# File 'lib/google/apis/connectors_v1/classes.rb', line 7959

def update!(**args)
  @additional_variables = args[:additional_variables] if args.key?(:additional_variables)
  @create_time = args[:create_time] if args.key?(:create_time)
  @event_subscriptions = args[:event_subscriptions] if args.key?(:event_subscriptions)
  @event_types = args[:event_types] if args.key?(:event_types)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @next_refresh_time = args[:next_refresh_time] if args.key?(:next_refresh_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end