Class: Google::Apis::ConnectorsV1::ConfigVariableTemplate
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::ConfigVariableTemplate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
ConfigVariableTemplate provides metadata about a ConfigVariable that is used
in a Connection.
Instance Attribute Summary collapse
-
#authorization_code_link ⇒ Google::Apis::ConnectorsV1::AuthorizationCodeLink
This configuration captures the details required to render an authorization link for the OAuth Authorization Code Flow.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#enum_options ⇒ Array<Google::Apis::ConnectorsV1::EnumOption>
Optional.
-
#enum_source ⇒ String
Optional.
-
#is_advanced ⇒ Boolean
(also: #is_advanced?)
Optional.
-
#key ⇒ String
Optional.
-
#location_type ⇒ String
Optional.
-
#multiple_select_config ⇒ Google::Apis::ConnectorsV1::MultipleSelectConfig
MultipleSelectConfig represents the multiple options for a config variable.
-
#required ⇒ Boolean
(also: #required?)
Optional.
-
#required_condition ⇒ Google::Apis::ConnectorsV1::LogicalExpression
Struct for representing boolean expressions.
-
#role_grant ⇒ Google::Apis::ConnectorsV1::RoleGrant
This configuration defines all the Cloud IAM roles that needs to be granted to a particular Google Cloud resource for the selected principal like service account.
-
#state ⇒ String
Output only.
-
#validation_regex ⇒ String
Optional.
-
#value_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigVariableTemplate
constructor
A new instance of ConfigVariableTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigVariableTemplate
Returns a new instance of ConfigVariableTemplate.
757 758 759 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_code_link ⇒ Google::Apis::ConnectorsV1::AuthorizationCodeLink
This configuration captures the details required to render an authorization
link for the OAuth Authorization Code Flow.
Corresponds to the JSON property authorizationCodeLink
675 676 677 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 675 def @authorization_code_link end |
#description ⇒ String
Optional. Description.
Corresponds to the JSON property description
680 681 682 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 680 def description @description end |
#display_name ⇒ String
Optional. Display name of the parameter.
Corresponds to the JSON property displayName
685 686 687 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 685 def display_name @display_name end |
#enum_options ⇒ Array<Google::Apis::ConnectorsV1::EnumOption>
Optional. Enum options. To be populated if ValueType is ENUM
Corresponds to the JSON property enumOptions
690 691 692 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 690 def @enum_options end |
#enum_source ⇒ String
Optional. enum source denotes the source of api to fill the enum options
Corresponds to the JSON property enumSource
695 696 697 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 695 def enum_source @enum_source end |
#is_advanced ⇒ Boolean Also known as: is_advanced?
Optional. Indicates if current template is part of advanced settings
Corresponds to the JSON property isAdvanced
700 701 702 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 700 def is_advanced @is_advanced end |
#key ⇒ String
Optional. Key of the config variable.
Corresponds to the JSON property key
706 707 708 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 706 def key @key end |
#location_type ⇒ String
Optional. Location Type denotes where this value should be sent in BYOC
connections.
Corresponds to the JSON property locationType
712 713 714 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 712 def location_type @location_type end |
#multiple_select_config ⇒ Google::Apis::ConnectorsV1::MultipleSelectConfig
MultipleSelectConfig represents the multiple options for a config variable.
Corresponds to the JSON property multipleSelectConfig
717 718 719 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 717 def multiple_select_config @multiple_select_config end |
#required ⇒ Boolean Also known as: required?
Optional. Flag represents that this ConfigVariable must be provided for a
connection.
Corresponds to the JSON property required
723 724 725 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 723 def required @required end |
#required_condition ⇒ Google::Apis::ConnectorsV1::LogicalExpression
Struct for representing boolean expressions.
Corresponds to the JSON property requiredCondition
729 730 731 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 729 def required_condition @required_condition end |
#role_grant ⇒ Google::Apis::ConnectorsV1::RoleGrant
This configuration defines all the Cloud IAM roles that needs to be granted to
a particular Google Cloud resource for the selected principal like service
account. These configurations will let UI display to customers what IAM roles
need to be granted by them. Or these configurations can be used by the UI to
render a 'grant' button to do the same on behalf of the user.
Corresponds to the JSON property roleGrant
738 739 740 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 738 def role_grant @role_grant end |
#state ⇒ String
Output only. State of the config variable.
Corresponds to the JSON property state
743 744 745 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 743 def state @state end |
#validation_regex ⇒ String
Optional. Regular expression in RE2 syntax used for validating the value of
a ConfigVariable.
Corresponds to the JSON property validationRegex
749 750 751 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 749 def validation_regex @validation_regex end |
#value_type ⇒ String
Optional. Type of the parameter: string, int, bool etc. consider custom type
for the benefit for the validation.
Corresponds to the JSON property valueType
755 756 757 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 755 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 762 def update!(**args) @authorization_code_link = args[:authorization_code_link] if args.key?(:authorization_code_link) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enum_options = args[:enum_options] if args.key?(:enum_options) @enum_source = args[:enum_source] if args.key?(:enum_source) @is_advanced = args[:is_advanced] if args.key?(:is_advanced) @key = args[:key] if args.key?(:key) @location_type = args[:location_type] if args.key?(:location_type) @multiple_select_config = args[:multiple_select_config] if args.key?(:multiple_select_config) @required = args[:required] if args.key?(:required) @required_condition = args[:required_condition] if args.key?(:required_condition) @role_grant = args[:role_grant] if args.key?(:role_grant) @state = args[:state] if args.key?(:state) @validation_regex = args[:validation_regex] if args.key?(:validation_regex) @value_type = args[:value_type] if args.key?(:value_type) end |