Class: Google::Apis::ConnectorsV1::Connection
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::Connection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Connection represents an instance of connector.
Instance Attribute Summary collapse
-
#async_operations_enabled ⇒ Boolean
(also: #async_operations_enabled?)
Optional.
-
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
-
#auth_override_enabled ⇒ Boolean
(also: #auth_override_enabled?)
Optional.
-
#billing_config ⇒ Google::Apis::ConnectorsV1::BillingConfig
Billing config for the connection.
-
#config_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional.
-
#connection_revision ⇒ Fixnum
Output only.
-
#connector_version ⇒ String
Required.
-
#connector_version_infra_config ⇒ Google::Apis::ConnectorsV1::ConnectorVersionInfraConfig
This configuration provides infra configs like rate limit threshold which need to be configurable for every connector version Corresponds to the JSON property
connectorVersionInfraConfig. -
#connector_version_launch_stage ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#destination_configs ⇒ Array<Google::Apis::ConnectorsV1::DestinationConfig>
Optional.
-
#envoy_image_location ⇒ String
Output only.
-
#eua_oauth_auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
-
#eventing_config ⇒ Google::Apis::ConnectorsV1::EventingConfig
Eventing Configuration of a connection next: 19 Corresponds to the JSON property
eventingConfig. -
#eventing_enablement_type ⇒ String
Optional.
-
#eventing_runtime_data ⇒ Google::Apis::ConnectorsV1::EventingRuntimeData
Eventing runtime data has the details related to eventing managed by the system.
-
#fallback_on_admin_credentials ⇒ Boolean
(also: #fallback_on_admin_credentials?)
Optional.
-
#host ⇒ String
Output only.
-
#image_location ⇒ String
Output only.
-
#is_trusted_tester ⇒ Boolean
(also: #is_trusted_tester?)
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#lock_config ⇒ Google::Apis::ConnectorsV1::LockConfig
Determines whether or no a connection is locked.
-
#log_config ⇒ Google::Apis::ConnectorsV1::ConnectorsLogConfig
Log configuration for the connection.
-
#name ⇒ String
Output only.
-
#node_config ⇒ Google::Apis::ConnectorsV1::NodeConfig
Node configuration for the connection.
-
#service_account ⇒ String
Optional.
-
#service_directory ⇒ String
Output only.
-
#ssl_config ⇒ Google::Apis::ConnectorsV1::SslConfig
SSL Configuration of a connection Corresponds to the JSON property
sslConfig. -
#status ⇒ Google::Apis::ConnectorsV1::ConnectionStatus
ConnectionStatus indicates the state of the connection.
-
#subscription_type ⇒ String
Output only.
-
#suspended ⇒ Boolean
(also: #suspended?)
Optional.
-
#tls_service_directory ⇒ String
Output only.
-
#traffic_shaping_configs ⇒ Array<Google::Apis::ConnectorsV1::TrafficShapingConfig>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Connection
constructor
A new instance of Connection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Connection
Returns a new instance of Connection.
945 946 947 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#async_operations_enabled ⇒ Boolean Also known as: async_operations_enabled?
Optional. Async operations enabled for the connection. If Async Operations is
enabled, Connection allows the customers to initiate async long running
operations using the actions API.
Corresponds to the JSON property asyncOperationsEnabled
745 746 747 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 745 def async_operations_enabled @async_operations_enabled end |
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
Corresponds to the JSON property authConfig
751 752 753 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 751 def auth_config @auth_config end |
#auth_override_enabled ⇒ Boolean Also known as: auth_override_enabled?
Optional. Auth override enabled for the connection. If Auth Override is
enabled, Connection allows the backend service auth to be overridden in the
entities/actions API.
Corresponds to the JSON property authOverrideEnabled
758 759 760 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 758 def auth_override_enabled @auth_override_enabled end |
#billing_config ⇒ Google::Apis::ConnectorsV1::BillingConfig
Billing config for the connection.
Corresponds to the JSON property billingConfig
764 765 766 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 764 def billing_config @billing_config end |
#config_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional. Configuration for configuring the connection with an external system.
Corresponds to the JSON property configVariables
769 770 771 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 769 def config_variables @config_variables end |
#connection_revision ⇒ Fixnum
Output only. Connection revision. This field is only updated when the
connection is created or updated by User.
Corresponds to the JSON property connectionRevision
775 776 777 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 775 def connection_revision @connection_revision end |
#connector_version ⇒ String
Required. Connector version on which the connection is created. The format is:
projects//locations//providers//connectors//versions/* Only global
location is supported for ConnectorVersion resource.
Corresponds to the JSON property connectorVersion
782 783 784 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 782 def connector_version @connector_version end |
#connector_version_infra_config ⇒ Google::Apis::ConnectorsV1::ConnectorVersionInfraConfig
This configuration provides infra configs like rate limit threshold which need
to be configurable for every connector version
Corresponds to the JSON property connectorVersionInfraConfig
788 789 790 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 788 def connector_version_infra_config @connector_version_infra_config end |
#connector_version_launch_stage ⇒ String
Output only. Flag to mark the version indicating the launch stage.
Corresponds to the JSON property connectorVersionLaunchStage
793 794 795 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 793 def connector_version_launch_stage @connector_version_launch_stage end |
#create_time ⇒ String
Output only. Created time.
Corresponds to the JSON property createTime
798 799 800 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 798 def create_time @create_time end |
#description ⇒ String
Optional. Description of the resource.
Corresponds to the JSON property description
803 804 805 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 803 def description @description end |
#destination_configs ⇒ Array<Google::Apis::ConnectorsV1::DestinationConfig>
Optional. Configuration of the Connector's destination. Only accepted for
Connectors that accepts user defined destination(s).
Corresponds to the JSON property destinationConfigs
809 810 811 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 809 def destination_configs @destination_configs end |
#envoy_image_location ⇒ String
Output only. GCR location where the envoy image is stored. formatted like: gcr.
io/bucketName/imageName
Corresponds to the JSON property envoyImageLocation
815 816 817 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 815 def envoy_image_location @envoy_image_location end |
#eua_oauth_auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
Corresponds to the JSON property euaOauthAuthConfig
820 821 822 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 820 def eua_oauth_auth_config @eua_oauth_auth_config end |
#eventing_config ⇒ Google::Apis::ConnectorsV1::EventingConfig
Eventing Configuration of a connection next: 19
Corresponds to the JSON property eventingConfig
825 826 827 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 825 def eventing_config @eventing_config end |
#eventing_enablement_type ⇒ String
Optional. Eventing enablement type. Will be nil if eventing is not enabled.
Corresponds to the JSON property eventingEnablementType
830 831 832 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 830 def eventing_enablement_type @eventing_enablement_type end |
#eventing_runtime_data ⇒ Google::Apis::ConnectorsV1::EventingRuntimeData
Eventing runtime data has the details related to eventing managed by the
system.
Corresponds to the JSON property eventingRuntimeData
836 837 838 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 836 def eventing_runtime_data @eventing_runtime_data end |
#fallback_on_admin_credentials ⇒ Boolean Also known as: fallback_on_admin_credentials?
Optional. Fallback on admin credentials for the connection. If this both
auth_override_enabled and fallback_on_admin_credentials are set to true, the
connection will use the admin credentials if the dynamic auth header is not
present during auth override.
Corresponds to the JSON property fallbackOnAdminCredentials
844 845 846 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 844 def fallback_on_admin_credentials @fallback_on_admin_credentials end |
#host ⇒ String
Output only. The name of the Hostname of the Service Directory service with
TLS.
Corresponds to the JSON property host
851 852 853 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 851 def host @host end |
#image_location ⇒ String
Output only. GCR location where the runtime image is stored. formatted like:
gcr.io/bucketName/imageName
Corresponds to the JSON property imageLocation
857 858 859 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 857 def image_location @image_location end |
#is_trusted_tester ⇒ Boolean Also known as: is_trusted_tester?
Output only. Is trusted tester program enabled for the project.
Corresponds to the JSON property isTrustedTester
862 863 864 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 862 def is_trusted_tester @is_trusted_tester end |
#labels ⇒ Hash<String,String>
Optional. Resource labels to represent user-provided metadata. Refer to cloud
documentation on labels for more details. https://cloud.google.com/compute/
docs/labeling-resources
Corresponds to the JSON property labels
870 871 872 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 870 def labels @labels end |
#lock_config ⇒ Google::Apis::ConnectorsV1::LockConfig
Determines whether or no a connection is locked. If locked, a reason must be
specified.
Corresponds to the JSON property lockConfig
876 877 878 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 876 def lock_config @lock_config end |
#log_config ⇒ Google::Apis::ConnectorsV1::ConnectorsLogConfig
Log configuration for the connection.
Corresponds to the JSON property logConfig
881 882 883 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 881 def log_config @log_config end |
#name ⇒ String
Output only. Resource name of the Connection. Format: projects/project/
locations/location/connections/connection
Corresponds to the JSON property name
887 888 889 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 887 def name @name end |
#node_config ⇒ Google::Apis::ConnectorsV1::NodeConfig
Node configuration for the connection.
Corresponds to the JSON property nodeConfig
892 893 894 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 892 def node_config @node_config end |
#service_account ⇒ String
Optional. Service account needed for runtime plane to access Google Cloud
resources.
Corresponds to the JSON property serviceAccount
898 899 900 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 898 def service_account @service_account end |
#service_directory ⇒ String
Output only. The name of the Service Directory service name. Used for Private
Harpoon to resolve the ILB address. e.g. "projects/cloud-connectors-e2e-
testing/locations/us-central1/namespaces/istio-system/services/istio-
ingressgateway-connectors"
Corresponds to the JSON property serviceDirectory
906 907 908 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 906 def service_directory @service_directory end |
#ssl_config ⇒ Google::Apis::ConnectorsV1::SslConfig
SSL Configuration of a connection
Corresponds to the JSON property sslConfig
911 912 913 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 911 def ssl_config @ssl_config end |
#status ⇒ Google::Apis::ConnectorsV1::ConnectionStatus
ConnectionStatus indicates the state of the connection.
Corresponds to the JSON property status
916 917 918 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 916 def status @status end |
#subscription_type ⇒ String
Output only. This subscription type enum states the subscription type of the
project.
Corresponds to the JSON property subscriptionType
922 923 924 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 922 def subscription_type @subscription_type end |
#suspended ⇒ Boolean Also known as: suspended?
Optional. Suspended indicates if a user has suspended a connection or not.
Corresponds to the JSON property suspended
927 928 929 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 927 def suspended @suspended end |
#tls_service_directory ⇒ String
Output only. The name of the Service Directory service with TLS.
Corresponds to the JSON property tlsServiceDirectory
933 934 935 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 933 def tls_service_directory @tls_service_directory end |
#traffic_shaping_configs ⇒ Array<Google::Apis::ConnectorsV1::TrafficShapingConfig>
Optional. Traffic shaping configuration for the connection.
Corresponds to the JSON property trafficShapingConfigs
938 939 940 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 938 def traffic_shaping_configs @traffic_shaping_configs end |
#update_time ⇒ String
Output only. Updated time.
Corresponds to the JSON property updateTime
943 944 945 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 943 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 950 def update!(**args) @async_operations_enabled = args[:async_operations_enabled] if args.key?(:async_operations_enabled) @auth_config = args[:auth_config] if args.key?(:auth_config) @auth_override_enabled = args[:auth_override_enabled] if args.key?(:auth_override_enabled) @billing_config = args[:billing_config] if args.key?(:billing_config) @config_variables = args[:config_variables] if args.key?(:config_variables) @connection_revision = args[:connection_revision] if args.key?(:connection_revision) @connector_version = args[:connector_version] if args.key?(:connector_version) @connector_version_infra_config = args[:connector_version_infra_config] if args.key?(:connector_version_infra_config) @connector_version_launch_stage = args[:connector_version_launch_stage] if args.key?(:connector_version_launch_stage) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @destination_configs = args[:destination_configs] if args.key?(:destination_configs) @envoy_image_location = args[:envoy_image_location] if args.key?(:envoy_image_location) @eua_oauth_auth_config = args[:eua_oauth_auth_config] if args.key?(:eua_oauth_auth_config) @eventing_config = args[:eventing_config] if args.key?(:eventing_config) @eventing_enablement_type = args[:eventing_enablement_type] if args.key?(:eventing_enablement_type) @eventing_runtime_data = args[:eventing_runtime_data] if args.key?(:eventing_runtime_data) @fallback_on_admin_credentials = args[:fallback_on_admin_credentials] if args.key?(:fallback_on_admin_credentials) @host = args[:host] if args.key?(:host) @image_location = args[:image_location] if args.key?(:image_location) @is_trusted_tester = args[:is_trusted_tester] if args.key?(:is_trusted_tester) @labels = args[:labels] if args.key?(:labels) @lock_config = args[:lock_config] if args.key?(:lock_config) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @node_config = args[:node_config] if args.key?(:node_config) @service_account = args[:service_account] if args.key?(:service_account) @service_directory = args[:service_directory] if args.key?(:service_directory) @ssl_config = args[:ssl_config] if args.key?(:ssl_config) @status = args[:status] if args.key?(:status) @subscription_type = args[:subscription_type] if args.key?(:subscription_type) @suspended = args[:suspended] if args.key?(:suspended) @tls_service_directory = args[:tls_service_directory] if args.key?(:tls_service_directory) @traffic_shaping_configs = args[:traffic_shaping_configs] if args.key?(:traffic_shaping_configs) @update_time = args[:update_time] if args.key?(:update_time) end |