Class: Google::Apis::ConnectorsV1::ConnectorVersionInfraConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

This configuration provides infra configs like rate limit threshold which need to be configurable for every connector version

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectorVersionInfraConfig

Returns a new instance of ConnectorVersionInfraConfig.



1557
1558
1559
# File 'lib/google/apis/connectors_v1/classes.rb', line 1557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_ratelimit_window_secondsFixnum

Output only. The window used for ratelimiting runtime requests to connections. Corresponds to the JSON property connectionRatelimitWindowSeconds

Returns:

  • (Fixnum)


1504
1505
1506
# File 'lib/google/apis/connectors_v1/classes.rb', line 1504

def connection_ratelimit_window_seconds
  @connection_ratelimit_window_seconds
end

#deployment_modelString

Output only. Indicates whether connector is deployed on GKE/CloudRun Corresponds to the JSON property deploymentModel

Returns:

  • (String)


1509
1510
1511
# File 'lib/google/apis/connectors_v1/classes.rb', line 1509

def deployment_model
  @deployment_model
end

#deployment_model_migration_stateString

Output only. Status of the deployment model migration. Corresponds to the JSON property deploymentModelMigrationState

Returns:

  • (String)


1514
1515
1516
# File 'lib/google/apis/connectors_v1/classes.rb', line 1514

def deployment_model_migration_state
  @deployment_model_migration_state
end

#hpa_configGoogle::Apis::ConnectorsV1::HpaConfig

Autoscaling config for connector deployment system metrics. Corresponds to the JSON property hpaConfig



1519
1520
1521
# File 'lib/google/apis/connectors_v1/classes.rb', line 1519

def hpa_config
  @hpa_config
end

#internalclient_ratelimit_thresholdFixnum

Output only. Max QPS supported for internal requests originating from Connd. Corresponds to the JSON property internalclientRatelimitThreshold

Returns:

  • (Fixnum)


1524
1525
1526
# File 'lib/google/apis/connectors_v1/classes.rb', line 1524

def internalclient_ratelimit_threshold
  @internalclient_ratelimit_threshold
end

#max_instance_request_concurrencyFixnum

Output only. Max instance request concurrency. Corresponds to the JSON property maxInstanceRequestConcurrency

Returns:

  • (Fixnum)


1529
1530
1531
# File 'lib/google/apis/connectors_v1/classes.rb', line 1529

def max_instance_request_concurrency
  @max_instance_request_concurrency
end

#ratelimit_thresholdFixnum

Output only. Max QPS supported by the connector version before throttling of requests. Corresponds to the JSON property ratelimitThreshold

Returns:

  • (Fixnum)


1535
1536
1537
# File 'lib/google/apis/connectors_v1/classes.rb', line 1535

def ratelimit_threshold
  @ratelimit_threshold
end

#resource_limitsGoogle::Apis::ConnectorsV1::ResourceLimits

Resource limits defined for connection pods of a given connector type. Corresponds to the JSON property resourceLimits



1540
1541
1542
# File 'lib/google/apis/connectors_v1/classes.rb', line 1540

def resource_limits
  @resource_limits
end

#resource_requestsGoogle::Apis::ConnectorsV1::ResourceRequests

Resource requests defined for connection pods of a given connector type. Corresponds to the JSON property resourceRequests



1545
1546
1547
# File 'lib/google/apis/connectors_v1/classes.rb', line 1545

def resource_requests
  @resource_requests
end

#shared_deploymentString

Output only. The name of shared connector deployment. Corresponds to the JSON property sharedDeployment

Returns:

  • (String)


1550
1551
1552
# File 'lib/google/apis/connectors_v1/classes.rb', line 1550

def shared_deployment
  @shared_deployment
end

#tls_migration_stateString

Output only. Status of the TLS migration. Corresponds to the JSON property tlsMigrationState

Returns:

  • (String)


1555
1556
1557
# File 'lib/google/apis/connectors_v1/classes.rb', line 1555

def tls_migration_state
  @tls_migration_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/google/apis/connectors_v1/classes.rb', line 1562

def update!(**args)
  @connection_ratelimit_window_seconds = args[:connection_ratelimit_window_seconds] if args.key?(:connection_ratelimit_window_seconds)
  @deployment_model = args[:deployment_model] if args.key?(:deployment_model)
  @deployment_model_migration_state = args[:deployment_model_migration_state] if args.key?(:deployment_model_migration_state)
  @hpa_config = args[:hpa_config] if args.key?(:hpa_config)
  @internalclient_ratelimit_threshold = args[:internalclient_ratelimit_threshold] if args.key?(:internalclient_ratelimit_threshold)
  @max_instance_request_concurrency = args[:max_instance_request_concurrency] if args.key?(:max_instance_request_concurrency)
  @ratelimit_threshold = args[:ratelimit_threshold] if args.key?(:ratelimit_threshold)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
  @resource_requests = args[:resource_requests] if args.key?(:resource_requests)
  @shared_deployment = args[:shared_deployment] if args.key?(:shared_deployment)
  @tls_migration_state = args[:tls_migration_state] if args.key?(:tls_migration_state)
end