Class: Google::Apis::ConnectorsV1::CustomConnectorVersion
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::CustomConnectorVersion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
CustomConnectorVersion indicates a specific version of a connector.
Instance Attribute Summary collapse
-
#async_operations_support ⇒ Boolean
(also: #async_operations_support?)
Optional.
-
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
-
#auth_config_templates ⇒ Array<Google::Apis::ConnectorsV1::AuthConfigTemplate>
Optional.
-
#auth_override_support ⇒ Boolean
(also: #auth_override_support?)
Optional.
-
#backend_variable_templates ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariableTemplate>
Optional.
-
#create_time ⇒ String
Output only.
-
#destination_configs ⇒ Array<Google::Apis::ConnectorsV1::DestinationConfig>
Optional.
-
#enable_backend_destination_config ⇒ Boolean
(also: #enable_backend_destination_config?)
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#partner_metadata ⇒ Google::Apis::ConnectorsV1::PartnerMetadata
Partner metadata details.
-
#publish_status ⇒ Google::Apis::ConnectorsV1::PublishStatus
Publish status of a custom connector.
-
#service_account ⇒ String
Optional.
-
#spec_location ⇒ String
Optional.
-
#spec_server_urls ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomConnectorVersion
constructor
A new instance of CustomConnectorVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomConnectorVersion
Returns a new instance of CustomConnectorVersion.
1855 1856 1857 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#async_operations_support ⇒ Boolean Also known as: async_operations_support?
Optional. Indicates if Async Operations/Connector Job is supported. This is
only available for SDK based custom connectors.
Corresponds to the JSON property asyncOperationsSupport
1753 1754 1755 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1753 def async_operations_support @async_operations_support end |
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
Corresponds to the JSON property authConfig
1759 1760 1761 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1759 def auth_config @auth_config end |
#auth_config_templates ⇒ Array<Google::Apis::ConnectorsV1::AuthConfigTemplate>
Optional. Auth Config Templates is only used when connector backend is enabled.
This is used to specify the auth configs supported by the connector backend
service to talk to the actual application backend.
Corresponds to the JSON property authConfigTemplates
1766 1767 1768 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1766 def auth_config_templates @auth_config_templates end |
#auth_override_support ⇒ Boolean Also known as: auth_override_support?
Optional. Auth override support.
Corresponds to the JSON property authOverrideSupport
1771 1772 1773 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1771 def auth_override_support @auth_override_support end |
#backend_variable_templates ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariableTemplate>
Optional. Backend variable templates is only used when connector backend is
enabled. This is used to specify the variables required by the connector
backend service to talk to the actual application backend. This translates to
additional variable templates in the connection config.
Corresponds to the JSON property backendVariableTemplates
1780 1781 1782 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1780 def backend_variable_templates @backend_variable_templates end |
#create_time ⇒ String
Output only. Created time.
Corresponds to the JSON property createTime
1785 1786 1787 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1785 def create_time @create_time end |
#destination_configs ⇒ Array<Google::Apis::ConnectorsV1::DestinationConfig>
Optional. Destination config(s) for accessing connector service (facade). This
is used only when enable_backend_destination_config is true.
Corresponds to the JSON property destinationConfigs
1791 1792 1793 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1791 def destination_configs @destination_configs end |
#enable_backend_destination_config ⇒ Boolean Also known as: enable_backend_destination_config?
Optional. Indicates if an intermediatory connectorservice is used as backend.
When this is enabled, the connector destination and connector auth config are
required. For SDK based connectors, this is always enabled.
Corresponds to the JSON property enableBackendDestinationConfig
1798 1799 1800 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1798 def enable_backend_destination_config @enable_backend_destination_config end |
#labels ⇒ Hash<String,String>
Optional. Resource labels to represent user-provided metadata. Refer to cloud
documentation on labels for more details. https://cloud.google.com/compute/
docs/labeling-resources
Corresponds to the JSON property labels
1806 1807 1808 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1806 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of the Version. Format: projects/
project/locations/location/customConnectors/custom_connector/
customConnectorVersions/custom_connector_version
Corresponds to the JSON property name
1813 1814 1815 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1813 def name @name end |
#partner_metadata ⇒ Google::Apis::ConnectorsV1::PartnerMetadata
Partner metadata details. This will be populated when publishing the custom
connector as a partner connector version. On publishing, parntner connector
version will be created using the fields in PartnerMetadata.
Corresponds to the JSON property partnerMetadata
1820 1821 1822 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1820 def @partner_metadata end |
#publish_status ⇒ Google::Apis::ConnectorsV1::PublishStatus
Publish status of a custom connector.
Corresponds to the JSON property publishStatus
1825 1826 1827 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1825 def publish_status @publish_status end |
#service_account ⇒ String
Optional. Service account used by runtime plane to access auth config secrets.
Corresponds to the JSON property serviceAccount
1830 1831 1832 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1830 def service_account @service_account end |
#spec_location ⇒ String
Optional. Location of the custom connector spec. This is only used for Open
API based custom connectors. The location can be either a public url like
https://public-url.com/spec Or a Google Cloud Storage location like gs:///.
Corresponds to the JSON property specLocation
1837 1838 1839 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1837 def spec_location @spec_location end |
#spec_server_urls ⇒ Array<String>
Output only. Server URLs parsed from the Open API spec. This is only used for
Open API based custom connectors.
Corresponds to the JSON property specServerUrls
1843 1844 1845 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1843 def spec_server_urls @spec_server_urls end |
#state ⇒ String
Output only. State of the custom connector version.
Corresponds to the JSON property state
1848 1849 1850 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1848 def state @state end |
#update_time ⇒ String
Output only. Updated time.
Corresponds to the JSON property updateTime
1853 1854 1855 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1853 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1860 def update!(**args) @async_operations_support = args[:async_operations_support] if args.key?(:async_operations_support) @auth_config = args[:auth_config] if args.key?(:auth_config) @auth_config_templates = args[:auth_config_templates] if args.key?(:auth_config_templates) @auth_override_support = args[:auth_override_support] if args.key?(:auth_override_support) @backend_variable_templates = args[:backend_variable_templates] if args.key?(:backend_variable_templates) @create_time = args[:create_time] if args.key?(:create_time) @destination_configs = args[:destination_configs] if args.key?(:destination_configs) @enable_backend_destination_config = args[:enable_backend_destination_config] if args.key?(:enable_backend_destination_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata) @publish_status = args[:publish_status] if args.key?(:publish_status) @service_account = args[:service_account] if args.key?(:service_account) @spec_location = args[:spec_location] if args.key?(:spec_location) @spec_server_urls = args[:spec_server_urls] if args.key?(:spec_server_urls) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |