Class: Google::Apis::ConnectorsV1::CustomConnectorVersion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

CustomConnectorVersion indicates a specific version of a connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomConnectorVersion

Returns a new instance of CustomConnectorVersion.



1803
1804
1805
# File 'lib/google/apis/connectors_v1/classes.rb', line 1803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#async_operations_supportBoolean Also known as: async_operations_support?

Optional. Indicates if Async Operations/Connector Job is supported. This is only available for SDK based custom connectors. Corresponds to the JSON property asyncOperationsSupport

Returns:

  • (Boolean)


1701
1702
1703
# File 'lib/google/apis/connectors_v1/classes.rb', line 1701

def async_operations_support
  @async_operations_support
end

#auth_configGoogle::Apis::ConnectorsV1::AuthConfig

AuthConfig defines details of a authentication type. Corresponds to the JSON property authConfig



1707
1708
1709
# File 'lib/google/apis/connectors_v1/classes.rb', line 1707

def auth_config
  @auth_config
end

#auth_config_templatesArray<Google::Apis::ConnectorsV1::AuthConfigTemplate>

Optional. Auth Config Templates is only used when connector backend is enabled. This is used to specify the auth configs supported by the connector backend service to talk to the actual application backend. Corresponds to the JSON property authConfigTemplates



1714
1715
1716
# File 'lib/google/apis/connectors_v1/classes.rb', line 1714

def auth_config_templates
  @auth_config_templates
end

#auth_override_supportBoolean Also known as: auth_override_support?

Optional. Auth override support. Corresponds to the JSON property authOverrideSupport

Returns:

  • (Boolean)


1719
1720
1721
# File 'lib/google/apis/connectors_v1/classes.rb', line 1719

def auth_override_support
  @auth_override_support
end

#backend_variable_templatesArray<Google::Apis::ConnectorsV1::ConfigVariableTemplate>

Optional. Backend variable templates is only used when connector backend is enabled. This is used to specify the variables required by the connector backend service to talk to the actual application backend. This translates to additional variable templates in the connection config. Corresponds to the JSON property backendVariableTemplates



1728
1729
1730
# File 'lib/google/apis/connectors_v1/classes.rb', line 1728

def backend_variable_templates
  @backend_variable_templates
end

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


1733
1734
1735
# File 'lib/google/apis/connectors_v1/classes.rb', line 1733

def create_time
  @create_time
end

#destination_configsArray<Google::Apis::ConnectorsV1::DestinationConfig>

Optional. Destination config(s) for accessing connector service (facade). This is used only when enable_backend_destination_config is true. Corresponds to the JSON property destinationConfigs



1739
1740
1741
# File 'lib/google/apis/connectors_v1/classes.rb', line 1739

def destination_configs
  @destination_configs
end

#enable_backend_destination_configBoolean Also known as: enable_backend_destination_config?

Optional. Indicates if an intermediatory connectorservice is used as backend. When this is enabled, the connector destination and connector auth config are required. For SDK based connectors, this is always enabled. Corresponds to the JSON property enableBackendDestinationConfig

Returns:

  • (Boolean)


1746
1747
1748
# File 'lib/google/apis/connectors_v1/classes.rb', line 1746

def enable_backend_destination_config
  @enable_backend_destination_config
end

#labelsHash<String,String>

Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/ docs/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1754
1755
1756
# File 'lib/google/apis/connectors_v1/classes.rb', line 1754

def labels
  @labels
end

#nameString

Output only. Identifier. Resource name of the Version. Format: projects/ project/locations/location/customConnectors/custom_connector/ customConnectorVersions/custom_connector_version Corresponds to the JSON property name

Returns:

  • (String)


1761
1762
1763
# File 'lib/google/apis/connectors_v1/classes.rb', line 1761

def name
  @name
end

#partner_metadataGoogle::Apis::ConnectorsV1::PartnerMetadata

Partner metadata details. This will be populated when publishing the custom connector as a partner connector version. On publishing, parntner connector version will be created using the fields in PartnerMetadata. Corresponds to the JSON property partnerMetadata



1768
1769
1770
# File 'lib/google/apis/connectors_v1/classes.rb', line 1768

def 
  @partner_metadata
end

#publish_statusGoogle::Apis::ConnectorsV1::PublishStatus

Publish status of a custom connector. Corresponds to the JSON property publishStatus



1773
1774
1775
# File 'lib/google/apis/connectors_v1/classes.rb', line 1773

def publish_status
  @publish_status
end

#service_accountString

Optional. Service account used by runtime plane to access auth config secrets. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1778
1779
1780
# File 'lib/google/apis/connectors_v1/classes.rb', line 1778

def 
  @service_account
end

#spec_locationString

Optional. Location of the custom connector spec. This is only used for Open API based custom connectors. The location can be either a public url like https://public-url.com/spec Or a Google Cloud Storage location like gs:///. Corresponds to the JSON property specLocation

Returns:

  • (String)


1785
1786
1787
# File 'lib/google/apis/connectors_v1/classes.rb', line 1785

def spec_location
  @spec_location
end

#spec_server_urlsArray<String>

Output only. Server URLs parsed from the Open API spec. This is only used for Open API based custom connectors. Corresponds to the JSON property specServerUrls

Returns:

  • (Array<String>)


1791
1792
1793
# File 'lib/google/apis/connectors_v1/classes.rb', line 1791

def spec_server_urls
  @spec_server_urls
end

#stateString

Output only. State of the custom connector version. Corresponds to the JSON property state

Returns:

  • (String)


1796
1797
1798
# File 'lib/google/apis/connectors_v1/classes.rb', line 1796

def state
  @state
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1801
1802
1803
# File 'lib/google/apis/connectors_v1/classes.rb', line 1801

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
# File 'lib/google/apis/connectors_v1/classes.rb', line 1808

def update!(**args)
  @async_operations_support = args[:async_operations_support] if args.key?(:async_operations_support)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @auth_config_templates = args[:auth_config_templates] if args.key?(:auth_config_templates)
  @auth_override_support = args[:auth_override_support] if args.key?(:auth_override_support)
  @backend_variable_templates = args[:backend_variable_templates] if args.key?(:backend_variable_templates)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination_configs = args[:destination_configs] if args.key?(:destination_configs)
  @enable_backend_destination_config = args[:enable_backend_destination_config] if args.key?(:enable_backend_destination_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @publish_status = args[:publish_status] if args.key?(:publish_status)
  @service_account = args[:service_account] if args.key?(:service_account)
  @spec_location = args[:spec_location] if args.key?(:spec_location)
  @spec_server_urls = args[:spec_server_urls] if args.key?(:spec_server_urls)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end