Class: Google::Apis::ConnectorsV1::DailyCycle

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Time window specified for daily operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyCycle

Returns a new instance of DailyCycle.



1845
1846
1847
# File 'lib/google/apis/connectors_v1/classes.rb', line 1845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. Duration of the time window, set by service producer. Corresponds to the JSON property duration

Returns:

  • (String)


1836
1837
1838
# File 'lib/google/apis/connectors_v1/classes.rb', line 1836

def duration
  @duration
end

#start_timeGoogle::Apis::ConnectorsV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



1843
1844
1845
# File 'lib/google/apis/connectors_v1/classes.rb', line 1843

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1850
1851
1852
1853
# File 'lib/google/apis/connectors_v1/classes.rb', line 1850

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end