Class: Google::Apis::ConnectorsV1::DenyMaintenancePeriod
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::DenyMaintenancePeriod
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
DenyMaintenancePeriod definition. Maintenance is forbidden within the deny period. The start_date must be less than the end_date.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::ConnectorsV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::ConnectorsV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::ConnectorsV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DenyMaintenancePeriod
constructor
A new instance of DenyMaintenancePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DenyMaintenancePeriod
Returns a new instance of DenyMaintenancePeriod.
2010 2011 2012 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::ConnectorsV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
1989 1990 1991 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 1989 def end_date @end_date end |
#start_date ⇒ Google::Apis::ConnectorsV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
2001 2002 2003 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2001 def start_date @start_date end |
#time ⇒ Google::Apis::ConnectorsV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
2008 2009 2010 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2008 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2015 2016 2017 2018 2019 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2015 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |