Class: Google::Apis::ConnectorsV1::EgressControlConfig
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EgressControlConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Egress control config for connector runtime. These configurations define the rules to identify which outbound domains/hosts needs to be whitelisted. It may be a static information for a particular connector version or it is derived from the configurations provided by the customer in Connection resource.
Instance Attribute Summary collapse
-
#access_mode ⇒ String
Optional.
-
#additional_extraction_rules ⇒ Google::Apis::ConnectorsV1::ExtractionRules
Extraction Rules to identity the backends from customer provided configuration in Connection resource.
-
#allowlisted_project_numbers ⇒ Array<String>
Optional.
-
#backends ⇒ String
Static Comma separated backends which are common for all Connection resources.
-
#extraction_rules ⇒ Google::Apis::ConnectorsV1::ExtractionRules
Extraction Rules to identity the backends from customer provided configuration in Connection resource.
-
#launch_environment ⇒ String
Launch environment for egress control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EgressControlConfig
constructor
A new instance of EgressControlConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EgressControlConfig
Returns a new instance of EgressControlConfig.
2181 2182 2183 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_mode ⇒ String
Optional. Access mode for egress control.
Corresponds to the JSON property accessMode
2150 2151 2152 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2150 def access_mode @access_mode end |
#additional_extraction_rules ⇒ Google::Apis::ConnectorsV1::ExtractionRules
Extraction Rules to identity the backends from customer provided configuration
in Connection resource.
Corresponds to the JSON property additionalExtractionRules
2156 2157 2158 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2156 def additional_extraction_rules @additional_extraction_rules end |
#allowlisted_project_numbers ⇒ Array<String>
Optional. Used when access_mode is RESTRICTED or ACCESS_MODE_UNSPECIFIED.
Corresponds to the JSON property allowlistedProjectNumbers
2161 2162 2163 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2161 def allowlisted_project_numbers @allowlisted_project_numbers end |
#backends ⇒ String
Static Comma separated backends which are common for all Connection resources.
Supported formats for each backend are host:port or just host (host can be ip
address or domain name).
Corresponds to the JSON property backends
2168 2169 2170 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2168 def backends @backends end |
#extraction_rules ⇒ Google::Apis::ConnectorsV1::ExtractionRules
Extraction Rules to identity the backends from customer provided configuration
in Connection resource.
Corresponds to the JSON property extractionRules
2174 2175 2176 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2174 def extraction_rules @extraction_rules end |
#launch_environment ⇒ String
Launch environment for egress control.
Corresponds to the JSON property launchEnvironment
2179 2180 2181 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2179 def launch_environment @launch_environment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2186 def update!(**args) @access_mode = args[:access_mode] if args.key?(:access_mode) @additional_extraction_rules = args[:additional_extraction_rules] if args.key?(:additional_extraction_rules) @allowlisted_project_numbers = args[:allowlisted_project_numbers] if args.key?(:allowlisted_project_numbers) @backends = args[:backends] if args.key?(:backends) @extraction_rules = args[:extraction_rules] if args.key?(:extraction_rules) @launch_environment = args[:launch_environment] if args.key?(:launch_environment) end |