Class: Google::Apis::ConnectorsV1::EndUserAuthentication

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

AuthConfig defines details of a authentication type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthentication

Returns a new instance of EndUserAuthentication.



2354
2355
2356
# File 'lib/google/apis/connectors_v1/classes.rb', line 2354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_variablesArray<Google::Apis::ConnectorsV1::EndUserAuthenticationConfigVariable>

Optional. Config variables for the EndUserAuthentication. Corresponds to the JSON property configVariables



2297
2298
2299
# File 'lib/google/apis/connectors_v1/classes.rb', line 2297

def config_variables
  @config_variables
end

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


2302
2303
2304
# File 'lib/google/apis/connectors_v1/classes.rb', line 2302

def create_time
  @create_time
end

#destination_configsArray<Google::Apis::ConnectorsV1::DestinationConfig>

Optional. Destination configs for the EndUserAuthentication. Corresponds to the JSON property destinationConfigs



2307
2308
2309
# File 'lib/google/apis/connectors_v1/classes.rb', line 2307

def destination_configs
  @destination_configs
end

#end_user_authentication_configGoogle::Apis::ConnectorsV1::EndUserAuthenticationConfig

EndUserAuthenticationConfig defines details of a authentication configuration for EUC Corresponds to the JSON property endUserAuthenticationConfig



2313
2314
2315
# File 'lib/google/apis/connectors_v1/classes.rb', line 2313

def end_user_authentication_config
  @end_user_authentication_config
end

#labelsArray<String>

Optional. Labels for the EndUserAuthentication. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


2318
2319
2320
# File 'lib/google/apis/connectors_v1/classes.rb', line 2318

def labels
  @labels
end

#nameString

Required. Identifier. Resource name of the EndUserAuthentication. Format: projects/project/locations/location/connections/connection/ endUserAuthentications/end_user_authentication Corresponds to the JSON property name

Returns:

  • (String)


2325
2326
2327
# File 'lib/google/apis/connectors_v1/classes.rb', line 2325

def name
  @name
end

#notify_endpoint_destinationGoogle::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination

Message for NotifyEndpointDestination Destination to hit when the refresh token is expired. Corresponds to the JSON property notifyEndpointDestination



2331
2332
2333
# File 'lib/google/apis/connectors_v1/classes.rb', line 2331

def notify_endpoint_destination
  @notify_endpoint_destination
end

#rolesArray<String>

Optional. Roles for the EndUserAuthentication. Corresponds to the JSON property roles

Returns:

  • (Array<String>)


2336
2337
2338
# File 'lib/google/apis/connectors_v1/classes.rb', line 2336

def roles
  @roles
end

#statusGoogle::Apis::ConnectorsV1::EndUserAuthenticationEndUserAuthenticationStatus

EndUserAuthentication Status denotes the status of the EndUserAuthentication resource. Corresponds to the JSON property status



2342
2343
2344
# File 'lib/google/apis/connectors_v1/classes.rb', line 2342

def status
  @status
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2347
2348
2349
# File 'lib/google/apis/connectors_v1/classes.rb', line 2347

def update_time
  @update_time
end

#user_idString

Optional. The user id of the user. Corresponds to the JSON property userId

Returns:

  • (String)


2352
2353
2354
# File 'lib/google/apis/connectors_v1/classes.rb', line 2352

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
# File 'lib/google/apis/connectors_v1/classes.rb', line 2359

def update!(**args)
  @config_variables = args[:config_variables] if args.key?(:config_variables)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination_configs = args[:destination_configs] if args.key?(:destination_configs)
  @end_user_authentication_config = args[:end_user_authentication_config] if args.key?(:end_user_authentication_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notify_endpoint_destination = args[:notify_endpoint_destination] if args.key?(:notify_endpoint_destination)
  @roles = args[:roles] if args.key?(:roles)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end