Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EndUserAuthenticationConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
EndUserAuthenticationConfig defines details of a authentication configuration for EUC
Instance Attribute Summary collapse
-
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::EndUserAuthenticationConfigVariable>
Optional.
-
#auth_key ⇒ String
Identifier key for auth config Corresponds to the JSON property
authKey. -
#auth_type ⇒ String
The type of authentication configured.
-
#oauth2_auth_code_flow ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlow
Parameters to support Oauth 2.0 Auth Code Grant Authentication.
-
#oauth2_auth_code_flow_google_managed ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged
Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client.
-
#oauth2_client_credentials ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2ClientCredentials
Parameters to support Oauth 2.0 Client Credentials Grant Authentication.
-
#oauth2_jwt_bearer ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2JwtBearer
Parameters to support JSON Web Token (JWT) Profile for Oauth 2.0 Authorization Grant based authentication.
-
#ssh_public_key ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigSshPublicKey
Parameters to support Ssh public key Authentication.
-
#user_password ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigUserPassword
Parameters to support Username and Password Authentication.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndUserAuthenticationConfig
constructor
A new instance of EndUserAuthenticationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndUserAuthenticationConfig
Returns a new instance of EndUserAuthenticationConfig.
2430 2431 2432 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::EndUserAuthenticationConfigVariable>
Optional. List containing additional auth configs.
Corresponds to the JSON property additionalVariables
2382 2383 2384 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2382 def additional_variables @additional_variables end |
#auth_key ⇒ String
Identifier key for auth config
Corresponds to the JSON property authKey
2387 2388 2389 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2387 def auth_key @auth_key end |
#auth_type ⇒ String
The type of authentication configured.
Corresponds to the JSON property authType
2392 2393 2394 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2392 def auth_type @auth_type end |
#oauth2_auth_code_flow ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlow
Parameters to support Oauth 2.0 Auth Code Grant Authentication. See https://
www.rfc-editor.org/rfc/rfc6749#section-1.3.1 for more details.
Corresponds to the JSON property oauth2AuthCodeFlow
2398 2399 2400 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2398 def oauth2_auth_code_flow @oauth2_auth_code_flow end |
#oauth2_auth_code_flow_google_managed ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged
Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google
Provided OAuth Client. See https://tools.ietf.org/html/rfc6749#section-1.3.1
for more details.
Corresponds to the JSON property oauth2AuthCodeFlowGoogleManaged
2405 2406 2407 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2405 def oauth2_auth_code_flow_google_managed @oauth2_auth_code_flow_google_managed end |
#oauth2_client_credentials ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2ClientCredentials
Parameters to support Oauth 2.0 Client Credentials Grant Authentication. See
https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details.
Corresponds to the JSON property oauth2ClientCredentials
2411 2412 2413 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2411 def oauth2_client_credentials @oauth2_client_credentials end |
#oauth2_jwt_bearer ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2JwtBearer
Parameters to support JSON Web Token (JWT) Profile for Oauth 2.0 Authorization
Grant based authentication. See https://tools.ietf.org/html/rfc7523 for more
details.
Corresponds to the JSON property oauth2JwtBearer
2418 2419 2420 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2418 def oauth2_jwt_bearer @oauth2_jwt_bearer end |
#ssh_public_key ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigSshPublicKey
Parameters to support Ssh public key Authentication.
Corresponds to the JSON property sshPublicKey
2423 2424 2425 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2423 def ssh_public_key @ssh_public_key end |
#user_password ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationConfigUserPassword
Parameters to support Username and Password Authentication.
Corresponds to the JSON property userPassword
2428 2429 2430 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2428 def user_password @user_password end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2435 def update!(**args) @additional_variables = args[:additional_variables] if args.key?(:additional_variables) @auth_key = args[:auth_key] if args.key?(:auth_key) @auth_type = args[:auth_type] if args.key?(:auth_type) @oauth2_auth_code_flow = args[:oauth2_auth_code_flow] if args.key?(:oauth2_auth_code_flow) @oauth2_auth_code_flow_google_managed = args[:oauth2_auth_code_flow_google_managed] if args.key?(:oauth2_auth_code_flow_google_managed) @oauth2_client_credentials = args[:oauth2_client_credentials] if args.key?(:oauth2_client_credentials) @oauth2_jwt_bearer = args[:oauth2_jwt_bearer] if args.key?(:oauth2_jwt_bearer) @ssh_public_key = args[:ssh_public_key] if args.key?(:ssh_public_key) @user_password = args[:user_password] if args.key?(:user_password) end |