Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client. See https://tools.ietf.org/html/rfc6749#section-1.3.1 for more details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged

Returns a new instance of EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged.



2545
2546
2547
# File 'lib/google/apis/connectors_v1/classes.rb', line 2545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_codeString

Optional. Authorization code to be exchanged for access and refresh tokens. Corresponds to the JSON property authCode

Returns:

  • (String)


2527
2528
2529
# File 'lib/google/apis/connectors_v1/classes.rb', line 2527

def auth_code
  @auth_code
end

#oauth_token_dataGoogle::Apis::ConnectorsV1::OAuthTokenData

pass only at create and not update using updateMask Auth Code Data Corresponds to the JSON property oauthTokenData



2532
2533
2534
# File 'lib/google/apis/connectors_v1/classes.rb', line 2532

def oauth_token_data
  @oauth_token_data
end

#redirect_uriString

Optional. Redirect URI to be provided during the auth code exchange. Corresponds to the JSON property redirectUri

Returns:

  • (String)


2537
2538
2539
# File 'lib/google/apis/connectors_v1/classes.rb', line 2537

def redirect_uri
  @redirect_uri
end

#scopesArray<String>

Required. Scopes the connection will request when the user performs the auth code flow. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


2543
2544
2545
# File 'lib/google/apis/connectors_v1/classes.rb', line 2543

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2550
2551
2552
2553
2554
2555
# File 'lib/google/apis/connectors_v1/classes.rb', line 2550

def update!(**args)
  @auth_code = args[:auth_code] if args.key?(:auth_code)
  @oauth_token_data = args[:oauth_token_data] if args.key?(:oauth_token_data)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @scopes = args[:scopes] if args.key?(:scopes)
end