Class: Google::Apis::ConnectorsV1::EndUserAuthenticationConfigVariable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

EndUserAuthenticationConfigVariable represents a configuration variable present in a EndUserAuthentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthenticationConfigVariable

Returns a new instance of EndUserAuthenticationConfigVariable.



2735
2736
2737
# File 'lib/google/apis/connectors_v1/classes.rb', line 2735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Value is a bool. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


2712
2713
2714
# File 'lib/google/apis/connectors_v1/classes.rb', line 2712

def bool_value
  @bool_value
end

#int_valueFixnum

Value is an integer Corresponds to the JSON property intValue

Returns:

  • (Fixnum)


2718
2719
2720
# File 'lib/google/apis/connectors_v1/classes.rb', line 2718

def int_value
  @int_value
end

#keyString

Required. Key of the config variable. Corresponds to the JSON property key

Returns:

  • (String)


2723
2724
2725
# File 'lib/google/apis/connectors_v1/classes.rb', line 2723

def key
  @key
end

#secret_valueGoogle::Apis::ConnectorsV1::EuaSecret

EUASecret provides a reference to entries in Secret Manager. Corresponds to the JSON property secretValue



2728
2729
2730
# File 'lib/google/apis/connectors_v1/classes.rb', line 2728

def secret_value
  @secret_value
end

#string_valueString

Value is a string. Corresponds to the JSON property stringValue

Returns:

  • (String)


2733
2734
2735
# File 'lib/google/apis/connectors_v1/classes.rb', line 2733

def string_value
  @string_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2740
2741
2742
2743
2744
2745
2746
# File 'lib/google/apis/connectors_v1/classes.rb', line 2740

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @int_value = args[:int_value] if args.key?(:int_value)
  @key = args[:key] if args.key?(:key)
  @secret_value = args[:secret_value] if args.key?(:secret_value)
  @string_value = args[:string_value] if args.key?(:string_value)
end