Class: Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Message for NotifyEndpointDestination Destination to hit when the refresh token is expired.
Instance Attribute Summary collapse
-
#endpoint ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestinationEndPoint
Endpoint message includes details of the Destination endpoint.
-
#service_account ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndUserAuthenticationNotifyEndpointDestination
constructor
A new instance of EndUserAuthenticationNotifyEndpointDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndUserAuthenticationNotifyEndpointDestination
Returns a new instance of EndUserAuthenticationNotifyEndpointDestination.
2849 2850 2851 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestinationEndPoint
Endpoint message includes details of the Destination endpoint.
Corresponds to the JSON property endpoint
2837 2838 2839 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2837 def endpoint @endpoint end |
#service_account ⇒ String
Required. Service account needed for runtime plane to notify the backend.
Corresponds to the JSON property serviceAccount
2842 2843 2844 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2842 def service_account @service_account end |
#type ⇒ String
Required. type of the destination
Corresponds to the JSON property type
2847 2848 2849 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2847 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2854 2855 2856 2857 2858 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2854 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @service_account = args[:service_account] if args.key?(:service_account) @type = args[:type] if args.key?(:type) end |