Class: Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Message for NotifyEndpointDestination Destination to hit when the refresh token is expired.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndUserAuthenticationNotifyEndpointDestination

Returns a new instance of EndUserAuthenticationNotifyEndpointDestination.



2795
2796
2797
# File 'lib/google/apis/connectors_v1/classes.rb', line 2795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointGoogle::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestinationEndPoint

Endpoint message includes details of the Destination endpoint. Corresponds to the JSON property endpoint



2783
2784
2785
# File 'lib/google/apis/connectors_v1/classes.rb', line 2783

def endpoint
  @endpoint
end

#service_accountString

Required. Service account needed for runtime plane to notify the backend. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2788
2789
2790
# File 'lib/google/apis/connectors_v1/classes.rb', line 2788

def 
  @service_account
end

#typeString

Required. type of the destination Corresponds to the JSON property type

Returns:

  • (String)


2793
2794
2795
# File 'lib/google/apis/connectors_v1/classes.rb', line 2793

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2800
2801
2802
2803
2804
# File 'lib/google/apis/connectors_v1/classes.rb', line 2800

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @service_account = args[:service_account] if args.key?(:service_account)
  @type = args[:type] if args.key?(:type)
end