Class: Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestination
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Message for NotifyEndpointDestination Destination to hit when the refresh token is expired.
Instance Attribute Summary collapse
-
#endpoint ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestinationEndPoint
Endpoint message includes details of the Destination endpoint.
-
#service_account ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndUserAuthenticationNotifyEndpointDestination
constructor
A new instance of EndUserAuthenticationNotifyEndpointDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndUserAuthenticationNotifyEndpointDestination
Returns a new instance of EndUserAuthenticationNotifyEndpointDestination.
2795 2796 2797 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ Google::Apis::ConnectorsV1::EndUserAuthenticationNotifyEndpointDestinationEndPoint
Endpoint message includes details of the Destination endpoint.
Corresponds to the JSON property endpoint
2783 2784 2785 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2783 def endpoint @endpoint end |
#service_account ⇒ String
Required. Service account needed for runtime plane to notify the backend.
Corresponds to the JSON property serviceAccount
2788 2789 2790 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2788 def service_account @service_account end |
#type ⇒ String
Required. type of the destination
Corresponds to the JSON property type
2793 2794 2795 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2793 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2800 2801 2802 2803 2804 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2800 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @service_account = args[:service_account] if args.key?(:service_account) @type = args[:type] if args.key?(:type) end |