Class: Google::Apis::ConnectorsV1::EventSubscription
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EventSubscription
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
represents the Connector's EventSubscription resource
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#destinations ⇒ Google::Apis::ConnectorsV1::EventSubscriptionDestination
Message for EventSubscription Destination to act on receiving an event Corresponds to the JSON property
destinations. -
#event_type_id ⇒ String
Optional.
-
#jms ⇒ Google::Apis::ConnectorsV1::Jms
JMS message denotes the source of the event Corresponds to the JSON property
jms. -
#name ⇒ String
Required.
-
#status ⇒ Google::Apis::ConnectorsV1::EventSubscriptionStatus
EventSubscription Status denotes the status of the EventSubscription resource.
-
#subscriber ⇒ String
Optional.
-
#subscriber_link ⇒ String
Optional.
-
#trigger_config_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventSubscription
constructor
A new instance of EventSubscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventSubscription
Returns a new instance of EventSubscription.
3032 3033 3034 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Created time.
Corresponds to the JSON property createTime
2983 2984 2985 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2983 def create_time @create_time end |
#destinations ⇒ Google::Apis::ConnectorsV1::EventSubscriptionDestination
Message for EventSubscription Destination to act on receiving an event
Corresponds to the JSON property destinations
2988 2989 2990 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2988 def destinations @destinations end |
#event_type_id ⇒ String
Optional. Event type id of the event of current EventSubscription.
Corresponds to the JSON property eventTypeId
2993 2994 2995 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2993 def event_type_id @event_type_id end |
#jms ⇒ Google::Apis::ConnectorsV1::Jms
JMS message denotes the source of the event
Corresponds to the JSON property jms
2998 2999 3000 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 2998 def jms @jms end |
#name ⇒ String
Required. Identifier. Resource name of the EventSubscription. Format: projects/
project/locations/location/connections/connection/eventSubscriptions/
event_subscription
Corresponds to the JSON property name
3005 3006 3007 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3005 def name @name end |
#status ⇒ Google::Apis::ConnectorsV1::EventSubscriptionStatus
EventSubscription Status denotes the status of the EventSubscription resource.
Corresponds to the JSON property status
3010 3011 3012 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3010 def status @status end |
#subscriber ⇒ String
Optional. name of the Subscriber for the current EventSubscription.
Corresponds to the JSON property subscriber
3015 3016 3017 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3015 def subscriber @subscriber end |
#subscriber_link ⇒ String
Optional. Link for Subscriber of the current EventSubscription.
Corresponds to the JSON property subscriberLink
3020 3021 3022 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3020 def subscriber_link @subscriber_link end |
#trigger_config_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional. Configuration for configuring the trigger
Corresponds to the JSON property triggerConfigVariables
3025 3026 3027 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3025 def trigger_config_variables @trigger_config_variables end |
#update_time ⇒ String
Output only. Updated time.
Corresponds to the JSON property updateTime
3030 3031 3032 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3030 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 3047 3048 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3037 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @destinations = args[:destinations] if args.key?(:destinations) @event_type_id = args[:event_type_id] if args.key?(:event_type_id) @jms = args[:jms] if args.key?(:jms) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @subscriber = args[:subscriber] if args.key?(:subscriber) @subscriber_link = args[:subscriber_link] if args.key?(:subscriber_link) @trigger_config_variables = args[:trigger_config_variables] if args.key?(:trigger_config_variables) @update_time = args[:update_time] if args.key?(:update_time) end |