Class: Google::Apis::ConnectorsV1::EventingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EventingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Eventing Configuration of a connection next: 19
Instance Attribute Summary collapse
-
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional.
-
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
-
#dead_letter_config ⇒ Google::Apis::ConnectorsV1::DeadLetterConfig
Dead Letter configuration details provided by the user.
-
#enrichment_config ⇒ Google::Apis::ConnectorsV1::EnrichmentConfig
Data enrichment configuration.
-
#enrichment_enabled ⇒ Boolean
(also: #enrichment_enabled?)
Optional.
-
#events_listener_ingress_endpoint ⇒ String
Optional.
-
#listener_auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
-
#private_connectivity_allowlisted_projects ⇒ Array<String>
Optional.
-
#private_connectivity_enabled ⇒ Boolean
(also: #private_connectivity_enabled?)
Optional.
-
#proxy_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
-
#registration_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
-
#ssl_config ⇒ Google::Apis::ConnectorsV1::SslConfig
SSL Configuration of a connection Corresponds to the JSON property
sslConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventingConfig
constructor
A new instance of EventingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventingConfig
Returns a new instance of EventingConfig.
3247 3248 3249 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3247 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariable>
Optional. Additional eventing related field values
Corresponds to the JSON property additionalVariables
3186 3187 3188 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3186 def additional_variables @additional_variables end |
#auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
Corresponds to the JSON property authConfig
3191 3192 3193 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3191 def auth_config @auth_config end |
#dead_letter_config ⇒ Google::Apis::ConnectorsV1::DeadLetterConfig
Dead Letter configuration details provided by the user.
Corresponds to the JSON property deadLetterConfig
3196 3197 3198 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3196 def dead_letter_config @dead_letter_config end |
#enrichment_config ⇒ Google::Apis::ConnectorsV1::EnrichmentConfig
Data enrichment configuration.
Corresponds to the JSON property enrichmentConfig
3201 3202 3203 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3201 def enrichment_config @enrichment_config end |
#enrichment_enabled ⇒ Boolean Also known as: enrichment_enabled?
Optional. Enrichment Enabled.
Corresponds to the JSON property enrichmentEnabled
3206 3207 3208 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3206 def enrichment_enabled @enrichment_enabled end |
#events_listener_ingress_endpoint ⇒ String
Optional. Ingress endpoint of the event listener. This is used only when
private connectivity is enabled.
Corresponds to the JSON property eventsListenerIngressEndpoint
3213 3214 3215 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3213 def events_listener_ingress_endpoint @events_listener_ingress_endpoint end |
#listener_auth_config ⇒ Google::Apis::ConnectorsV1::AuthConfig
AuthConfig defines details of a authentication type.
Corresponds to the JSON property listenerAuthConfig
3218 3219 3220 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3218 def listener_auth_config @listener_auth_config end |
#private_connectivity_allowlisted_projects ⇒ Array<String>
Optional. List of projects to be allowlisted for the service attachment
created in the tenant project for eventing ingress.
Corresponds to the JSON property privateConnectivityAllowlistedProjects
3224 3225 3226 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3224 def private_connectivity_allowlisted_projects @private_connectivity_allowlisted_projects end |
#private_connectivity_enabled ⇒ Boolean Also known as: private_connectivity_enabled?
Optional. Private Connectivity Enabled.
Corresponds to the JSON property privateConnectivityEnabled
3229 3230 3231 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3229 def private_connectivity_enabled @private_connectivity_enabled end |
#proxy_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
Corresponds to the JSON property proxyDestinationConfig
3235 3236 3237 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3235 def proxy_destination_config @proxy_destination_config end |
#registration_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfig
Define the Connectors target endpoint.
Corresponds to the JSON property registrationDestinationConfig
3240 3241 3242 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3240 def registration_destination_config @registration_destination_config end |
#ssl_config ⇒ Google::Apis::ConnectorsV1::SslConfig
SSL Configuration of a connection
Corresponds to the JSON property sslConfig
3245 3246 3247 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3245 def ssl_config @ssl_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3252 def update!(**args) @additional_variables = args[:additional_variables] if args.key?(:additional_variables) @auth_config = args[:auth_config] if args.key?(:auth_config) @dead_letter_config = args[:dead_letter_config] if args.key?(:dead_letter_config) @enrichment_config = args[:enrichment_config] if args.key?(:enrichment_config) @enrichment_enabled = args[:enrichment_enabled] if args.key?(:enrichment_enabled) @events_listener_ingress_endpoint = args[:events_listener_ingress_endpoint] if args.key?(:events_listener_ingress_endpoint) @listener_auth_config = args[:listener_auth_config] if args.key?(:listener_auth_config) @private_connectivity_allowlisted_projects = args[:private_connectivity_allowlisted_projects] if args.key?(:private_connectivity_allowlisted_projects) @private_connectivity_enabled = args[:private_connectivity_enabled] if args.key?(:private_connectivity_enabled) @proxy_destination_config = args[:proxy_destination_config] if args.key?(:proxy_destination_config) @registration_destination_config = args[:registration_destination_config] if args.key?(:registration_destination_config) @ssl_config = args[:ssl_config] if args.key?(:ssl_config) end |