Class: Google::Apis::ConnectorsV1::EventingConfigTemplate
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EventingConfigTemplate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Eventing Config details of a connector version. next: 14
Instance Attribute Summary collapse
-
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariableTemplate>
Additional fields that need to be rendered.
-
#auth_config_templates ⇒ Array<Google::Apis::ConnectorsV1::AuthConfigTemplate>
AuthConfigTemplates represents the auth values for the webhook adapter.
-
#auto_refresh ⇒ Boolean
(also: #auto_refresh?)
Auto refresh to extend webhook life.
-
#auto_registration_supported ⇒ Boolean
(also: #auto_registration_supported?)
Auto Registration supported.
-
#encryption_key_template ⇒ Google::Apis::ConnectorsV1::ConfigVariableTemplate
ConfigVariableTemplate provides metadata about a
ConfigVariablethat is used in a Connection. -
#enrichment_supported ⇒ Boolean
(also: #enrichment_supported?)
Enrichment Supported.
-
#event_listener_type ⇒ String
The type of the event listener for a specific connector.
-
#is_eventing_supported ⇒ Boolean
(also: #is_eventing_supported?)
Is Eventing Supported.
-
#listener_auth_config_templates ⇒ Array<Google::Apis::ConnectorsV1::AuthConfigTemplate>
ListenerAuthConfigTemplates represents the auth values for the event listener.
-
#proxy_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfigTemplate
DestinationConfigTemplate defines required destinations supported by the Connector.
-
#registration_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfigTemplate
DestinationConfigTemplate defines required destinations supported by the Connector.
-
#ssl_config_template ⇒ Google::Apis::ConnectorsV1::SslConfigTemplate
Ssl config details of a connector version Corresponds to the JSON property
sslConfigTemplate. -
#trigger_config_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariableTemplate>
Trigger Config fields that needs to be rendered Corresponds to the JSON property
triggerConfigVariables.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventingConfigTemplate
constructor
A new instance of EventingConfigTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventingConfigTemplate
Returns a new instance of EventingConfigTemplate.
3344 3345 3346 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariableTemplate>
Additional fields that need to be rendered.
Corresponds to the JSON property additionalVariables
3275 3276 3277 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3275 def additional_variables @additional_variables end |
#auth_config_templates ⇒ Array<Google::Apis::ConnectorsV1::AuthConfigTemplate>
AuthConfigTemplates represents the auth values for the webhook adapter.
Corresponds to the JSON property authConfigTemplates
3280 3281 3282 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3280 def auth_config_templates @auth_config_templates end |
#auto_refresh ⇒ Boolean Also known as: auto_refresh?
Auto refresh to extend webhook life.
Corresponds to the JSON property autoRefresh
3285 3286 3287 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3285 def auto_refresh @auto_refresh end |
#auto_registration_supported ⇒ Boolean Also known as: auto_registration_supported?
Auto Registration supported.
Corresponds to the JSON property autoRegistrationSupported
3291 3292 3293 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3291 def auto_registration_supported @auto_registration_supported end |
#encryption_key_template ⇒ Google::Apis::ConnectorsV1::ConfigVariableTemplate
ConfigVariableTemplate provides metadata about a ConfigVariable that is used
in a Connection.
Corresponds to the JSON property encryptionKeyTemplate
3298 3299 3300 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3298 def encryption_key_template @encryption_key_template end |
#enrichment_supported ⇒ Boolean Also known as: enrichment_supported?
Enrichment Supported.
Corresponds to the JSON property enrichmentSupported
3303 3304 3305 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3303 def enrichment_supported @enrichment_supported end |
#event_listener_type ⇒ String
The type of the event listener for a specific connector.
Corresponds to the JSON property eventListenerType
3309 3310 3311 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3309 def event_listener_type @event_listener_type end |
#is_eventing_supported ⇒ Boolean Also known as: is_eventing_supported?
Is Eventing Supported.
Corresponds to the JSON property isEventingSupported
3314 3315 3316 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3314 def is_eventing_supported @is_eventing_supported end |
#listener_auth_config_templates ⇒ Array<Google::Apis::ConnectorsV1::AuthConfigTemplate>
ListenerAuthConfigTemplates represents the auth values for the event listener.
Corresponds to the JSON property listenerAuthConfigTemplates
3320 3321 3322 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3320 def listener_auth_config_templates @listener_auth_config_templates end |
#proxy_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfigTemplate
DestinationConfigTemplate defines required destinations supported by the
Connector.
Corresponds to the JSON property proxyDestinationConfig
3326 3327 3328 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3326 def proxy_destination_config @proxy_destination_config end |
#registration_destination_config ⇒ Google::Apis::ConnectorsV1::DestinationConfigTemplate
DestinationConfigTemplate defines required destinations supported by the
Connector.
Corresponds to the JSON property registrationDestinationConfig
3332 3333 3334 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3332 def registration_destination_config @registration_destination_config end |
#ssl_config_template ⇒ Google::Apis::ConnectorsV1::SslConfigTemplate
Ssl config details of a connector version
Corresponds to the JSON property sslConfigTemplate
3337 3338 3339 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3337 def ssl_config_template @ssl_config_template end |
#trigger_config_variables ⇒ Array<Google::Apis::ConnectorsV1::ConfigVariableTemplate>
Trigger Config fields that needs to be rendered
Corresponds to the JSON property triggerConfigVariables
3342 3343 3344 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3342 def trigger_config_variables @trigger_config_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3349 3350 3351 3352 3353 3354 3355 3356 3357 3358 3359 3360 3361 3362 3363 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3349 def update!(**args) @additional_variables = args[:additional_variables] if args.key?(:additional_variables) @auth_config_templates = args[:auth_config_templates] if args.key?(:auth_config_templates) @auto_refresh = args[:auto_refresh] if args.key?(:auto_refresh) @auto_registration_supported = args[:auto_registration_supported] if args.key?(:auto_registration_supported) @encryption_key_template = args[:encryption_key_template] if args.key?(:encryption_key_template) @enrichment_supported = args[:enrichment_supported] if args.key?(:enrichment_supported) @event_listener_type = args[:event_listener_type] if args.key?(:event_listener_type) @is_eventing_supported = args[:is_eventing_supported] if args.key?(:is_eventing_supported) @listener_auth_config_templates = args[:listener_auth_config_templates] if args.key?(:listener_auth_config_templates) @proxy_destination_config = args[:proxy_destination_config] if args.key?(:proxy_destination_config) @registration_destination_config = args[:registration_destination_config] if args.key?(:registration_destination_config) @ssl_config_template = args[:ssl_config_template] if args.key?(:ssl_config_template) @trigger_config_variables = args[:trigger_config_variables] if args.key?(:trigger_config_variables) end |