Class: Google::Apis::ConnectorsV1::EventingRuntimeData
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EventingRuntimeData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Eventing runtime data has the details related to eventing managed by the system.
Instance Attribute Summary collapse
-
#events_listener_endpoint ⇒ String
Output only.
-
#events_listener_psc_sa ⇒ String
Output only.
-
#status ⇒ Google::Apis::ConnectorsV1::EventingStatus
EventingStatus indicates the state of eventing.
-
#webhook_data ⇒ Google::Apis::ConnectorsV1::WebhookData
WebhookData has details of webhook configuration.
-
#webhook_subscriptions ⇒ Google::Apis::ConnectorsV1::WebhookSubscriptions
WebhookSubscriptions has details of webhook subscriptions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventingRuntimeData
constructor
A new instance of EventingRuntimeData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventingRuntimeData
Returns a new instance of EventingRuntimeData.
3540 3541 3542 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#events_listener_endpoint ⇒ String
Output only. Events listener endpoint. The value will populated after
provisioning the events listener.
Corresponds to the JSON property eventsListenerEndpoint
3516 3517 3518 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3516 def events_listener_endpoint @events_listener_endpoint end |
#events_listener_psc_sa ⇒ String
Output only. Events listener PSC Service attachment. The value will be
populated after provisioning the events listener with private connectivity
enabled.
Corresponds to the JSON property eventsListenerPscSa
3523 3524 3525 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3523 def events_listener_psc_sa @events_listener_psc_sa end |
#status ⇒ Google::Apis::ConnectorsV1::EventingStatus
EventingStatus indicates the state of eventing.
Corresponds to the JSON property status
3528 3529 3530 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3528 def status @status end |
#webhook_data ⇒ Google::Apis::ConnectorsV1::WebhookData
WebhookData has details of webhook configuration.
Corresponds to the JSON property webhookData
3533 3534 3535 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3533 def webhook_data @webhook_data end |
#webhook_subscriptions ⇒ Google::Apis::ConnectorsV1::WebhookSubscriptions
WebhookSubscriptions has details of webhook subscriptions.
Corresponds to the JSON property webhookSubscriptions
3538 3539 3540 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3538 def webhook_subscriptions @webhook_subscriptions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3545 3546 3547 3548 3549 3550 3551 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3545 def update!(**args) @events_listener_endpoint = args[:events_listener_endpoint] if args.key?(:events_listener_endpoint) @events_listener_psc_sa = args[:events_listener_psc_sa] if args.key?(:events_listener_psc_sa) @status = args[:status] if args.key?(:status) @webhook_data = args[:webhook_data] if args.key?(:webhook_data) @webhook_subscriptions = args[:webhook_subscriptions] if args.key?(:webhook_subscriptions) end |