Class: Google::Apis::ConnectorsV1::EventingRuntimeData
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::EventingRuntimeData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Eventing runtime data has the details related to eventing managed by the system.
Instance Attribute Summary collapse
-
#events_listener_endpoint ⇒ String
Output only.
-
#events_listener_psc_sa ⇒ String
Output only.
-
#status ⇒ Google::Apis::ConnectorsV1::EventingStatus
EventingStatus indicates the state of eventing.
-
#webhook_data ⇒ Google::Apis::ConnectorsV1::WebhookData
WebhookData has details of webhook configuration.
-
#webhook_subscriptions ⇒ Google::Apis::ConnectorsV1::WebhookSubscriptions
WebhookSubscriptions has details of webhook subscriptions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventingRuntimeData
constructor
A new instance of EventingRuntimeData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventingRuntimeData
Returns a new instance of EventingRuntimeData.
3461 3462 3463 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#events_listener_endpoint ⇒ String
Output only. Events listener endpoint. The value will populated after
provisioning the events listener.
Corresponds to the JSON property eventsListenerEndpoint
3437 3438 3439 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3437 def events_listener_endpoint @events_listener_endpoint end |
#events_listener_psc_sa ⇒ String
Output only. Events listener PSC Service attachment. The value will be
populated after provisioning the events listener with private connectivity
enabled.
Corresponds to the JSON property eventsListenerPscSa
3444 3445 3446 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3444 def events_listener_psc_sa @events_listener_psc_sa end |
#status ⇒ Google::Apis::ConnectorsV1::EventingStatus
EventingStatus indicates the state of eventing.
Corresponds to the JSON property status
3449 3450 3451 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3449 def status @status end |
#webhook_data ⇒ Google::Apis::ConnectorsV1::WebhookData
WebhookData has details of webhook configuration.
Corresponds to the JSON property webhookData
3454 3455 3456 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3454 def webhook_data @webhook_data end |
#webhook_subscriptions ⇒ Google::Apis::ConnectorsV1::WebhookSubscriptions
WebhookSubscriptions has details of webhook subscriptions.
Corresponds to the JSON property webhookSubscriptions
3459 3460 3461 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3459 def webhook_subscriptions @webhook_subscriptions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3466 def update!(**args) @events_listener_endpoint = args[:events_listener_endpoint] if args.key?(:events_listener_endpoint) @events_listener_psc_sa = args[:events_listener_psc_sa] if args.key?(:events_listener_psc_sa) @status = args[:status] if args.key?(:status) @webhook_data = args[:webhook_data] if args.key?(:webhook_data) @webhook_subscriptions = args[:webhook_subscriptions] if args.key?(:webhook_subscriptions) end |