Class: Google::Apis::ConnectorsV1::ExtractionRule
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::ExtractionRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Extraction Rule.
Instance Attribute Summary collapse
-
#extraction_regex ⇒ String
Regex used to extract backend details from source.
-
#format_string ⇒ String
Format string used to format the extracted backend details.
-
#source ⇒ Google::Apis::ConnectorsV1::Source
Source to extract the backend from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtractionRule
constructor
A new instance of ExtractionRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtractionRule
Returns a new instance of ExtractionRule.
3575 3576 3577 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extraction_regex ⇒ String
Regex used to extract backend details from source. If empty, whole source
value will be used.
Corresponds to the JSON property extractionRegex
3562 3563 3564 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3562 def extraction_regex @extraction_regex end |
#format_string ⇒ String
Format string used to format the extracted backend details. If empty,
extracted backend details will be returned as it is.
Corresponds to the JSON property formatString
3568 3569 3570 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3568 def format_string @format_string end |
#source ⇒ Google::Apis::ConnectorsV1::Source
Source to extract the backend from.
Corresponds to the JSON property source
3573 3574 3575 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3573 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3580 3581 3582 3583 3584 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3580 def update!(**args) @extraction_regex = args[:extraction_regex] if args.key?(:extraction_regex) @format_string = args[:format_string] if args.key?(:format_string) @source = args[:source] if args.key?(:source) end |