Class: Google::Apis::ConnectorsV1::GenerateConnectionToolspecOverrideResponse
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::GenerateConnectionToolspecOverrideResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Response message for GenerateConnectionToolspecOverride API.
Instance Attribute Summary collapse
-
#toolspec_override ⇒ Google::Apis::ConnectorsV1::ToolspecOverride
Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateConnectionToolspecOverrideResponse
constructor
A new instance of GenerateConnectionToolspecOverrideResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateConnectionToolspecOverrideResponse
Returns a new instance of GenerateConnectionToolspecOverrideResponse.
3778 3779 3780 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#toolspec_override ⇒ Google::Apis::ConnectorsV1::ToolspecOverride
Toolspec overrides for a connection only holds the information that is to be
displayed in the UI for admins.
Corresponds to the JSON property toolspecOverride
3776 3777 3778 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3776 def toolspec_override @toolspec_override end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3783 3784 3785 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 3783 def update!(**args) @toolspec_override = args[:toolspec_override] if args.key?(:toolspec_override) end |