Class: Google::Apis::ConnectorsV1::JsonSchema
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::JsonSchema
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
JsonSchema representation of schema metadata
Instance Attribute Summary collapse
-
#additional_details ⇒ Hash<String,Object>
Additional details apart from standard json schema fields, this gives flexibility to store metadata about the schema Corresponds to the JSON property
additionalDetails. -
#default ⇒ Object
The default value of the field or object described by this schema.
-
#description ⇒ String
A description of this schema.
-
#enum ⇒ Array<Object>
Possible values for an enumeration.
-
#format ⇒ String
Format of the value as per https://json-schema.org/understanding-json-schema/ reference/string.html#format Corresponds to the JSON property
format. -
#items ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata Corresponds to the JSON property
items. -
#jdbc_type ⇒ String
JDBC datatype of the field.
-
#properties ⇒ Hash<String,Google::Apis::ConnectorsV1::JsonSchema>
The child schemas, applicable only if this is of type
object. -
#required ⇒ Array<String>
Whether this property is required.
-
#type ⇒ Array<String>
JSON Schema Validation: A Vocabulary for Structural Validation of JSON Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JsonSchema
constructor
A new instance of JsonSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JsonSchema
Returns a new instance of JsonSchema.
4173 4174 4175 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_details ⇒ Hash<String,Object>
Additional details apart from standard json schema fields, this gives
flexibility to store metadata about the schema
Corresponds to the JSON property additionalDetails
4122 4123 4124 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4122 def additional_details @additional_details end |
#default ⇒ Object
The default value of the field or object described by this schema.
Corresponds to the JSON property default
4127 4128 4129 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4127 def default @default end |
#description ⇒ String
A description of this schema.
Corresponds to the JSON property description
4132 4133 4134 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4132 def description @description end |
#enum ⇒ Array<Object>
Possible values for an enumeration. This works in conjunction with type to
represent types with a fixed set of legal values
Corresponds to the JSON property enum
4138 4139 4140 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4138 def enum @enum end |
#format ⇒ String
Format of the value as per https://json-schema.org/understanding-json-schema/
reference/string.html#format
Corresponds to the JSON property format
4144 4145 4146 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4144 def format @format end |
#items ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata
Corresponds to the JSON property items
4149 4150 4151 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4149 def items @items end |
#jdbc_type ⇒ String
JDBC datatype of the field.
Corresponds to the JSON property jdbcType
4154 4155 4156 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4154 def jdbc_type @jdbc_type end |
#properties ⇒ Hash<String,Google::Apis::ConnectorsV1::JsonSchema>
The child schemas, applicable only if this is of type object. The key is the
name of the property and the value is the json schema that describes that
property
Corresponds to the JSON property properties
4161 4162 4163 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4161 def properties @properties end |
#required ⇒ Array<String>
Whether this property is required.
Corresponds to the JSON property required
4166 4167 4168 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4166 def required @required end |
#type ⇒ Array<String>
JSON Schema Validation: A Vocabulary for Structural Validation of JSON
Corresponds to the JSON property type
4171 4172 4173 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4171 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4178 def update!(**args) @additional_details = args[:additional_details] if args.key?(:additional_details) @default = args[:default] if args.key?(:default) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @jdbc_type = args[:jdbc_type] if args.key?(:jdbc_type) @properties = args[:properties] if args.key?(:properties) @required = args[:required] if args.key?(:required) @type = args[:type] if args.key?(:type) end |