Class: Google::Apis::ConnectorsV1::MaintenanceSettings
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::MaintenanceSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Maintenance settings associated with instance. Allows service producers and end users to assign settings that controls maintenance on this instance.
Instance Attribute Summary collapse
-
#exclude ⇒ Boolean
(also: #exclude?)
Optional.
-
#is_rollback ⇒ Boolean
(also: #is_rollback?)
Optional.
-
#maintenance_policies ⇒ Hash<String,Google::Apis::ConnectorsV1::MaintenancePolicy>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenanceSettings
constructor
A new instance of MaintenanceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenanceSettings
Returns a new instance of MaintenanceSettings.
4958 4959 4960 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude ⇒ Boolean Also known as: exclude?
Optional. Exclude instance from maintenance. When true, rollout service will
not attempt maintenance on the instance. Rollout service will include the
instance in reported rollout progress as not attempted.
Corresponds to the JSON property exclude
4939 4940 4941 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4939 def exclude @exclude end |
#is_rollback ⇒ Boolean Also known as: is_rollback?
Optional. If the update call is triggered from rollback, set the value as true.
Corresponds to the JSON property isRollback
4945 4946 4947 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4945 def is_rollback @is_rollback end |
#maintenance_policies ⇒ Hash<String,Google::Apis::ConnectorsV1::MaintenancePolicy>
Optional. The MaintenancePolicies that have been attached to the instance. The
key must be of the type name of the oneof policy name defined in
MaintenancePolicy, and the embedded policy must define the same policy type.
For details, please refer to go/mr-user-guide. Should not be set if
maintenance_policy_names is set. If only the name is needed, then only
populate MaintenancePolicy.name.
Corresponds to the JSON property maintenancePolicies
4956 4957 4958 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4956 def maintenance_policies @maintenance_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4963 4964 4965 4966 4967 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 4963 def update!(**args) @exclude = args[:exclude] if args.key?(:exclude) @is_rollback = args[:is_rollback] if args.key?(:is_rollback) @maintenance_policies = args[:maintenance_policies] if args.key?(:maintenance_policies) end |