Class: Google::Apis::ConnectorsV1::OAuthTokenData
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::OAuthTokenData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
pass only at create and not update using updateMask Auth Code Data
Instance Attribute Summary collapse
-
#access_token ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
-
#create_time ⇒ String
Optional.
-
#expiry ⇒ String
Optional.
-
#refresh_token ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OAuthTokenData
constructor
A new instance of OAuthTokenData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OAuthTokenData
Returns a new instance of OAuthTokenData.
5409 5410 5411 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_token ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
Corresponds to the JSON property accessToken
5392 5393 5394 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5392 def access_token @access_token end |
#create_time ⇒ String
Optional. Timestamp when the access token was created.
Corresponds to the JSON property createTime
5397 5398 5399 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5397 def create_time @create_time end |
#expiry ⇒ String
Optional. Time in seconds when the access token expires.
Corresponds to the JSON property expiry
5402 5403 5404 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5402 def expiry @expiry end |
#refresh_token ⇒ Google::Apis::ConnectorsV1::EuaSecret
EUASecret provides a reference to entries in Secret Manager.
Corresponds to the JSON property refreshToken
5407 5408 5409 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5407 def refresh_token @refresh_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5414 5415 5416 5417 5418 5419 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5414 def update!(**args) @access_token = args[:access_token] if args.key?(:access_token) @create_time = args[:create_time] if args.key?(:create_time) @expiry = args[:expiry] if args.key?(:expiry) @refresh_token = args[:refresh_token] if args.key?(:refresh_token) end |