Class: Google::Apis::ConnectorsV1::Oauth2AuthCodeFlow
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::Oauth2AuthCodeFlow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Parameters to support Oauth 2.0 Auth Code Grant Authentication. See https:// www.rfc-editor.org/rfc/rfc6749#section-1.3.1 for more details.
Instance Attribute Summary collapse
-
#auth_code ⇒ String
Optional.
-
#auth_uri ⇒ String
Optional.
-
#client_id ⇒ String
Optional.
-
#client_secret ⇒ Google::Apis::ConnectorsV1::Secret
Secret provides a reference to entries in Secret Manager.
-
#enable_pkce ⇒ Boolean
(also: #enable_pkce?)
Optional.
-
#pkce_verifier ⇒ String
Optional.
-
#redirect_uri ⇒ String
Optional.
-
#scopes ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Oauth2AuthCodeFlow
constructor
A new instance of Oauth2AuthCodeFlow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Oauth2AuthCodeFlow
Returns a new instance of Oauth2AuthCodeFlow.
5469 5470 5471 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_code ⇒ String
Optional. Authorization code to be exchanged for access and refresh tokens.
Corresponds to the JSON property authCode
5430 5431 5432 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5430 def auth_code @auth_code end |
#auth_uri ⇒ String
Optional. Auth URL for Authorization Code Flow
Corresponds to the JSON property authUri
5435 5436 5437 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5435 def auth_uri @auth_uri end |
#client_id ⇒ String
Optional. Client ID for user-provided OAuth app.
Corresponds to the JSON property clientId
5440 5441 5442 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5440 def client_id @client_id end |
#client_secret ⇒ Google::Apis::ConnectorsV1::Secret
Secret provides a reference to entries in Secret Manager.
Corresponds to the JSON property clientSecret
5445 5446 5447 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5445 def client_secret @client_secret end |
#enable_pkce ⇒ Boolean Also known as: enable_pkce?
Optional. Whether to enable PKCE when the user performs the auth code flow.
Corresponds to the JSON property enablePkce
5450 5451 5452 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5450 def enable_pkce @enable_pkce end |
#pkce_verifier ⇒ String
Optional. PKCE verifier to be used during the auth code exchange.
Corresponds to the JSON property pkceVerifier
5456 5457 5458 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5456 def pkce_verifier @pkce_verifier end |
#redirect_uri ⇒ String
Optional. Redirect URI to be provided during the auth code exchange.
Corresponds to the JSON property redirectUri
5461 5462 5463 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5461 def redirect_uri @redirect_uri end |
#scopes ⇒ Array<String>
Optional. Scopes the connection will request when the user performs the auth
code flow.
Corresponds to the JSON property scopes
5467 5468 5469 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5467 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5474 def update!(**args) @auth_code = args[:auth_code] if args.key?(:auth_code) @auth_uri = args[:auth_uri] if args.key?(:auth_uri) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @enable_pkce = args[:enable_pkce] if args.key?(:enable_pkce) @pkce_verifier = args[:pkce_verifier] if args.key?(:pkce_verifier) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @scopes = args[:scopes] if args.key?(:scopes) end |