Class: Google::Apis::ConnectorsV1::Oauth2AuthCodeFlow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Parameters to support Oauth 2.0 Auth Code Grant Authentication. See https:// www.rfc-editor.org/rfc/rfc6749#section-1.3.1 for more details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Oauth2AuthCodeFlow

Returns a new instance of Oauth2AuthCodeFlow.



5390
5391
5392
# File 'lib/google/apis/connectors_v1/classes.rb', line 5390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_codeString

Optional. Authorization code to be exchanged for access and refresh tokens. Corresponds to the JSON property authCode

Returns:

  • (String)


5351
5352
5353
# File 'lib/google/apis/connectors_v1/classes.rb', line 5351

def auth_code
  @auth_code
end

#auth_uriString

Optional. Auth URL for Authorization Code Flow Corresponds to the JSON property authUri

Returns:

  • (String)


5356
5357
5358
# File 'lib/google/apis/connectors_v1/classes.rb', line 5356

def auth_uri
  @auth_uri
end

#client_idString

Optional. Client ID for user-provided OAuth app. Corresponds to the JSON property clientId

Returns:

  • (String)


5361
5362
5363
# File 'lib/google/apis/connectors_v1/classes.rb', line 5361

def client_id
  @client_id
end

#client_secretGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientSecret



5366
5367
5368
# File 'lib/google/apis/connectors_v1/classes.rb', line 5366

def client_secret
  @client_secret
end

#enable_pkceBoolean Also known as: enable_pkce?

Optional. Whether to enable PKCE when the user performs the auth code flow. Corresponds to the JSON property enablePkce

Returns:

  • (Boolean)


5371
5372
5373
# File 'lib/google/apis/connectors_v1/classes.rb', line 5371

def enable_pkce
  @enable_pkce
end

#pkce_verifierString

Optional. PKCE verifier to be used during the auth code exchange. Corresponds to the JSON property pkceVerifier

Returns:

  • (String)


5377
5378
5379
# File 'lib/google/apis/connectors_v1/classes.rb', line 5377

def pkce_verifier
  @pkce_verifier
end

#redirect_uriString

Optional. Redirect URI to be provided during the auth code exchange. Corresponds to the JSON property redirectUri

Returns:

  • (String)


5382
5383
5384
# File 'lib/google/apis/connectors_v1/classes.rb', line 5382

def redirect_uri
  @redirect_uri
end

#scopesArray<String>

Optional. Scopes the connection will request when the user performs the auth code flow. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


5388
5389
5390
# File 'lib/google/apis/connectors_v1/classes.rb', line 5388

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
# File 'lib/google/apis/connectors_v1/classes.rb', line 5395

def update!(**args)
  @auth_code = args[:auth_code] if args.key?(:auth_code)
  @auth_uri = args[:auth_uri] if args.key?(:auth_uri)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @enable_pkce = args[:enable_pkce] if args.key?(:enable_pkce)
  @pkce_verifier = args[:pkce_verifier] if args.key?(:pkce_verifier)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @scopes = args[:scopes] if args.key?(:scopes)
end