Class: Google::Apis::ConnectorsV1::Oauth2AuthCodeFlowGoogleManaged

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client. See https://tools.ietf.org/html/rfc6749#section-1.3.1 for more details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Oauth2AuthCodeFlowGoogleManaged

Returns a new instance of Oauth2AuthCodeFlowGoogleManaged.



5508
5509
5510
# File 'lib/google/apis/connectors_v1/classes.rb', line 5508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_codeString

Optional. Authorization code to be exchanged for access and refresh tokens. Corresponds to the JSON property authCode

Returns:

  • (String)


5495
5496
5497
# File 'lib/google/apis/connectors_v1/classes.rb', line 5495

def auth_code
  @auth_code
end

#redirect_uriString

Optional. Redirect URI to be provided during the auth code exchange. Corresponds to the JSON property redirectUri

Returns:

  • (String)


5500
5501
5502
# File 'lib/google/apis/connectors_v1/classes.rb', line 5500

def redirect_uri
  @redirect_uri
end

#scopesArray<String>

Required. Scopes the connection will request when the user performs the auth code flow. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


5506
5507
5508
# File 'lib/google/apis/connectors_v1/classes.rb', line 5506

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5513
5514
5515
5516
5517
# File 'lib/google/apis/connectors_v1/classes.rb', line 5513

def update!(**args)
  @auth_code = args[:auth_code] if args.key?(:auth_code)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @scopes = args[:scopes] if args.key?(:scopes)
end