Class: Google::Apis::ConnectorsV1::Oauth2AuthCodeFlowGoogleManaged
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::Oauth2AuthCodeFlowGoogleManaged
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client. See https://tools.ietf.org/html/rfc6749#section-1.3.1 for more details.
Instance Attribute Summary collapse
-
#auth_code ⇒ String
Optional.
-
#redirect_uri ⇒ String
Optional.
-
#scopes ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Oauth2AuthCodeFlowGoogleManaged
constructor
A new instance of Oauth2AuthCodeFlowGoogleManaged.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Oauth2AuthCodeFlowGoogleManaged
Returns a new instance of Oauth2AuthCodeFlowGoogleManaged.
5429 5430 5431 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_code ⇒ String
Optional. Authorization code to be exchanged for access and refresh tokens.
Corresponds to the JSON property authCode
5416 5417 5418 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5416 def auth_code @auth_code end |
#redirect_uri ⇒ String
Optional. Redirect URI to be provided during the auth code exchange.
Corresponds to the JSON property redirectUri
5421 5422 5423 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5421 def redirect_uri @redirect_uri end |
#scopes ⇒ Array<String>
Required. Scopes the connection will request when the user performs the auth
code flow.
Corresponds to the JSON property scopes
5427 5428 5429 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5427 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5434 5435 5436 5437 5438 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5434 def update!(**args) @auth_code = args[:auth_code] if args.key?(:auth_code) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @scopes = args[:scopes] if args.key?(:scopes) end |