Class: Google::Apis::ConnectorsV1::Provider
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::Provider
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Provider indicates the owner who provides the connectors.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#documentation_uri ⇒ String
Output only.
-
#external_uri ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#launch_stage ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#web_assets_location ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Provider
constructor
A new instance of Provider.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Provider
Returns a new instance of Provider.
6001 6002 6003 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Created time.
Corresponds to the JSON property createTime
5950 5951 5952 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5950 def create_time @create_time end |
#description ⇒ String
Output only. Description of the resource.
Corresponds to the JSON property description
5955 5956 5957 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5955 def description @description end |
#display_name ⇒ String
Output only. Display name.
Corresponds to the JSON property displayName
5960 5961 5962 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5960 def display_name @display_name end |
#documentation_uri ⇒ String
Output only. Link to documentation page.
Corresponds to the JSON property documentationUri
5965 5966 5967 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5965 def documentation_uri @documentation_uri end |
#external_uri ⇒ String
Output only. Link to external page.
Corresponds to the JSON property externalUri
5970 5971 5972 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5970 def external_uri @external_uri end |
#labels ⇒ Hash<String,String>
Output only. Resource labels to represent user-provided metadata. Refer to
cloud documentation on labels for more details. https://cloud.google.com/
compute/docs/labeling-resources
Corresponds to the JSON property labels
5977 5978 5979 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5977 def labels @labels end |
#launch_stage ⇒ String
Output only. Flag to mark the version indicating the launch stage.
Corresponds to the JSON property launchStage
5982 5983 5984 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5982 def launch_stage @launch_stage end |
#name ⇒ String
Output only. Resource name of the Provider. Format: projects/project/
locations/location/providers/provider Only global location is supported
for Provider resource.
Corresponds to the JSON property name
5989 5990 5991 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5989 def name @name end |
#update_time ⇒ String
Output only. Updated time.
Corresponds to the JSON property updateTime
5994 5995 5996 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5994 def update_time @update_time end |
#web_assets_location ⇒ String
Output only. Cloud storage location of icons etc consumed by UI.
Corresponds to the JSON property webAssetsLocation
5999 6000 6001 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 5999 def web_assets_location @web_assets_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6006 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri) @external_uri = args[:external_uri] if args.key?(:external_uri) @labels = args[:labels] if args.key?(:labels) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @web_assets_location = args[:web_assets_location] if args.key?(:web_assets_location) end |