Class: Google::Apis::ConnectorsV1::RoleGrant

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

This configuration defines all the Cloud IAM roles that needs to be granted to a particular Google Cloud resource for the selected principal like service account. These configurations will let UI display to customers what IAM roles need to be granted by them. Or these configurations can be used by the UI to render a 'grant' button to do the same on behalf of the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoleGrant

Returns a new instance of RoleGrant.



6302
6303
6304
# File 'lib/google/apis/connectors_v1/classes.rb', line 6302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#helper_text_templateString

Optional. Template that UI can use to provide helper text to customers. Corresponds to the JSON property helperTextTemplate

Returns:

  • (String)


6285
6286
6287
# File 'lib/google/apis/connectors_v1/classes.rb', line 6285

def helper_text_template
  @helper_text_template
end

#principalString

Optional. Principal/Identity for whom the role need to assigned. Corresponds to the JSON property principal

Returns:

  • (String)


6290
6291
6292
# File 'lib/google/apis/connectors_v1/classes.rb', line 6290

def principal
  @principal
end

#resourceGoogle::Apis::ConnectorsV1::Resource

Resource definition Corresponds to the JSON property resource



6295
6296
6297
# File 'lib/google/apis/connectors_v1/classes.rb', line 6295

def resource
  @resource
end

#rolesArray<String>

Optional. List of roles that need to be granted. Corresponds to the JSON property roles

Returns:

  • (Array<String>)


6300
6301
6302
# File 'lib/google/apis/connectors_v1/classes.rb', line 6300

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6307
6308
6309
6310
6311
6312
# File 'lib/google/apis/connectors_v1/classes.rb', line 6307

def update!(**args)
  @helper_text_template = args[:helper_text_template] if args.key?(:helper_text_template)
  @principal = args[:principal] if args.key?(:principal)
  @resource = args[:resource] if args.key?(:resource)
  @roles = args[:roles] if args.key?(:roles)
end