Class: Google::Apis::ConnectorsV1::RuntimeActionSchema

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Schema of a runtime action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuntimeActionSchema

Returns a new instance of RuntimeActionSchema.



6456
6457
6458
# File 'lib/google/apis/connectors_v1/classes.rb', line 6456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. Name of the action. Corresponds to the JSON property action

Returns:

  • (String)


6414
6415
6416
# File 'lib/google/apis/connectors_v1/classes.rb', line 6414

def action
  @action
end

#descriptionString

Output only. Brief Description of action Corresponds to the JSON property description

Returns:

  • (String)


6419
6420
6421
# File 'lib/google/apis/connectors_v1/classes.rb', line 6419

def description
  @description
end

#display_nameString

Output only. Display Name of action to be shown on client side Corresponds to the JSON property displayName

Returns:

  • (String)


6424
6425
6426
# File 'lib/google/apis/connectors_v1/classes.rb', line 6424

def display_name
  @display_name
end

#input_json_schemaGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property inputJsonSchema



6429
6430
6431
# File 'lib/google/apis/connectors_v1/classes.rb', line 6429

def input_json_schema
  @input_json_schema
end

#input_parametersArray<Google::Apis::ConnectorsV1::InputParameter>

Output only. List of input parameter metadata for the action. Corresponds to the JSON property inputParameters



6434
6435
6436
# File 'lib/google/apis/connectors_v1/classes.rb', line 6434

def input_parameters
  @input_parameters
end

#input_schema_as_stringString

Output only. Input schema as string. Corresponds to the JSON property inputSchemaAsString

Returns:

  • (String)


6439
6440
6441
# File 'lib/google/apis/connectors_v1/classes.rb', line 6439

def input_schema_as_string
  @input_schema_as_string
end

#result_json_schemaGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property resultJsonSchema



6444
6445
6446
# File 'lib/google/apis/connectors_v1/classes.rb', line 6444

def result_json_schema
  @result_json_schema
end

#result_metadataArray<Google::Apis::ConnectorsV1::ResultMetadata>

Output only. List of result field metadata. Corresponds to the JSON property resultMetadata



6449
6450
6451
# File 'lib/google/apis/connectors_v1/classes.rb', line 6449

def 
  @result_metadata
end

#result_schema_as_stringString

Output only. Result schema as string. Corresponds to the JSON property resultSchemaAsString

Returns:

  • (String)


6454
6455
6456
# File 'lib/google/apis/connectors_v1/classes.rb', line 6454

def result_schema_as_string
  @result_schema_as_string
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6461
6462
6463
6464
6465
6466
6467
6468
6469
6470
6471
# File 'lib/google/apis/connectors_v1/classes.rb', line 6461

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @input_json_schema = args[:input_json_schema] if args.key?(:input_json_schema)
  @input_parameters = args[:input_parameters] if args.key?(:input_parameters)
  @input_schema_as_string = args[:input_schema_as_string] if args.key?(:input_schema_as_string)
  @result_json_schema = args[:result_json_schema] if args.key?(:result_json_schema)
  @result_metadata = args[:result_metadata] if args.key?(:result_metadata)
  @result_schema_as_string = args[:result_schema_as_string] if args.key?(:result_schema_as_string)
end