Class: Google::Apis::ConnectorsV1::RuntimeActionSchema
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::RuntimeActionSchema
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Schema of a runtime action.
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#input_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata Corresponds to the JSON property
inputJsonSchema. -
#input_parameters ⇒ Array<Google::Apis::ConnectorsV1::InputParameter>
Output only.
-
#input_schema_as_string ⇒ String
Output only.
-
#result_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata Corresponds to the JSON property
resultJsonSchema. -
#result_metadata ⇒ Array<Google::Apis::ConnectorsV1::ResultMetadata>
Output only.
-
#result_schema_as_string ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeActionSchema
constructor
A new instance of RuntimeActionSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeActionSchema
Returns a new instance of RuntimeActionSchema.
6364 6365 6366 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Name of the action.
Corresponds to the JSON property action
6322 6323 6324 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6322 def action @action end |
#description ⇒ String
Output only. Brief Description of action
Corresponds to the JSON property description
6327 6328 6329 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6327 def description @description end |
#display_name ⇒ String
Output only. Display Name of action to be shown on client side
Corresponds to the JSON property displayName
6332 6333 6334 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6332 def display_name @display_name end |
#input_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata
Corresponds to the JSON property inputJsonSchema
6337 6338 6339 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6337 def input_json_schema @input_json_schema end |
#input_parameters ⇒ Array<Google::Apis::ConnectorsV1::InputParameter>
Output only. List of input parameter metadata for the action.
Corresponds to the JSON property inputParameters
6342 6343 6344 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6342 def input_parameters @input_parameters end |
#input_schema_as_string ⇒ String
Output only. Input schema as string.
Corresponds to the JSON property inputSchemaAsString
6347 6348 6349 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6347 def input_schema_as_string @input_schema_as_string end |
#result_json_schema ⇒ Google::Apis::ConnectorsV1::JsonSchema
JsonSchema representation of schema metadata
Corresponds to the JSON property resultJsonSchema
6352 6353 6354 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6352 def result_json_schema @result_json_schema end |
#result_metadata ⇒ Array<Google::Apis::ConnectorsV1::ResultMetadata>
Output only. List of result field metadata.
Corresponds to the JSON property resultMetadata
6357 6358 6359 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6357 def @result_metadata end |
#result_schema_as_string ⇒ String
Output only. Result schema as string.
Corresponds to the JSON property resultSchemaAsString
6362 6363 6364 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6362 def result_schema_as_string @result_schema_as_string end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6369 6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6369 def update!(**args) @action = args[:action] if args.key?(:action) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @input_json_schema = args[:input_json_schema] if args.key?(:input_json_schema) @input_parameters = args[:input_parameters] if args.key?(:input_parameters) @input_schema_as_string = args[:input_schema_as_string] if args.key?(:input_schema_as_string) @result_json_schema = args[:result_json_schema] if args.key?(:result_json_schema) @result_metadata = args[:result_metadata] if args.key?(:result_metadata) @result_schema_as_string = args[:result_schema_as_string] if args.key?(:result_schema_as_string) end |