Class: Google::Apis::ConnectorsV1::RuntimeEntitySchema

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Schema of a runtime entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuntimeEntitySchema

Returns a new instance of RuntimeEntitySchema.



6486
6487
6488
# File 'lib/google/apis/connectors_v1/classes.rb', line 6486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityString

Output only. Name of the entity. Corresponds to the JSON property entity

Returns:

  • (String)


6469
6470
6471
# File 'lib/google/apis/connectors_v1/classes.rb', line 6469

def entity
  @entity
end

#fieldsArray<Google::Apis::ConnectorsV1::Field>

Output only. List of fields in the entity. Corresponds to the JSON property fields



6474
6475
6476
# File 'lib/google/apis/connectors_v1/classes.rb', line 6474

def fields
  @fields
end

#json_schemaGoogle::Apis::ConnectorsV1::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property jsonSchema



6479
6480
6481
# File 'lib/google/apis/connectors_v1/classes.rb', line 6479

def json_schema
  @json_schema
end

#operationsArray<String>

List of operations supported by this entity Corresponds to the JSON property operations

Returns:

  • (Array<String>)


6484
6485
6486
# File 'lib/google/apis/connectors_v1/classes.rb', line 6484

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6491
6492
6493
6494
6495
6496
# File 'lib/google/apis/connectors_v1/classes.rb', line 6491

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @fields = args[:fields] if args.key?(:fields)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @operations = args[:operations] if args.key?(:operations)
end