Class: Google::Apis::ConnectorsV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::Schedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::ConnectorsV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
6612 6613 6614 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
6598 6599 6600 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6598 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
6603 6604 6605 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6603 def duration @duration end |
#start_time ⇒ Google::Apis::ConnectorsV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
6610 6611 6612 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6610 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6617 6618 6619 6620 6621 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6617 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |