Class: Google::Apis::ConnectorsV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::Schedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::ConnectorsV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
6520 6521 6522 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
6506 6507 6508 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6506 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
6511 6512 6513 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6511 def duration @duration end |
#start_time ⇒ Google::Apis::ConnectorsV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
6518 6519 6520 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6518 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6525 6526 6527 6528 6529 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6525 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |