Class: Google::Apis::ConnectorsV1::Secret
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::Secret
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Secret provides a reference to entries in Secret Manager.
Instance Attribute Summary collapse
-
#secret_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Secret
constructor
A new instance of Secret.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Secret
Returns a new instance of Secret.
6724 6725 6726 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#secret_version ⇒ String
Optional. The resource name of the secret version in the format, format as:
projects/*/secrets/*/versions/*.
Corresponds to the JSON property secretVersion
6722 6723 6724 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6722 def secret_version @secret_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6729 6730 6731 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 6729 def update!(**args) @secret_version = args[:secret_version] if args.key?(:secret_version) end |