Class: Google::Apis::ConnectorsV1::Secret

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Secret provides a reference to entries in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Secret

Returns a new instance of Secret.



6632
6633
6634
# File 'lib/google/apis/connectors_v1/classes.rb', line 6632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secret_versionString

Optional. The resource name of the secret version in the format, format as: projects/*/secrets/*/versions/*. Corresponds to the JSON property secretVersion

Returns:

  • (String)


6630
6631
6632
# File 'lib/google/apis/connectors_v1/classes.rb', line 6630

def secret_version
  @secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6637
6638
6639
# File 'lib/google/apis/connectors_v1/classes.rb', line 6637

def update!(**args)
  @secret_version = args[:secret_version] if args.key?(:secret_version)
end