Class: Google::Apis::ConnectorsV1::SloEligibility

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

SloEligibility is a tuple containing eligibility value: true if an instance is eligible for SLO calculation or false if it should be excluded from all SLO- related calculations along with a user-defined reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SloEligibility

Returns a new instance of SloEligibility.



6753
6754
6755
# File 'lib/google/apis/connectors_v1/classes.rb', line 6753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligibleBoolean Also known as: eligible?

Whether an instance is eligible or ineligible. Corresponds to the JSON property eligible

Returns:

  • (Boolean)


6744
6745
6746
# File 'lib/google/apis/connectors_v1/classes.rb', line 6744

def eligible
  @eligible
end

#reasonString

User-defined reason for the current value of instance eligibility. Usually, this can be directly mapped to the internal state. An empty reason is allowed. Corresponds to the JSON property reason

Returns:

  • (String)


6751
6752
6753
# File 'lib/google/apis/connectors_v1/classes.rb', line 6751

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6758
6759
6760
6761
# File 'lib/google/apis/connectors_v1/classes.rb', line 6758

def update!(**args)
  @eligible = args[:eligible] if args.key?(:eligible)
  @reason = args[:reason] if args.key?(:reason)
end