Class: Google::Apis::ConnectorsV1::SshPublicKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Parameters to support Ssh public key Authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SshPublicKey

Returns a new instance of SshPublicKey.



6850
6851
6852
# File 'lib/google/apis/connectors_v1/classes.rb', line 6850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cert_typeString

Optional. Format of SSH Client cert. Corresponds to the JSON property certType

Returns:

  • (String)


6833
6834
6835
# File 'lib/google/apis/connectors_v1/classes.rb', line 6833

def cert_type
  @cert_type
end

#ssh_client_certGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property sshClientCert



6838
6839
6840
# File 'lib/google/apis/connectors_v1/classes.rb', line 6838

def ssh_client_cert
  @ssh_client_cert
end

#ssh_client_cert_passGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property sshClientCertPass



6843
6844
6845
# File 'lib/google/apis/connectors_v1/classes.rb', line 6843

def ssh_client_cert_pass
  @ssh_client_cert_pass
end

#usernameString

Optional. The user account used to authenticate. Corresponds to the JSON property username

Returns:

  • (String)


6848
6849
6850
# File 'lib/google/apis/connectors_v1/classes.rb', line 6848

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6855
6856
6857
6858
6859
6860
# File 'lib/google/apis/connectors_v1/classes.rb', line 6855

def update!(**args)
  @cert_type = args[:cert_type] if args.key?(:cert_type)
  @ssh_client_cert = args[:ssh_client_cert] if args.key?(:ssh_client_cert)
  @ssh_client_cert_pass = args[:ssh_client_cert_pass] if args.key?(:ssh_client_cert_pass)
  @username = args[:username] if args.key?(:username)
end