Class: Google::Apis::ConnectorsV1::SslConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

SSL Configuration of a connection

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslConfig

Returns a new instance of SslConfig.



7010
7011
7012
# File 'lib/google/apis/connectors_v1/classes.rb', line 7010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_variablesArray<Google::Apis::ConnectorsV1::ConfigVariable>

Optional. Additional SSL related field values Corresponds to the JSON property additionalVariables



6962
6963
6964
# File 'lib/google/apis/connectors_v1/classes.rb', line 6962

def additional_variables
  @additional_variables
end

#client_cert_typeString

Optional. Type of Client Cert (PEM/JKS/.. etc.) Corresponds to the JSON property clientCertType

Returns:

  • (String)


6967
6968
6969
# File 'lib/google/apis/connectors_v1/classes.rb', line 6967

def client_cert_type
  @client_cert_type
end

#client_certificateGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientCertificate



6972
6973
6974
# File 'lib/google/apis/connectors_v1/classes.rb', line 6972

def client_certificate
  @client_certificate
end

#client_private_keyGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientPrivateKey



6977
6978
6979
# File 'lib/google/apis/connectors_v1/classes.rb', line 6977

def client_private_key
  @client_private_key
end

#client_private_key_passGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property clientPrivateKeyPass



6982
6983
6984
# File 'lib/google/apis/connectors_v1/classes.rb', line 6982

def client_private_key_pass
  @client_private_key_pass
end

#private_server_certificateGoogle::Apis::ConnectorsV1::Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property privateServerCertificate



6987
6988
6989
# File 'lib/google/apis/connectors_v1/classes.rb', line 6987

def private_server_certificate
  @private_server_certificate
end

#server_cert_typeString

Optional. Type of Server Cert (PEM/JKS/.. etc.) Corresponds to the JSON property serverCertType

Returns:

  • (String)


6992
6993
6994
# File 'lib/google/apis/connectors_v1/classes.rb', line 6992

def server_cert_type
  @server_cert_type
end

#trust_modelString

Optional. Trust Model of the SSL connection Corresponds to the JSON property trustModel

Returns:

  • (String)


6997
6998
6999
# File 'lib/google/apis/connectors_v1/classes.rb', line 6997

def trust_model
  @trust_model
end

#typeString

Optional. Controls the ssl type for the given connector version. Corresponds to the JSON property type

Returns:

  • (String)


7002
7003
7004
# File 'lib/google/apis/connectors_v1/classes.rb', line 7002

def type
  @type
end

#use_sslBoolean Also known as: use_ssl?

Optional. Bool for enabling SSL Corresponds to the JSON property useSsl

Returns:

  • (Boolean)


7007
7008
7009
# File 'lib/google/apis/connectors_v1/classes.rb', line 7007

def use_ssl
  @use_ssl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/google/apis/connectors_v1/classes.rb', line 7015

def update!(**args)
  @additional_variables = args[:additional_variables] if args.key?(:additional_variables)
  @client_cert_type = args[:client_cert_type] if args.key?(:client_cert_type)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_private_key = args[:client_private_key] if args.key?(:client_private_key)
  @client_private_key_pass = args[:client_private_key_pass] if args.key?(:client_private_key_pass)
  @private_server_certificate = args[:private_server_certificate] if args.key?(:private_server_certificate)
  @server_cert_type = args[:server_cert_type] if args.key?(:server_cert_type)
  @trust_model = args[:trust_model] if args.key?(:trust_model)
  @type = args[:type] if args.key?(:type)
  @use_ssl = args[:use_ssl] if args.key?(:use_ssl)
end