Class: Google::Apis::ConnectorsV1::SslConfigTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Ssl config details of a connector version

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslConfigTemplate

Returns a new instance of SslConfigTemplate.



6967
6968
6969
# File 'lib/google/apis/connectors_v1/classes.rb', line 6967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_variablesArray<Google::Apis::ConnectorsV1::ConfigVariableTemplate>

Any additional fields that need to be rendered Corresponds to the JSON property additionalVariables



6944
6945
6946
# File 'lib/google/apis/connectors_v1/classes.rb', line 6944

def additional_variables
  @additional_variables
end

#client_cert_typeArray<String>

List of supported Client Cert Types Corresponds to the JSON property clientCertType

Returns:

  • (Array<String>)


6949
6950
6951
# File 'lib/google/apis/connectors_v1/classes.rb', line 6949

def client_cert_type
  @client_cert_type
end

#is_tls_mandatoryBoolean Also known as: is_tls_mandatory?

Boolean for determining if the connector version mandates TLS. Corresponds to the JSON property isTlsMandatory

Returns:

  • (Boolean)


6954
6955
6956
# File 'lib/google/apis/connectors_v1/classes.rb', line 6954

def is_tls_mandatory
  @is_tls_mandatory
end

#server_cert_typeArray<String>

List of supported Server Cert Types Corresponds to the JSON property serverCertType

Returns:

  • (Array<String>)


6960
6961
6962
# File 'lib/google/apis/connectors_v1/classes.rb', line 6960

def server_cert_type
  @server_cert_type
end

#ssl_typeString

Controls the ssl type for the given connector version Corresponds to the JSON property sslType

Returns:

  • (String)


6965
6966
6967
# File 'lib/google/apis/connectors_v1/classes.rb', line 6965

def ssl_type
  @ssl_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6972
6973
6974
6975
6976
6977
6978
# File 'lib/google/apis/connectors_v1/classes.rb', line 6972

def update!(**args)
  @additional_variables = args[:additional_variables] if args.key?(:additional_variables)
  @client_cert_type = args[:client_cert_type] if args.key?(:client_cert_type)
  @is_tls_mandatory = args[:is_tls_mandatory] if args.key?(:is_tls_mandatory)
  @server_cert_type = args[:server_cert_type] if args.key?(:server_cert_type)
  @ssl_type = args[:ssl_type] if args.key?(:ssl_type)
end