Class: Google::Apis::ConnectorsV1::SupportedRuntimeFeatures
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::SupportedRuntimeFeatures
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Supported runtime features of a connector version.
Instance Attribute Summary collapse
-
#action_apis ⇒ Boolean
(also: #action_apis?)
Specifies if the connector supports action apis like 'executeAction'.
-
#async_operations ⇒ Boolean
(also: #async_operations?)
Specifies if the connector supports async long running operations.
-
#entity_apis ⇒ Boolean
(also: #entity_apis?)
Specifies if the connector supports entity apis like 'createEntity'.
-
#sql_query ⇒ Boolean
(also: #sql_query?)
Specifies if the connector supports 'ExecuteSqlQuery' operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupportedRuntimeFeatures
constructor
A new instance of SupportedRuntimeFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupportedRuntimeFeatures
Returns a new instance of SupportedRuntimeFeatures.
7086 7087 7088 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_apis ⇒ Boolean Also known as: action_apis?
Specifies if the connector supports action apis like 'executeAction'.
Corresponds to the JSON property actionApis
7065 7066 7067 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7065 def action_apis @action_apis end |
#async_operations ⇒ Boolean Also known as: async_operations?
Specifies if the connector supports async long running operations.
Corresponds to the JSON property asyncOperations
7071 7072 7073 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7071 def async_operations @async_operations end |
#entity_apis ⇒ Boolean Also known as: entity_apis?
Specifies if the connector supports entity apis like 'createEntity'.
Corresponds to the JSON property entityApis
7077 7078 7079 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7077 def entity_apis @entity_apis end |
#sql_query ⇒ Boolean Also known as: sql_query?
Specifies if the connector supports 'ExecuteSqlQuery' operation.
Corresponds to the JSON property sqlQuery
7083 7084 7085 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7083 def sql_query @sql_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7091 7092 7093 7094 7095 7096 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7091 def update!(**args) @action_apis = args[:action_apis] if args.key?(:action_apis) @async_operations = args[:async_operations] if args.key?(:async_operations) @entity_apis = args[:entity_apis] if args.key?(:entity_apis) @sql_query = args[:sql_query] if args.key?(:sql_query) end |