Class: Google::Apis::ConnectorsV1::ToolName

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Tool name for which the tool spec override is to be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolName

Returns a new instance of ToolName.



7295
7296
7297
# File 'lib/google/apis/connectors_v1/classes.rb', line 7295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_typeString

Optional. Entity type name for which the tool was generated. Corresponds to the JSON property entityType

Returns:

  • (String)


7283
7284
7285
# File 'lib/google/apis/connectors_v1/classes.rb', line 7283

def entity_type
  @entity_type
end

#nameString

Required. Tool name that was generated in the list tools call. Corresponds to the JSON property name

Returns:

  • (String)


7288
7289
7290
# File 'lib/google/apis/connectors_v1/classes.rb', line 7288

def name
  @name
end

#operationString

Optional. Operation for which the tool was generated. Corresponds to the JSON property operation

Returns:

  • (String)


7293
7294
7295
# File 'lib/google/apis/connectors_v1/classes.rb', line 7293

def operation
  @operation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7300
7301
7302
7303
7304
# File 'lib/google/apis/connectors_v1/classes.rb', line 7300

def update!(**args)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
end