Class: Google::Apis::ConnectorsV1::ToolName
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::ToolName
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Tool name for which the tool spec override is to be generated.
Instance Attribute Summary collapse
-
#entity_type ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#operation ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolName
constructor
A new instance of ToolName.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolName
Returns a new instance of ToolName.
7295 7296 7297 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7295 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity_type ⇒ String
Optional. Entity type name for which the tool was generated.
Corresponds to the JSON property entityType
7283 7284 7285 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7283 def entity_type @entity_type end |
#name ⇒ String
Required. Tool name that was generated in the list tools call.
Corresponds to the JSON property name
7288 7289 7290 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7288 def name @name end |
#operation ⇒ String
Optional. Operation for which the tool was generated.
Corresponds to the JSON property operation
7293 7294 7295 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7293 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7300 7301 7302 7303 7304 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7300 def update!(**args) @entity_type = args[:entity_type] if args.key?(:entity_type) @name = args[:name] if args.key?(:name) @operation = args[:operation] if args.key?(:operation) end |