Class: Google::Apis::ConnectorsV1::ToolspecOverride
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::ToolspecOverride
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins.
Instance Attribute Summary collapse
-
#base_version ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#tools ⇒ Array<Hash<String,Object>>
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolspecOverride
constructor
A new instance of ToolspecOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolspecOverride
Returns a new instance of ToolspecOverride.
7716 7717 7718 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_version ⇒ String
Required. Represents the base version of the toolspec for which admin has
added overrides.
Corresponds to the JSON property baseVersion
7697 7698 7699 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7697 def base_version @base_version end |
#create_time ⇒ String
Output only. Created time.
Corresponds to the JSON property createTime
7702 7703 7704 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7702 def create_time @create_time end |
#tools ⇒ Array<Hash<String,Object>>
Required. List of tools defined in the tool spec. Marking this field as
required as this is the only field that is editable by the user in modify API
so we should have at least one tool in the list.
Corresponds to the JSON property tools
7709 7710 7711 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7709 def tools @tools end |
#update_time ⇒ String
Output only. Updated time.
Corresponds to the JSON property updateTime
7714 7715 7716 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7714 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7721 7722 7723 7724 7725 7726 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7721 def update!(**args) @base_version = args[:base_version] if args.key?(:base_version) @create_time = args[:create_time] if args.key?(:create_time) @tools = args[:tools] if args.key?(:tools) @update_time = args[:update_time] if args.key?(:update_time) end |