Class: Google::Apis::ConnectorsV1::ToolspecOverride

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb

Overview

Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolspecOverride

Returns a new instance of ToolspecOverride.



7329
7330
7331
# File 'lib/google/apis/connectors_v1/classes.rb', line 7329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Created time. Corresponds to the JSON property createTime

Returns:

  • (String)


7315
7316
7317
# File 'lib/google/apis/connectors_v1/classes.rb', line 7315

def create_time
  @create_time
end

#toolsArray<Hash<String,Object>>

Required. List of tools defined in the tool spec. Marking this field as required as this is the only field that is editable by the user in modify API so we should have at least one tool in the list. Corresponds to the JSON property tools

Returns:

  • (Array<Hash<String,Object>>)


7322
7323
7324
# File 'lib/google/apis/connectors_v1/classes.rb', line 7322

def tools
  @tools
end

#update_timeString

Output only. Updated time. Corresponds to the JSON property updateTime

Returns:

  • (String)


7327
7328
7329
# File 'lib/google/apis/connectors_v1/classes.rb', line 7327

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7334
7335
7336
7337
7338
# File 'lib/google/apis/connectors_v1/classes.rb', line 7334

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @tools = args[:tools] if args.key?(:tools)
  @update_time = args[:update_time] if args.key?(:update_time)
end