Class: Google::Apis::ConnectorsV1::ToolspecOverride
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::ToolspecOverride
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#tools ⇒ Array<Hash<String,Object>>
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolspecOverride
constructor
A new instance of ToolspecOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolspecOverride
Returns a new instance of ToolspecOverride.
7329 7330 7331 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Created time.
Corresponds to the JSON property createTime
7315 7316 7317 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7315 def create_time @create_time end |
#tools ⇒ Array<Hash<String,Object>>
Required. List of tools defined in the tool spec. Marking this field as
required as this is the only field that is editable by the user in modify API
so we should have at least one tool in the list.
Corresponds to the JSON property tools
7322 7323 7324 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7322 def tools @tools end |
#update_time ⇒ String
Output only. Updated time.
Corresponds to the JSON property updateTime
7327 7328 7329 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7327 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7334 7335 7336 7337 7338 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7334 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @tools = args[:tools] if args.key?(:tools) @update_time = args[:update_time] if args.key?(:update_time) end |