Class: Google::Apis::ConnectorsV1::UserPassword
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV1::UserPassword
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v1/classes.rb,
lib/google/apis/connectors_v1/representations.rb,
lib/google/apis/connectors_v1/representations.rb
Overview
Parameters to support Username and Password Authentication.
Instance Attribute Summary collapse
-
#password ⇒ Google::Apis::ConnectorsV1::Secret
Secret provides a reference to entries in Secret Manager.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserPassword
constructor
A new instance of UserPassword.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserPassword
Returns a new instance of UserPassword.
7274 7275 7276 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password ⇒ Google::Apis::ConnectorsV1::Secret
Secret provides a reference to entries in Secret Manager.
Corresponds to the JSON property password
7267 7268 7269 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7267 def password @password end |
#username ⇒ String
Optional. Username.
Corresponds to the JSON property username
7272 7273 7274 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7272 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7279 7280 7281 7282 |
# File 'lib/google/apis/connectors_v1/classes.rb', line 7279 def update!(**args) @password = args[:password] if args.key?(:password) @username = args[:username] if args.key?(:username) end |